@@ -20,6 +20,7 @@ from mercurial import (
     pycompat,
     registrar,
     ui as uimod,
+    util,
 )
 from mercurial.utils import (
     procutil,
@@ -120,7 +121,7 @@ def cmdview(ui, repo, *pats, **opts):
     # TODO: Figure out if this hack for py2exe is still needed, and possibly
     #       wrap this to handle unicode on py3
     if not pycompat.ispy3:
-        mystderr = pycompat.bytesio()
+        mystderr = util.bytesio()
         sys.stderr = mystderr
         sys.__stdout__ = sys.stdout
         sys.__stderr__ = sys.stderr
