@@ -38,6 +38,7 @@ import array
 
 from mercurial import (
     pycompat,
+    util,
 )
 
 __version__ = "1.1-pythongettext"
@@ -236,4 +237,4 @@ class Msgfmt:
             self.po.close()
 
     def getAsFile(self):
-        return pycompat.bytesio(self.get())
+        return util.bytesio(self.get())
