@@ -54,7 +54,7 @@ class AboutDialog(QDialog):
 
         self.setWindowIcon(qtlib.geticon('thg'))
         self.setWindowTitle(_('About'))
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self.vbox = QVBoxLayout()
         self.vbox.setSpacing(8)
@@ -62,33 +62,33 @@ class AboutDialog(QDialog):
         self.logo_lbl = QLabel()
         self.logo_lbl.setMinimumSize(QSize(92, 50))
         self.logo_lbl.setScaledContents(False)
-        self.logo_lbl.setAlignment(Qt.AlignCenter)
+        self.logo_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.logo_lbl.setPixmap(QPixmap(qtlib.iconpath('thg_logo_92x50.png')))
         self.vbox.addWidget(self.logo_lbl)
 
         self.name_version_libs_lbl = QLabel()
         self.name_version_libs_lbl.setText(' ')
-        self.name_version_libs_lbl.setAlignment(Qt.AlignCenter)
+        self.name_version_libs_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.name_version_libs_lbl.setTextInteractionFlags(
-                Qt.TextSelectableByMouse)
+                Qt.TextInteractionFlag.TextSelectableByMouse)
         self.vbox.addWidget(self.name_version_libs_lbl)
         self.getVersionInfo()
 
         self.copyright_lbl = QLabel()
-        self.copyright_lbl.setAlignment(Qt.AlignCenter)
+        self.copyright_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.copyright_lbl.setText('\n'
                 + _('Copyright 2008-2022 Steve Borho and others'))
         self.vbox.addWidget(self.copyright_lbl)
         self.courtesy_lbl = QLabel()
-        self.courtesy_lbl.setAlignment(Qt.AlignCenter)
+        self.courtesy_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.courtesy_lbl.setText(
               _('Several icons are courtesy of the TortoiseSVN and Tango projects') + '\n')
         self.vbox.addWidget(self.courtesy_lbl)
 
         self.download_url_lbl = QLabel()
         self.download_url_lbl.setMouseTracking(True)
-        self.download_url_lbl.setAlignment(Qt.AlignCenter)
-        self.download_url_lbl.setTextInteractionFlags(Qt.LinksAccessibleByMouse)
+        self.download_url_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
+        self.download_url_lbl.setTextInteractionFlags(Qt.TextInteractionFlag.LinksAccessibleByMouse)
         self.download_url_lbl.setOpenExternalLinks(True)
         self.download_url_lbl.setText('<a href=%s>%s</a>' %
                                       ('https://tortoisehg.bitbucket.io',
@@ -99,7 +99,7 @@ class AboutDialog(QDialog):
         self.vbox.addWidget(QLabel())
 
         self.hosting_lbl = QLabel()
-        self.hosting_lbl.setAlignment(Qt.AlignCenter)
+        self.hosting_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.hosting_lbl.setText(
             _('Hosting donated by %s and %s') % (
                 '<a href=https://clever-cloud.com>Clever Cloud</a>',
@@ -108,7 +108,7 @@ class AboutDialog(QDialog):
         )
         self.hosting_lbl.setMouseTracking(True)
         self.hosting_lbl.setTextInteractionFlags(
-            Qt.LinksAccessibleByMouse
+            Qt.TextInteractionFlag.LinksAccessibleByMouse
         )
         self.hosting_lbl.setOpenExternalLinks(True)
         self.vbox.addWidget(self.hosting_lbl)
@@ -119,16 +119,16 @@ class AboutDialog(QDialog):
 
         bbox = QDialogButtonBox(self)
         self.license_btn = bbox.addButton(_('&License'),
-                                          QDialogButtonBox.ResetRole)
+                                          QDialogButtonBox.ButtonRole.ResetRole)
         self.license_btn.setAutoDefault(False)
         self.license_btn.clicked.connect(self.showLicense)
-        self.close_btn = bbox.addButton(QDialogButtonBox.Close)
+        self.close_btn = bbox.addButton(QDialogButtonBox.StandardButton.Close)
         self.close_btn.setDefault(True)
         self.close_btn.clicked.connect(self.close)
         self.vbox.addWidget(bbox)
 
         self.setLayout(self.vbox)
-        self.layout().setSizeConstraint(QLayout.SetFixedSize)
+        self.layout().setSizeConstraint(QLayout.SizeConstraint.SetFixedSize)
         self._readsettings()
 
         # Spawn it later, so that the dialog gets visible quickly.
@@ -184,13 +184,13 @@ class LicenseDialog(QDialog):
 
         self.setWindowIcon(qtlib.geticon('thg'))
         self.setWindowTitle(_('License'))
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.resize(700, 400)
 
         self.lic_txt = QPlainTextEdit()
         self.lic_txt.setFont(QFont('Monospace'))
         self.lic_txt.setTextInteractionFlags(
-                Qt.TextSelectableByKeyboard|Qt.TextSelectableByMouse)
+                Qt.TextInteractionFlag.TextSelectableByKeyboard|Qt.TextInteractionFlag.TextSelectableByMouse)
         try:
             with open(paths.get_license_path(), 'r') as fp:
                 lic = fp.read()
@@ -199,7 +199,7 @@ class LicenseDialog(QDialog):
             pass
 
         bbox = QDialogButtonBox(self)
-        self.close_btn = bbox.addButton(QDialogButtonBox.Close)
+        self.close_btn = bbox.addButton(QDialogButtonBox.StandardButton.Close)
         self.close_btn.clicked.connect(self.close)
 
         self.vbox = QVBoxLayout()
