@@ -82,7 +82,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
     def __init__(self, repoagent, rev, parent=None, minrev=None):
         # type: (thgrepo.RepoAgent, Optional[Text], Optional[QWidget], Optional[Text]) -> None
         super(ArchiveWidget, self).__init__(parent)
-        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._repoagent = repoagent
         if not minrev:
             minrev = rev
@@ -108,7 +108,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         ## revision selection
         self.rev_combo = QComboBox()
         self.rev_combo.setEditable(True)
-        self.rev_combo.setSizeAdjustPolicy(QComboBox.AdjustToContents)
+        self.rev_combo.setSizeAdjustPolicy(QComboBox.SizeAdjustPolicy.AdjustToContents)
         form.addRow(_('Revision:'), self.rev_combo)
 
         ### content type
@@ -127,7 +127,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         sincebox = QHBoxLayout()
         self.rootrev_combo = QComboBox(self)
         self.rootrev_combo.setEditable(True)
-        self.rootrev_combo.setSizeAdjustPolicy(QComboBox.AdjustToContents)
+        self.rootrev_combo.setSizeAdjustPolicy(QComboBox.SizeAdjustPolicy.AdjustToContents)
         if minrev:
             for text in possibleroots:
                 self.rootrev_combo.addItem(text)
@@ -228,7 +228,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             filter = ';;'.join(['%s (%s)' % (select['label'], ext),
                                 _('All files (*)')])
         response, _filter = FD.getSaveFileName(
-            self, caption, dest, filter, '', FD.ReadOnly)
+            self, caption, dest, filter, '', QFileDialog.Option.ReadOnly)
         if response:
             self.dest_edit.setText(response)
             self.update_path()
