@@ -85,16 +85,16 @@ class BackoutDialog(QWizard):
         super(BackoutDialog, self).__init__(parent)
         self._repoagent = repoagent
         f = self.windowFlags()
-        self.setWindowFlags(f & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(f & ~Qt.WindowType.WindowContextHelpButtonHint)
 
         repo = repoagent.rawRepo()
         parentbackout = repo[rev] == repo[b'.']
 
         self.setWindowTitle(_('Backout - %s') % repoagent.displayName())
         self.setWindowIcon(qtlib.geticon('hg-revert'))
-        self.setOption(QWizard.NoBackButtonOnStartPage, True)
-        self.setOption(QWizard.NoBackButtonOnLastPage, True)
-        self.setOption(QWizard.IndependentPages, True)
+        self.setOption(QWizard.WizardOption.NoBackButtonOnStartPage, True)
+        self.setOption(QWizard.WizardOption.NoBackButtonOnLastPage, True)
+        self.setOption(QWizard.WizardOption.IndependentPages, True)
 
         self.addPage(SummaryPage(repoagent, rev, parentbackout, self))
         self.addPage(BackoutPage(repoagent, rev, parentbackout, self))
@@ -511,7 +511,7 @@ class CommitPage(BasePage):
             if self.isComplete():
                 self.wizard().next()
         actionEnter = QAction('alt-enter', self)
-        actionEnter.setShortcuts([Qt.CTRL+Qt.Key_Return, Qt.CTRL+Qt.Key_Enter])
+        actionEnter.setShortcuts([Qt.Modifier.CTRL+Qt.Key.Key_Return, Qt.Modifier.CTRL+Qt.Key.Key_Enter])
         actionEnter.triggered.connect(tryperform)
         self.addAction(actionEnter)
 
@@ -637,4 +637,4 @@ class ResultPage(BasePage):
     def currentPage(self):
         # type: () -> None
         self.bkCsInfo.update(self.repo[b'tip'])
-        self.wizard().setOption(QWizard.NoCancelButton, True)
+        self.wizard().setOption(QWizard.WizardOption.NoCancelButton, True)
