@@ -65,7 +65,7 @@ class BlockList(QWidget):
         self._pagestep = 10
         self._vrectcolor = QColor(0x00, 0x00, 0x55, 0x25)
         self._vrectbordercolor = self._vrectcolor.darker()
-        self.sizePolicy().setControlType(QSizePolicy.Slider)
+        self.sizePolicy().setControlType(QSizePolicy.ControlType.Slider)
         self.setMinimumWidth(20)
 
     def clear(self):
@@ -186,7 +186,7 @@ class BlockMatch(BlockList):
         self._pagestep =  {'left': 10, 'right': 10}
         self._vrectcolor = QColor(0x00, 0x00, 0x55, 0x25)
         self._vrectbordercolor = self._vrectcolor.darker()
-        self.sizePolicy().setControlType(QSizePolicy.Slider)
+        self.sizePolicy().setControlType(QSizePolicy.ControlType.Slider)
         self.setMinimumWidth(20)
 
     def nDiffs(self):
@@ -243,7 +243,7 @@ class BlockMatch(BlockList):
         w = self.width()
         h = self.height()
         p = QPainter(self)
-        p.setRenderHint(p.Antialiasing)
+        p.setRenderHint(QPainter.RenderHint.Antialiasing)
 
         ps_l = float(self._pagestep['left'])
         ps_r = float(self._pagestep['right'])
@@ -260,7 +260,7 @@ class BlockMatch(BlockList):
         mr = v_r
         Mr = v_r + ps_r
 
-        p.setPen(Qt.NoPen)
+        p.setPen(Qt.PenStyle.NoPen)
         for typ, alo, ahi, blo, bhi in self._blocks:
             if not (ml<=alo<=Ml or ml<=ahi<=Ml or mr<=blo<=Mr or mr<=bhi<=Mr):
                 continue
