@@ -50,7 +50,7 @@ class BookmarkDialog(QDialog):
     def __init__(self, repoagent, rev, parent=None):
         super(BookmarkDialog, self).__init__(parent)
         self.setWindowFlags(self.windowFlags() & \
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
         self._repoagent = repoagent
         repo = repoagent.rawRepo()
         self._cmdsession = cmdcore.nullCmdSession()
@@ -61,13 +61,13 @@ class BookmarkDialog(QDialog):
         base = QVBoxLayout()
         base.setSpacing(0)
         base.setContentsMargins(*(0,)*4)
-        base.setSizeConstraint(QLayout.SetMinAndMaxSize)
+        base.setSizeConstraint(QLayout.SizeConstraint.SetMinAndMaxSize)
         self.setLayout(base)
 
         ## main layout grid
         formwidget = QWidget(self)
-        formwidget.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
-        form = QFormLayout(fieldGrowthPolicy=QFormLayout.AllNonFixedFieldsGrow)
+        formwidget.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
+        form = QFormLayout(fieldGrowthPolicy=QFormLayout.FieldGrowthPolicy.AllNonFixedFieldsGrow)
         formwidget.setLayout(form)
         base.addWidget(formwidget)
 
@@ -97,13 +97,12 @@ class BookmarkDialog(QDialog):
         form.addRow(_('Activate:'), self.activateCheckBox)
 
         ## bottom buttons
-        BB = QDialogButtonBox
         bbox = QDialogButtonBox()
-        self.addBtn = bbox.addButton(_('&Add'), BB.ActionRole)
-        self.renameBtn = bbox.addButton(_('Re&name'), BB.ActionRole)
-        self.removeBtn = bbox.addButton(_('&Remove'), BB.ActionRole)
-        self.moveBtn = bbox.addButton(_('&Move'), BB.ActionRole)
-        bbox.addButton(BB.Close)
+        self.addBtn = bbox.addButton(_('&Add'), QDialogButtonBox.ButtonRole.ActionRole)
+        self.renameBtn = bbox.addButton(_('Re&name'), QDialogButtonBox.ButtonRole.ActionRole)
+        self.removeBtn = bbox.addButton(_('&Remove'), QDialogButtonBox.ButtonRole.ActionRole)
+        self.moveBtn = bbox.addButton(_('&Move'), QDialogButtonBox.ButtonRole.ActionRole)
+        bbox.addButton(QDialogButtonBox.StandardButton.Close)
         bbox.rejected.connect(self.reject)
         form.addRow(bbox)
 
@@ -114,8 +113,8 @@ class BookmarkDialog(QDialog):
 
         ## horizontal separator
         self.sep = QFrame()
-        self.sep.setFrameShadow(QFrame.Sunken)
-        self.sep.setFrameShape(QFrame.HLine)
+        self.sep.setFrameShadow(QFrame.Shadow.Sunken)
+        self.sep.setFrameShape(QFrame.Shape.HLine)
         self.layout().addWidget(self.sep)
 
         ## status line
@@ -287,7 +286,7 @@ class SyncBookmarkDialog(QDialog):
 
         # horizontal splitter
         self.splitter = QSplitter(self)
-        self.splitter.setOrientation(Qt.Horizontal)
+        self.splitter.setOrientation(Qt.Orientation.Horizontal)
         self.splitter.setChildrenCollapsible(False)
         self.splitter.setObjectName('splitter')
         self.layout().addWidget(self.splitter)
@@ -301,8 +300,8 @@ class SyncBookmarkDialog(QDialog):
         outgoingLabel = QLabel(_('Outgoing Bookmarks'))
         outgoingLayout.addWidget(outgoingLabel)
         self.outgoingList = QListWidget(self)
-        self.outgoingList.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.outgoingList.setSelectionMode(QListWidget.ExtendedSelection)
+        self.outgoingList.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
+        self.outgoingList.setSelectionMode(QListWidget.SelectionMode.ExtendedSelection)
         self.outgoingList.customContextMenuRequested.connect(
             self._onOutgoingMenuRequested)
         self.outgoingList.itemSelectionChanged.connect(self._updateActions)
@@ -332,8 +331,8 @@ class SyncBookmarkDialog(QDialog):
         incomingLabel = QLabel(_('Incoming Bookmarks'))
         incomingLayout.addWidget(incomingLabel)
         self.incomingList = QListWidget(self)
-        self.incomingList.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.incomingList.setSelectionMode(QListWidget.ExtendedSelection)
+        self.incomingList.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
+        self.incomingList.setSelectionMode(QListWidget.SelectionMode.ExtendedSelection)
         self.incomingList.customContextMenuRequested.connect(
             self._onIncomingMenuRequested)
         self.incomingList.itemSelectionChanged.connect(self._updateActions)
@@ -457,7 +456,7 @@ class SyncBookmarkDialog(QDialog):
         bookmarks = [hglib.tounicode(x.strip()) for x in bookmarks]
         worklist.addItems(bookmarks)
         for select in selected:
-            items = worklist.findItems(select, Qt.MatchExactly)
+            items = worklist.findItems(select, Qt.MatchFlag.MatchExactly)
             for item in items:
                 item.setSelected(True)
 
@@ -472,7 +471,7 @@ class SyncBookmarkDialog(QDialog):
     def _popupMenuFor(self, actions, worklist, pos):
         menu = QMenu(self)
         menu.addActions(actions)
-        menu.setAttribute(Qt.WA_DeleteOnClose)
+        menu.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         menu.popup(worklist.viewport().mapToGlobal(pos))
 
     @pyqtSlot()
