@@ -96,11 +96,10 @@ class BranchOpDialog(QDialog):
                 newbranch.setChecked(True)
             self.closebranch = closebranch
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
-        bb.button(BB.Ok).setAutoDefault(True)
+        bb.button(QDialogButtonBox.StandardButton.Ok).setAutoDefault(True)
         layout.addWidget(bb)
         self.bb = bb
         self.branchCombo = branchCombo
