@@ -132,7 +132,7 @@ class BugReport(QDialog):
             return hglib.tounicode(ext)
 
         # TODO: make this more uniformly unicode safe
-        text = '#!python\n'
+        text = '```python\n'
         text += '** Mercurial version (%s).  TortoiseHg version (%s)\n' % (
                 hglib.hgversion, version.version())
         text += '** Command: %s\n' % (hglib.tounicode(opts.get('cmd', 'N/A')))
@@ -148,7 +148,8 @@ class BugReport(QDialog):
         text += ('** Qt-%s PyQt-%s QScintilla-%s\n'
                  % (QT_VERSION_STR, PYQT_VERSION_STR, QSCINTILLA_VERSION_STR))
         text += hglib.tounicode(opts.get('error', 'N/A'))
-        return "```" + text + "```"
+        text += '\n```'
+        return text
 
     def copyText(self):
         QApplication.clipboard().setText(self.text)
