@@ -89,7 +89,7 @@ class ChunksWidget(QWidget):
         self.setLayout(layout)
 
         self.splitter = QSplitter(self)
-        self.splitter.setOrientation(Qt.Vertical)
+        self.splitter.setOrientation(Qt.Orientation.Vertical)
         self.splitter.setChildrenCollapsible(False)
         self.layout().addWidget(self.splitter)
 
@@ -98,12 +98,12 @@ class ChunksWidget(QWidget):
         model = manifestmodel.ManifestModel(
             repoagent, self, statusfilter='MAR', flat=True)
         self.filelist.setModel(model)
-        self.filelist.setContextMenuPolicy(Qt.CustomContextMenu)
+        self.filelist.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.filelist.customContextMenuRequested.connect(self.menuRequest)
         self.filelist.doubleClicked.connect(self.vdiff)
 
         self.fileListFrame = QFrame(self.splitter)
-        self.fileListFrame.setFrameShape(QFrame.NoFrame)
+        self.fileListFrame.setFrameShape(QFrame.Shape.NoFrame)
         vbox = QVBoxLayout()
         vbox.setSpacing(0)
         vbox.setContentsMargins(0, 0, 0, 0)
@@ -240,7 +240,7 @@ class ChunksWidget(QWidget):
                                        parent=self):
                     dlg = rejects.RejectsDialog(repo.ui, repo.wjoin(wfile),
                                                 self)
-                    if dlg.exec_() == QDialog.Accepted:
+                    if dlg.exec_() == QDialog.DialogCode.Accepted:
                         ok = True
                     break
         return ok
@@ -284,7 +284,7 @@ class ChunksWidget(QWidget):
         if isinstance(ctx, patchctx):
             repo.thgbackup(ctx._path)
             fp = util.atomictempfile(ctx._path, b'wb')
-            buf = pycompat.bytesio()
+            buf = util.bytesio()
             try:
                 if ctx._ph.comments:
                     buf.write(b'\n'.join(ctx._ph.comments))
@@ -326,7 +326,7 @@ class ChunksWidget(QWidget):
                     wf = repo.wvfs(self.currentFile, b'wb', atomictemp=True)
                     wf.write(self.diffbrowse.origcontents)
                     wf.close()
-                    fp = pycompat.bytesio()
+                    fp = util.bytesio()
                     chunks[0].write(fp)
                     for c in kchunks:
                         c.write(fp)
@@ -393,7 +393,7 @@ class ChunksWidget(QWidget):
         else:
             # Apply chunks to wfile
             repo.thgbackup(repo.wjoin(wfile))
-            fp = pycompat.bytesio()
+            fp = util.bytesio()
             for c in chunks:
                 c.write(fp)
             fp.seek(0)
@@ -450,7 +450,7 @@ class ChunksWidget(QWidget):
             else:
                 return []
         else:
-            buf = pycompat.bytesio()
+            buf = util.bytesio()
             diffopts = patch.diffopts(repo.ui, {'git':True})
             m = scmutil.matchfiles(repo, [wfile])
             for p in patch.diff(repo, ctx.p1().node(), None, match=m,
@@ -530,11 +530,11 @@ class ElideLabel(QLabel):
     def paintEvent(self, event):
         p = QPainter()
         fm = QFontMetrics(self.font())
-        if fm.width(self.text()): # > self.contentsRect().width():
-            elided = fm.elidedText(self.text(), Qt.ElideLeft,
+        if fm.horizontalAdvance(self.text()): # > self.contentsRect().width():
+            elided = fm.elidedText(self.text(), Qt.TextElideMode.ElideLeft,
                                    self.rect().width(), 0)
-            p.drawText(self.rect(), Qt.AlignTop | Qt.AlignRight |
-                       Qt.TextSingleLine, elided)
+            p.drawText(self.rect(), Qt.AlignmentFlag.AlignTop | Qt.AlignmentFlag.AlignRight |
+                       Qt.TextFlag.TextSingleLine, elided)
         else:
             super(ElideLabel, self).paintEvent(event)
 
@@ -568,7 +568,7 @@ class DiffBrowser(QFrame):
         hbox.addWidget(w)
         w.setWordWrap(True)
         f = w.textInteractionFlags()
-        w.setTextInteractionFlags(f | Qt.TextSelectableByMouse)
+        w.setTextInteractionFlags(f | Qt.TextInteractionFlag.TextSelectableByMouse)
         w.linkActivated.connect(self.linkActivated)
 
         self.searchbar = qscilib.SearchToolBar()
@@ -580,16 +580,16 @@ class DiffBrowser(QFrame):
         self.sumlabel = QLabel()
         self.allbutton = QToolButton()
         self.allbutton.setText(_('All', 'files'))
-        self.allbutton.setShortcut(QKeySequence.SelectAll)
+        self.allbutton.setShortcut(QKeySequence.StandardKey.SelectAll)
         self.allbutton.clicked.connect(self.selectAll)
         self.nonebutton = QToolButton()
         self.nonebutton.setText(_('None', 'files'))
-        self.nonebutton.setShortcut(QKeySequence.New)
+        self.nonebutton.setShortcut(QKeySequence.StandardKey.New)
         self.nonebutton.clicked.connect(self.selectNone)
         self.actionFind = self.searchbar.toggleViewAction()
         self.actionFind.setIcon(qtlib.geticon('edit-find'))
         self.actionFind.setToolTip(_('Toggle display of text search bar'))
-        qtlib.newshortcutsforstdkey(QKeySequence.Find, self, self.searchbar.show)
+        qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Find, self, self.searchbar.show)
         self.diffToolbar = QToolBar(_('Diff Toolbar'))
         self.diffToolbar.setIconSize(qtlib.smallIconSize())
         self.diffToolbar.setStyleSheet(qtlib.tbstylesheet)
@@ -615,23 +615,23 @@ class DiffBrowser(QFrame):
         self.sci.setCaretLineVisible(False)
         self.sci.setFont(qtlib.getfont('fontdiff').font())
 
-        self.sci.setMarginType(1, qsci.SymbolMargin)
+        self.sci.setMarginType(1, qsci.MarginType.SymbolMargin)
         self.sci.setMarginLineNumbers(1, False)
-        self.sci.setMarginWidth(1, QFontMetrics(self.font()).width('XX'))
+        self.sci.setMarginWidth(1, QFontMetrics(self.font()).horizontalAdvance('XX'))
         self.sci.setMarginSensitivity(1, True)
         self.sci.marginClicked.connect(self.marginClicked)
 
-        self._checkedpix = qtlib.getcheckboxpixmap(QStyle.State_On,
-                                                   Qt.gray, self)
+        self._checkedpix = qtlib.getcheckboxpixmap(QStyle.StateFlag.State_On,
+                                                   Qt.GlobalColor.gray, self)
         self.selected = self.sci.markerDefine(self._checkedpix, -1)
 
-        self._uncheckedpix = qtlib.getcheckboxpixmap(QStyle.State_Off,
-                                                     Qt.gray, self)
+        self._uncheckedpix = qtlib.getcheckboxpixmap(QStyle.StateFlag.State_Off,
+                                                     Qt.GlobalColor.gray, self)
         self.unselected = self.sci.markerDefine(self._uncheckedpix, -1)
 
-        self.vertical = self.sci.markerDefine(qsci.VerticalLine, -1)
-        self.divider = self.sci.markerDefine(qsci.Background, -1)
-        self.selcolor = self.sci.markerDefine(qsci.Background, -1)
+        self.vertical = self.sci.markerDefine(qsci.MarkerSymbol.VerticalLine, -1)
+        self.divider = self.sci.markerDefine(qsci.MarkerSymbol.Background, -1)
+        self.selcolor = self.sci.markerDefine(qsci.MarkerSymbol.Background, -1)
         self.sci.setMarkerBackgroundColor(QColor('#BBFFFF'), self.selcolor)
         self.sci.setMarkerBackgroundColor(QColor('#AAAAAA'), self.divider)
         mask = (1 << self.selected) | (1 << self.unselected) | \
@@ -729,13 +729,13 @@ class DiffBrowser(QFrame):
 
     def _setupForceViewIndicator(self):
         if not self._forceviewindicator:
-            self._forceviewindicator = self.sci.indicatorDefine(self.sci.PlainIndicator)
+            self._forceviewindicator = self.sci.indicatorDefine(self.sci.IndicatorStyle.PlainIndicator)
             self.sci.setIndicatorDrawUnder(True, self._forceviewindicator)
             self.sci.setIndicatorForegroundColor(
                 QColor('blue'), self._forceviewindicator)
             # delay until next event-loop in order to complete mouse release
             self.sci.SCN_INDICATORRELEASE.connect(self.forceDisplayFile,
-                                                  Qt.QueuedConnection)
+                                                  Qt.ConnectionType.QueuedConnection)
 
     def forceDisplayFile(self):
         if self.curchunks:
@@ -783,12 +783,12 @@ class DiffBrowser(QFrame):
         elif isinstance(self._ctx.rev(), str):
             chunks = self._ctx._files[filename]
         else:
-            header = patch.parsepatch(pycompat.bytesio(fd.diff))[0]
+            header = patch.parsepatch(util.bytesio(fd.diff))[0]
             chunks = [header] + header.hunks
 
         utext = []
         for chunk in chunks[1:]:
-            buf = pycompat.bytesio()
+            buf = util.bytesio()
             chunk.selected = False
             chunk.write(buf)
             chunk.lines = buf.getvalue().splitlines()
