@@ -95,7 +95,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
     def __init__(self, config, cmdagent, parent=None):
         # type: (HgConfig, cmdcore.CmdAgent, Optional[QWidget]) -> None
         super(CloneWidget, self).__init__(parent)
-        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._config = config
         self._cmdagent = cmdagent
 
@@ -378,7 +378,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
         FD = QFileDialog
         caption = _("Select source repository")
         path = FD.getExistingDirectory(self, caption,
-            self.src_combo.currentText(), QFileDialog.ShowDirsOnly)
+            self.src_combo.currentText(), QFileDialog.Option.ShowDirsOnly)
         if path:
             self.src_combo.setEditText(QDir.toNativeSeparators(path))
             self._suggestDestination()
@@ -390,7 +390,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
         FD = QFileDialog
         caption = _("Select destination repository")
         path = FD.getExistingDirectory(self, caption,
-            self.dest_combo.currentText(), QFileDialog.ShowDirsOnly)
+            self.dest_combo.currentText(), QFileDialog.Option.ShowDirsOnly)
         if path:
             self.dest_combo.setEditText(QDir.toNativeSeparators(path))
             self._suggestDestination()  # in case existing dir is selected
@@ -403,7 +403,7 @@ class CloneWidget(cmdui.AbstractCmdWidget):
         caption = _("Select patch folder")
         upatchroot = os.path.join(self.src_combo.currentText(), '.hg')
         upath = FD.getExistingDirectory(self, caption, upatchroot,
-                                        QFileDialog.ShowDirsOnly)
+                                        QFileDialog.Option.ShowDirsOnly)
         if upath:
             self.qclone_txt.setText(QDir.toNativeSeparators(upath))
             self.qclone_txt.setFocus()
