@@ -77,23 +77,23 @@ class ProgressMessage(tuple):
     @property
     def topic(self):
         # type: () -> pycompat.unicode
-        return self[0]
+        return self[0]  # pytype: disable=bad-return-type
     @property
     def pos(self):
         # type: () -> Optional[int]
-        return self[1]
+        return self[1]  # pytype: disable=bad-return-type
     @property
     def item(self):
         # type: () -> pycompat.unicode
-        return self[2]
+        return self[2]  # pytype: disable=bad-return-type
     @property
     def unit(self):
         # type: () -> pycompat.unicode
-        return self[3]
+        return self[3]  # pytype: disable=bad-return-type
     @property
     def total(self):
         # type: () -> Optional[int]
-        return self[4]
+        return self[4]  # pytype: disable=bad-return-type
 
     def __repr__(self):
         names = ('topic', 'pos', 'item', 'unit', 'total')
