@@ -9,6 +9,11 @@ from __future__ import absolute_import
 
 import weakref
 
+from typing import (
+    cast,
+    Optional,
+)
+
 from mercurial import (
     pycompat,
 )
@@ -47,10 +52,6 @@ from . import (
     qscilib,
 )
 
-if hglib.TYPE_CHECKING:
-    from typing import (
-        Optional,
-    )
 
 def startProgress(topic, status):
     topic, item, pos, total, unit = topic, '...', status, None, ''
@@ -301,7 +302,7 @@ class InteractiveUiHandler(cmdcore.UiHandler):
         self._prompttext = ''
         self._promptmode = cmdcore.UiHandler.NoInput
         self._promptdefault = ''
-        self._uiparentref = None  # type: Optional[weakref.ReferenceType[QWidget]]
+        self._uiparentref = None
         if uiparent:
             self._uiparentref = weakref.ref(uiparent)
 
@@ -339,18 +340,21 @@ class InteractiveUiHandler(cmdcore.UiHandler):
             button.response = r
             if r == self._promptdefault:
                 dlg.setDefaultButton(button)
-        # cancel button is necessary to close prompt dialog with empty response
-        dlg.addButton(QMessageBox.StandardButton.Cancel).hide()
+        # button to close prompt dialog with empty response (i.e. abort)
+        dlg.addButton(QMessageBox.StandardButton.Abort)
+        dlg.setEscapeButton(QMessageBox.StandardButton.Abort)
         dlg.exec_()
         button = dlg.clickedButton()
         if button and dlg.buttonRole(button) == QMessageBox.ButtonRole.ActionRole:
             return button.response
 
-    def _parentWidget(self):
+    def _parentWidget(self) -> Optional[QWidget]:
+        # TODO: Drop this function if _uiparentref() can be typed as a QWidget
         p = self._uiparentref() if self._uiparentref else None
         while p and not p.isWidgetType():
             p = p.parent()
-        return p
+
+        return cast(Optional[QWidget], p)
 
 
 class PasswordUiHandler(InteractiveUiHandler):
