@@ -722,7 +722,11 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             try:
                 contents = pycompat.unicode(contents)
                 lexer = guess_lexer_for_filename(wfile, contents)
+                assert lexer is not None  # help pytype
+
+                # pytype: disable=attribute-error
                 for tokentype, value in lexer.get_tokens(contents):
+                    # pytype: enable=attribute-error
                     if tokentype in Token.Name and len(value) > 4:
                         tokens.add(value)
             except (ClassNotFound, TypeError):
@@ -901,7 +905,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
 
     def topicOp(self):
         # type: () -> None
-        d = topic.TopicDialog(self._repoagent, self.branchop, self)
+        d = topic.TopicDialog(self._repoagent, None, self)
         d.setWindowFlags(Qt.WindowType.Sheet)
         d.setWindowModality(Qt.WindowModality.WindowModal)
         d.exec_()
