@@ -36,20 +36,20 @@ class CompressDialog(QDialog):
     def __init__(self, repoagent, revs, parent):
         super(CompressDialog, self).__init__(parent)
         f = self.windowFlags()
-        self.setWindowFlags(f & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(f & ~Qt.WindowType.WindowContextHelpButtonHint)
         self._repoagent = repoagent
         self.revs = revs
 
         box = QVBoxLayout()
         box.setSpacing(8)
         box.setContentsMargins(*(6,)*4)
-        box.setSizeConstraint(QLayout.SetMinAndMaxSize)
+        box.setSizeConstraint(QLayout.SizeConstraint.SetMinAndMaxSize)
         self.setLayout(box)
 
         style = csinfo.panelstyle(selectable=True)
 
         srcb = QGroupBox(_('Compress changesets up to and including'))
-        srcb.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed)
+        srcb.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Fixed)
         srcb.setLayout(QVBoxLayout())
         srcb.layout().setContentsMargins(*(2,)*4)
         source = csinfo.create(self.repo, revs[0], style, withupdate=True)
@@ -57,7 +57,7 @@ class CompressDialog(QDialog):
         self.layout().addWidget(srcb)
 
         destb = QGroupBox(_('Onto destination'))
-        destb.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed)
+        destb.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Fixed)
         destb.setLayout(QVBoxLayout())
         destb.layout().setContentsMargins(*(2,)*4)
         dest = csinfo.create(self.repo, revs[1], style, withupdate=True)
@@ -69,7 +69,7 @@ class CompressDialog(QDialog):
         cmd.finished.connect(self.done)
         cmd.setLogVisible(True)
         self.compressbtn = cmd.addButton(_('Compress'),
-                                         QDialogButtonBox.AcceptRole)
+                                         QDialogButtonBox.ButtonRole.AcceptRole)
         self.compressbtn.setEnabled(False)
         self.compressbtn.clicked.connect(self.compress)
         self.layout().addWidget(cmd)
