@@ -240,8 +240,8 @@ class SummaryInfo(object):
                 if cvt.startswith(b'svn:'):
                     result = cvt.split(b'/', 1)[-1]
                     if cvt != result:
-                        return hglib.tounicode(result)
-                    return hglib.tounicode(cvt.split(b'@')[-1])
+                        return pycompat.unicode(result, 'utf-8', 'replace')
+                    return pycompat.unicode(cvt.split(b'@')[-1], 'utf-8', 'replace')
                 else:
                     return None
             elif item == 'converted':
@@ -312,8 +312,7 @@ class SummaryInfo(object):
             elif item in ('revnum', 'p4', 'close', 'converted'):
                 return str(value)
             elif item == 'svn':
-                # svn is always in utf-8 because ctx.extra() isn't converted
-                return pycompat.unicode(value, 'utf-8', 'replace')
+                return value
             elif item in ('rawbranch', 'branch'):
                 opts = dict(fg='black', bg='#aaffaa')
                 return qtlib.markup(' %s ' % value, **opts)
@@ -448,23 +447,23 @@ class SummaryPanel(SummaryBase, QWidget):
         if self.revlabel is None:
             self.revlabel = QLabel()
             self.revlabel.linkActivated.connect(self.linkActivated)
-            layout.addWidget(self.revlabel, 0, Qt.AlignTop)
+            layout.addWidget(self.revlabel, 0, Qt.AlignmentFlag.AlignTop)
 
         if 'expandable' in self.csstyle and self.csstyle['expandable']:
             if self.expand_btn.parentWidget() is None:
                 self.expand_btn.clicked.connect(lambda: self.update())
                 margin = QHBoxLayout()
                 margin.setContentsMargins(3, 3, 3, 3)
-                margin.addWidget(self.expand_btn, 0, Qt.AlignTop)
+                margin.addWidget(self.expand_btn, 0, Qt.AlignmentFlag.AlignTop)
                 layout.insertLayout(0, margin)
             self.expand_btn.setVisible(True)
         elif self.expand_btn.parentWidget() is not None:
             self.expand_btn.setHidden(True)
 
-        interact = Qt.LinksAccessibleByMouse
+        interact = Qt.TextInteractionFlag.LinksAccessibleByMouse
 
         if 'selectable' in self.csstyle and self.csstyle['selectable']:
-            interact |= Qt.TextBrowserInteraction
+            interact |= Qt.TextInteractionFlag.TextBrowserInteraction
 
         self.revlabel.setTextInteractionFlags(interact)
 
@@ -525,7 +524,7 @@ class SummaryLabel(SummaryBase, QLabel):
 
         if 'selectable' in self.csstyle:
             sel = self.csstyle['selectable']
-            val = sel and Qt.TextSelectableByMouse or Qt.TextBrowserInteraction
+            val = sel and Qt.TextInteractionFlag.TextSelectableByMouse or Qt.TextInteractionFlag.TextBrowserInteraction
             self.setTextInteractionFlags(val)
 
         if 'width' in self.csstyle:
