@@ -333,9 +333,9 @@ class HooksFrame(QFrame):
         self.setLayout(topbox)
         self.hooktable = QTableWidget(0, 3, parent)
         self.hooktable.setHorizontalHeaderLabels((_('Type'), _('Name'), _('Command')))
-        self.hooktable.sortByColumn(0, Qt.AscendingOrder)
-        self.hooktable.setSelectionBehavior(self.hooktable.SelectRows)
-        self.hooktable.setSelectionMode(self.hooktable.SingleSelection)
+        self.hooktable.sortByColumn(0, Qt.SortOrder.AscendingOrder)
+        self.hooktable.setSelectionBehavior(QTableWidget.SelectionBehavior.SelectRows)
+        self.hooktable.setSelectionMode(QTableWidget.SelectionMode.SingleSelection)
         self.hooktable.cellDoubleClicked.connect(self.editHook)
         topbox.addWidget(self.hooktable)
         buttonbox = QVBoxLayout()
@@ -384,7 +384,7 @@ class HooksFrame(QFrame):
                 self.hooktable.setItem(row, c, QTableWidgetItem(text))
             # Make the hook column not editable (a dialog is used to edit it)
             itemhook = self.hooktable.item(row, 0)
-            itemhook.setFlags(itemhook.flags() & ~Qt.ItemIsEditable)
+            itemhook.setFlags(itemhook.flags() & ~Qt.ItemFlag.ItemIsEditable)
             self.hooktable.setSortingEnabled(True)
             self.hooktable.resizeColumnsToContents()
             self.updatebuttons()
@@ -416,7 +416,7 @@ class HooksFrame(QFrame):
             self.hooktable.item(r, 2).setText(command)
             self.hooktable.setSortingEnabled(True)
             self.hooktable.clearSelection()
-            self.hooktable.setState(self.hooktable.NoState)
+            self.hooktable.setState(QTableWidget.State.NoState)
             self.hooktable.resizeColumnsToContents()
         return bool(res)
 
@@ -530,7 +530,7 @@ class HooksFrame(QFrame):
                 itemhook = QTableWidgetItem(hglib.tounicode(hooktype))
                 # Make the hook column not editable
                 # (a dialog is used to edit it)
-                itemhook.setFlags(itemhook.flags() & ~Qt.ItemIsEditable)
+                itemhook.setFlags(itemhook.flags() & ~Qt.ItemFlag.ItemIsEditable)
                 itemname = QTableWidgetItem(hglib.tounicode(name))
                 itemtool = QTableWidgetItem(
                     hglib.tounicode(hooks[hooktype][name]))
@@ -561,8 +561,8 @@ class ToolListBox(QListWidget):
 
         # Enable drag and drop to reorder the tools
         self.setDragEnabled(True)
-        self.setDragDropMode(self.InternalMove)
-        self.setDefaultDropAction(Qt.MoveAction)
+        self.setDragDropMode(QListWidget.DragDropMode.InternalMove)
+        self.setDefaultDropAction(Qt.DropAction.MoveAction)
 
     def _guidef2toollist(self, guidef):
         toollist = []
@@ -660,7 +660,7 @@ class CustomConfigDialog(QDialog):
     def __init__(self, parent=None, dialogname='', **kwargs):
         QDialog.__init__(self, parent, **kwargs)
         self.dialogname = dialogname
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self.hbox = QHBoxLayout()
         self.formvbox = QFormLayout()
@@ -695,7 +695,7 @@ class CustomConfigDialog(QDialog):
             combo.setCurrentIndex(index)
         if tooltips:
             for idx, tooltip in enumerate(tooltips):
-                combo.setItemData(idx, tooltip, Qt.ToolTipRole)
+                combo.setItemData(idx, tooltip, Qt.ItemDataRole.ToolTipRole)
         return combo
 
     def _addConfigItem(self, parent, label, configwidget, tooltip=None):
