@@ -53,7 +53,7 @@ class _LogWidgetForConsole(cmdui.LogWidget):
 
     def __init__(self, parent=None):
         super(_LogWidgetForConsole, self).__init__(parent)
-        self._prompt_marker = self.markerDefine(QsciScintilla.Background)
+        self._prompt_marker = self.markerDefine(QsciScintilla.MarkerSymbol.Background)
         self.setMarkerBackgroundColor(QColor('#e8f3fe'), self._prompt_marker)
         self.cursorPositionChanged.connect(self._updatePrompt)
         # ensure not moving prompt line even if completion list get shorter,
@@ -70,16 +70,16 @@ class _LogWidgetForConsole(cmdui.LogWidget):
     def keyPressEvent(self, event):
         cursoronprompt = not self.isReadOnly()
         if cursoronprompt:
-            if event.key() == Qt.Key_Up:
+            if event.key() == Qt.Key.Key_Up:
                 return self.historyRequested.emit(self.commandText(), -1)
-            elif event.key() == Qt.Key_Down:
+            elif event.key() == Qt.Key.Key_Down:
                 return self.historyRequested.emit(self.commandText(), +1)
             del self._savedcommands[:]  # settle candidate by user input
-            if event.key() in (Qt.Key_Return, Qt.Key_Enter):
+            if event.key() in (Qt.Key.Key_Return, Qt.Key.Key_Enter):
                 return self.returnPressed.emit(self.commandText())
-            if event.key() == Qt.Key_Tab:
+            if event.key() == Qt.Key.Key_Tab:
                 return self.completeRequested.emit(self.commandText())
-        if event.key() == Qt.Key_Escape:
+        if event.key() == Qt.Key.Key_Escape:
             # When ESC is pressed, if the cursor is on the prompt,
             # this clears it, if not, this moves the cursor to the prompt
             self.setCommandText('')
@@ -416,18 +416,18 @@ class ConsoleWidget(QWidget, qtlib.TaskWidget):
         extproc = QProcess(self)
         extproc.started.connect(self.closePrompt)
         extproc.finished.connect(self.openPrompt)
-        extproc.error.connect(self._handleExtprocError)
+        extproc.errorOccurred.connect(self._handleExtprocError)
         extproc.readyReadStandardOutput.connect(self._appendExtprocStdout)
         extproc.readyReadStandardError.connect(self._appendExtprocStderr)
         return extproc
 
     @pyqtSlot()
     def _handleExtprocError(self):
-        if self._extproc.state() == QProcess.NotRunning:
+        if self._extproc.state() == QProcess.ProcessState.NotRunning:
             self._logwidget.closePrompt()
         msg = self._extproc.errorString()
         self._logwidget.appendLog(msg + '\n', 'ui.error')
-        if self._extproc.state() == QProcess.NotRunning:
+        if self._extproc.state() == QProcess.ProcessState.NotRunning:
             self._logwidget.openPrompt()
 
     @pyqtSlot()
@@ -495,7 +495,7 @@ class ConsoleWidget(QWidget, qtlib.TaskWidget):
 
     def _runextcommand(self, cmdline):
         self._extproc.setWorkingDirectory(self._workingDirectory())
-        self._extproc.start(cmdline, QIODevice.ReadOnly)
+        self._extproc.start(cmdline, QIODevice.OpenModeFlag.ReadOnly)
 
     def _cmd_hg(self, args):
         self.closePrompt()
@@ -533,12 +533,12 @@ class LogDockWidget(QDockWidget):
     def __init__(self, repomanager, cmdagent, parent=None):
         super(LogDockWidget, self).__init__(parent)
 
-        self.setFeatures(QDockWidget.DockWidgetClosable |
-                         QDockWidget.DockWidgetMovable  |
-                         QDockWidget.DockWidgetFloatable)
+        self.setFeatures(QDockWidget.DockWidgetFeature.DockWidgetClosable |
+                         QDockWidget.DockWidgetFeature.DockWidgetMovable  |
+                         QDockWidget.DockWidgetFeature.DockWidgetFloatable)
         self.setWindowTitle(_('Console'))
         # Not enabled until we have a way to make it configurable
-        #self.setWindowFlags(Qt.Drawer)
+        #self.setWindowFlags(Qt.WindowType.Drawer)
         self.dockLocationChanged.connect(self._updateTitleBarStyle)
 
         self._repomanager = repomanager
@@ -591,8 +591,8 @@ class LogDockWidget(QDockWidget):
     @pyqtSlot(Qt.DockWidgetArea)
     def _updateTitleBarStyle(self, area):
         f = self.features()
-        if area & (Qt.TopDockWidgetArea | Qt.BottomDockWidgetArea):
-            f |= QDockWidget.DockWidgetVerticalTitleBar  # saves vertical space
+        if area & (Qt.DockWidgetArea.TopDockWidgetArea | Qt.DockWidgetArea.BottomDockWidgetArea):
+            f |= QDockWidget.DockWidgetFeature.DockWidgetVerticalTitleBar  # saves vertical space
         else:
-            f &= ~QDockWidget.DockWidgetVerticalTitleBar
+            f &= ~QDockWidget.DockWidgetFeature.DockWidgetVerticalTitleBar
         self.setFeatures(f)
