@@ -12,6 +12,19 @@ from __future__ import absolute_import
 import os
 import re
 
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Text,
+    Tuple,
+    Type,
+    TypeVar,
+    cast,
+)
+
 from .qtcore import (
     QDir,
     QMimeData,
@@ -29,6 +42,7 @@ from .qtgui import (
 )
 
 from mercurial import (
+    context,
     pycompat,
 )
 
@@ -48,49 +62,85 @@ from . import (
     visdiff,
 )
 
-def _lcanonpaths(fds):
+
+if hglib.TYPE_CHECKING:
+    from mercurial import (
+        localrepo,
+        ui as uimod,
+    )
+    from .cmdcore import CmdSession
+    from .filedata import _AbstractFileData
+    from .thgrepo import RepoAgent
+    from ..util.typelib import HgContext
+    FileData = _AbstractFileData
+
+_ActionTableEntry = Tuple[Text, Optional[Text], Optional[Text], Text,
+                          Tuple["_FileDataFilter", ...]]
+_ActionTable = Dict[Text, _ActionTableEntry]
+
+# The filter function type to reduce the list of input FileData entries.
+_FileDataFilter = Callable[[List["FileData"]], List["FileData"]]
+
+_MenuActionEntry = Tuple[QAction, Tuple[_FileDataFilter, ...]]
+
+_W = TypeVar('_W', bound=QWidget)
+
+
+def _lcanonpaths(fds: List["FileData"]) -> List[bytes]:
     return [hglib.fromunicode(e.canonicalFilePath()) for e in fds]
 
 # predicates to filter files
-def _anydeleted(fds):
-    if any(e.rev() is None and e.rawContext().deleted() for e in fds):
+def _anydeleted(fds: List["FileData"]) -> List["FileData"]:
+    if any(
+        e.rev() is None and cast(context.workingctx, e.rawContext()).deleted()
+        for e in fds
+    ):
         return fds
     return []
-def _committed(fds):
+def _committed(fds: List["FileData"]) -> List["FileData"]:
+    # pytype: disable=unsupported-operands
     return [e for e in fds if e.rev() is not None and e.rev() >= 0]
-def _filepath(pat):
+    # pytype: enable=unsupported-operands
+
+def _filepath(pat: Text) -> _FileDataFilter:
     patre = re.compile(pat)
     return lambda fds: [e for e in fds if patre.search(e.filePath())]
-def _filestatus(s):
+def _filestatus(s: Text) -> _FileDataFilter:
     s = frozenset(s)
     # include directory since its status is unknown
     return lambda fds: [e for e in fds if e.isDir() or e.fileStatus() in s]
-def _indirectbaserev(fds):
+def _indirectbaserev(fds: List["FileData"]) -> List["FileData"]:
     return [e for e in fds if e.baseRev() not in e.parentRevs()]
-def _isdir(fds):
+def _isdir(fds: List["FileData"]) -> List["FileData"]:
     return [e for e in fds if e.isDir()]
-def _isfile(fds):
+def _isfile(fds: List["FileData"]) -> List["FileData"]:
     return [e for e in fds if not e.isDir()]
-def _merged(fds):
+def _merged(fds: List["FileData"]) -> List["FileData"]:
     return [e for e in fds if len(e.rawContext().parents()) > 1]
-def _mergestatus(s):
+def _mergestatus(s: Text) -> _FileDataFilter:
     s = frozenset(s)
     # include directory since its status is unknown
     return lambda fds: [e for e in fds if e.isDir() or e.mergeStatus() in s]
-def _notpatch(fds):
+def _notpatch(fds: List["FileData"]) -> List["FileData"]:
+    # pytype: disable=unsupported-operands
     return [e for e in fds if e.rev() is None or e.rev() >= 0]
-def _notsubrepo(fds):
+    # pytype: enable=unsupported-operands
+
+def _notsubrepo(fds: List["FileData"]) -> List["FileData"]:
     return [e for e in fds if not e.repoRootPath() and not e.subrepoType()]
-def _notsubroot(fds):
+def _notsubroot(fds: List["FileData"]) -> List["FileData"]:
     return [e for e in fds if not e.subrepoType()]
-def _single(fds):
+def _single(fds: List["FileData"]) -> List["FileData"]:
     if len(fds) != 1:
         return []
     return fds
-def _subrepotype(t):
+def _subrepotype(t: Text) -> _FileDataFilter:
     return lambda fds: [e for e in fds if e.subrepoType() == t]
 
-def _filterby(fdfilters, fds):
+def _filterby(
+    fdfilters: Tuple[_FileDataFilter, ...],
+    fds: List["FileData"]
+) -> List["FileData"]:
     for f in fdfilters:
         if not fds:
             return []
@@ -127,24 +177,28 @@ class FilectxActions(QObject):
     """Ask the repowidget to change its revset filter"""
     runCustomCommandRequested = pyqtSignal(str, list)
 
-    _actiontable = {}
+    _actiontable: _ActionTable = {}
     actionSlot = _tablebuilder(_actiontable)
 
-    def __init__(self, repoagent, parent):
+    def __init__(
+        self,
+        repoagent: "RepoAgent",
+        parent: QWidget,
+    ) -> None:
         super(FilectxActions, self).__init__(parent)
         if not isinstance(parent, QWidget):
             raise ValueError('parent must be a QWidget')
 
         self._repoagent = repoagent
-        self._cmdsession = cmdcore.nullCmdSession()
-        self._selfds = []
+        self._cmdsession: "CmdSession" = cmdcore.nullCmdSession()
+        self._selfds: List["FileData"] = []
 
         self._nav_dialogs = qtlib.DialogKeeper(FilectxActions._createnavdialog,
                                                FilectxActions._gennavdialogkey,
                                                self)
 
-        self._actions = {}
-        self._customactions = {}
+        self._actions: Dict[Text, _MenuActionEntry] = {}
+        self._customactions: Dict[Text, _MenuActionEntry] = {}
         for name, d in self._actiontable.items():
             desc, icon, key, tip, fdfilters = d
             # QAction must be owned by QWidget; otherwise statusTip for context
@@ -163,7 +217,7 @@ class FilectxActions(QObject):
         self._initAdditionalActions()
         self._updateActions()
 
-    def _initAdditionalActions(self):
+    def _initAdditionalActions(self) -> None:
         # override to add actions that cannot be declared as actionSlot
         pass
 
@@ -174,17 +228,17 @@ class FilectxActions(QObject):
         return p
 
     @property
-    def _ui(self):
+    def _ui(self) -> "uimod.ui":
         repo = self._repoagent.rawRepo()
         return repo.ui
 
-    def _repoAgentFor(self, fd):
+    def _repoAgentFor(self, fd: "FileData") -> "RepoAgent":
         rpath = fd.repoRootPath()
         if not rpath:
             return self._repoagent
         return self._repoagent.subRepoAgent(rpath)
 
-    def _updateActions(self):
+    def _updateActions(self) -> None:
         idle = self._cmdsession.isFinished()
         selfds = self._selfds
         allactions = (list(self._actions.values())
@@ -192,47 +246,51 @@ class FilectxActions(QObject):
         for act, fdfilters in allactions:
             act.setEnabled(idle and bool(_filterby(fdfilters, selfds)))
 
-    def fileDataListForAction(self, name):
+    def fileDataListForAction(self, name: Text) -> List["FileData"]:
         fdfilters = self._actions[name][1]
         return _filterby(fdfilters, self._selfds)
 
-    def setFileDataList(self, selfds):
+    def setFileDataList(self, selfds: List["FileData"]) -> None:
         self._selfds = list(selfds)
         self._updateActions()
 
-    def actions(self):
+    def actions(self) -> List[QAction]:
         """List of the actions; The owner widget should register them"""
         return [a for a, _f in self._actions.values()]
 
-    def action(self, name):
+    def action(self, name: Text) -> QAction:
         return self._actions[name][0]
 
-    def _addAction(self, name, action, fdfilters):
+    def _addAction(
+        self, name: Text,
+        action: QAction,
+        fdfilters: Tuple[_FileDataFilter, ...]
+    ) -> None:
         assert name not in self._actions, name
         self._actions[name] = action, fdfilters
 
-    def _runCommand(self, cmdline):
+    def _runCommand(self, cmdline: List[Text]) -> "CmdSession":
         if not self._cmdsession.isFinished():
             return cmdcore.nullCmdSession()
-        sess = self._repoagent.runCommand(cmdline, self)
+        sess = self._repoagent.runCommand(cmdline, self._parentWidget())
         self._handleNewCommand(sess)
         return sess
 
-    def _runCommandSequence(self, cmdlines):
+    def _runCommandSequence(self, cmdlines: List[List[Text]]) -> "CmdSession":
         if not self._cmdsession.isFinished():
             return cmdcore.nullCmdSession()
-        sess = self._repoagent.runCommandSequence(cmdlines, self)
+        sess = self._repoagent.runCommandSequence(cmdlines, self._parentWidget())
         self._handleNewCommand(sess)
         return sess
 
-    def _handleNewCommand(self, sess):
+    def _handleNewCommand(self, sess: "CmdSession") -> None:
         assert self._cmdsession.isFinished()
         self._cmdsession = sess
         sess.commandFinished.connect(self._onCommandFinished)
         self._updateActions()
 
     @pyqtSlot(int)
-    def _onCommandFinished(self, ret):
+    def _onCommandFinished(self, ret: int) -> None:
         if ret == 255:
             cmdui.errorMessageBox(self._cmdsession, self._parentWidget())
         self._updateActions()
@@ -240,7 +298,7 @@ class FilectxActions(QObject):
     @actionSlot(_('File &History / Annotate'), 'hg-log', 'Shift+Return',
                 _('Show the history of the selected file'),
                 (_isfile, _notpatch, _filestatus('MARC!')))
-    def navigateFileLog(self, fds):
+    def navigateFileLog(self, fds: List["FileData"]) -> None:
         from tortoisehg.hgqt import filedialogs, fileview
         for fd in fds:
             dlg = self._navigate(filedialogs.FileLogDialog, fd)
@@ -251,12 +309,16 @@ class FilectxActions(QObject):
     @actionSlot(_('Co&mpare File Revisions'), 'compare-files', None,
                 _('Compare revisions of the selected file'),
                 (_isfile, _notpatch))
-    def navigateFileDiff(self, fds):
+    def navigateFileDiff(self, fds: List["FileData"]) -> None:
         from tortoisehg.hgqt import filedialogs
         for fd in fds:
             self._navigate(filedialogs.FileDiffDialog, fd)
 
-    def _navigate(self, dlgclass, fd):
+    def _navigate(
+        self,
+        dlgclass: Type[_W],
+        fd: "FileData"
+    ) -> Optional[_W]:
         repoagent = self._repoAgentFor(fd)
         repo = repoagent.rawRepo()
         filename = hglib.fromunicode(fd.canonicalFilePath())
@@ -265,43 +327,57 @@ class FilectxActions(QObject):
             dlg.goto(fd.rev())
             return dlg
 
-    def _createnavdialog(self, dlgclass, repoagent, filename):
+    def _createnavdialog(
+        self,
+        dlgclass: Type[_W],
+        repoagent: "RepoAgent",
+        filename: bytes,
+    ) -> _W:
         return dlgclass(repoagent, filename)
 
-    def _gennavdialogkey(self, dlgclass, repoagent, filename):
+    def _gennavdialogkey(
+        self,
+        dlgclass: Type[_W],
+        repoagent: "RepoAgent",
+        filename: bytes,
+    ) -> Tuple[Type[_W], bytes]:
         repo = repoagent.rawRepo()
         return dlgclass, repo.wjoin(filename)
 
     @actionSlot(_('Filter Histor&y'), 'hg-log', None,
                 _('Query about changesets affecting the selected files'),
                 _notsubrepo)
-    def filterFile(self, fds):
+    def filterFile(self, fds: List["FileData"]) -> None:
         pats = ["file('path:%s')" % e.filePath() for e in fds]
         self.filterRequested.emit(' or '.join(pats))
 
     @actionSlot(_('Diff &Changeset to Parent'), 'visualdiff', None, '',
                 _notpatch)
-    def visualDiff(self, fds):
+    def visualDiff(self, fds: List["FileData"]) -> None:
         self._visualDiffToBase(fds[0], [])
 
     @actionSlot(_('Diff Changeset to Loc&al'), 'ldiff', None, '',
                 _committed)
-    def visualDiffToLocal(self, fds):
+    def visualDiffToLocal(self, fds: List["FileData"]) -> None:
         self._visualDiff(fds[0], [], rev=['rev(%d)' % fds[0].rev()])
 
     @actionSlot(_('&Diff to Parent'), 'visualdiff', 'Ctrl+D',
                 _('View file changes in external diff tool'),
                 (_notpatch, _notsubroot, _filestatus('MAR!')))
-    def visualDiffFile(self, fds):
+    def visualDiffFile(self, fds: List["FileData"]) -> None:
         self._visualDiffToBase(fds[0], fds)
 
     @actionSlot(_('Diff to &Local'), 'ldiff', 'Shift+Ctrl+D',
                 _('View changes to current in external diff tool'),
                 _committed)
-    def visualDiffFileToLocal(self, fds):
+    def visualDiffFileToLocal(self, fds: List["FileData"]) -> None:
         self._visualDiff(fds[0], fds, rev=['rev(%d)' % fds[0].rev()])
 
-    def _visualDiffToBase(self, an_fd, fds):
+    def _visualDiffToBase(
+        self,
+        an_fd: "FileData",
+        fds: List["FileData"],
+    ) -> None:
         if an_fd.baseRev() == an_fd.parentRevs()[0]:
             self._visualDiff(an_fd, fds, change=an_fd.rev())  # can 3-way
         else:
@@ -310,7 +386,12 @@ class FilectxActions(QObject):
                 revs.append(an_fd.rev())
             self._visualDiff(an_fd, fds, rev=['rev(%d)' % r for r in revs])
 
-    def _visualDiff(self, an_fd, fds, **opts):
+    def _visualDiff(
+        self,
+        an_fd: "FileData",
+        fds: List["FileData"],
+        **opts,
+    ) -> None:
         filenames = _lcanonpaths(fds)
         repo = self._repoAgentFor(an_fd).rawRepo()
         dlg = visdiff.visualdiff(repo.ui, repo, filenames, opts)
@@ -321,10 +402,10 @@ class FilectxActions(QObject):
                 _('View file as it appeared at this revision using the '
                   'visual editor'),
                 _committed)
-    def editFile(self, fds):
+    def editFile(self, fds: List["FileData"]) -> None:
         self._editFileAt(fds, fds[0].rawContext())
 
-    def _editFileAt(self, fds, ctx):
+    def _editFileAt(self, fds: List["FileData"], ctx: "HgContext") -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         filenames = _lcanonpaths(fds)
         base, _ = visdiff.snapshot(repo, filenames, ctx)
@@ -336,10 +417,10 @@ class FilectxActions(QObject):
                 _("Open file as it appeared at this revision using the "
                   "system's default application for this file type"),
                 _committed)
-    def openFile(self, fds):
+    def openFile(self, fds: List["FileData"]) -> None:
         self._openFileAt(fds, fds[0].rawContext())
 
-    def _openFileAt(self, fds, ctx):
+    def _openFileAt(self, fds: List["FileData"], ctx: "HgContext") -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         filenames = _lcanonpaths(fds)
         base, _ = visdiff.snapshot(repo, filenames, ctx)
@@ -351,7 +432,7 @@ class FilectxActions(QObject):
     @actionSlot(_('&Save at Revision...'), None, 'Shift+Ctrl+S',
                 _('Save file as it appeared at this revision'),
                 _committed)
-    def saveFile(self, fds):
+    def saveFile(self, fds: List["FileData"]) -> None:
         cmdlines = []
         for fd in fds:
             wfile, ext = os.path.splitext(fd.absoluteFilePath())
@@ -377,7 +458,7 @@ class FilectxActions(QObject):
                 _('Edit current file(s) in working copy with the visual '
                   'editor'),
                 (_isfile, _filestatus('MACI?')))
-    def editLocalFile(self, fds):
+    def editLocalFile(self, fds: List["FileData"]) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         filenames = _lcanonpaths(fds)
         qtlib.editfiles(repo, filenames, parent=self._parentWidget())
@@ -386,7 +467,7 @@ class FilectxActions(QObject):
                 _("Open current file(s) in working copy with the system's "
                   "default application for this file type"),
                 (_isfile, _filestatus('MACI?')))
-    def openLocalFile(self, fds):
+    def openLocalFile(self, fds: List["FileData"]) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         for fd in fds:
             qtlib.openlocalurl(fd.absoluteFilePath())
@@ -395,13 +476,13 @@ class FilectxActions(QObject):
                 _('Open parent folder of current file in the system file '
                   'manager'),
                 (_isfile, _filestatus('MACI?')))
-    def exploreLocalFile(self, fds):
+    def exploreLocalFile(self, fds: List["FileData"]) -> None:
         for fd in fds:
             qtlib.openlocalurl(os.path.dirname(fd.absoluteFilePath()))
 
     @actionSlot(_('&Copy Patch'), 'copy-patch', None, '',
                 (_notpatch, _notsubroot, _filestatus('MAR!')))
-    def copyPatch(self, fds):
+    def copyPatch(self, fds: List["FileData"]) -> None:
         paths = [hglib.escapepath(fd.filePath()) for fd in fds]
         revs = pycompat.maplist(hglib.escaperev,
                                 [fds[0].baseRev(), fds[0].rev()])
@@ -411,7 +492,7 @@ class FilectxActions(QObject):
         sess.commandFinished.connect(self._copyPatchOutputToClipboard)
 
     @pyqtSlot(int)
-    def _copyPatchOutputToClipboard(self, ret):
+    def _copyPatchOutputToClipboard(self, ret: int) -> None:
         if ret != 0:
             return
         output = self._cmdsession.readAll()
@@ -422,20 +503,20 @@ class FilectxActions(QObject):
 
     @actionSlot(_('Copy Absolute &Path'), None, 'Shift+Ctrl+C',
                 _('Copy full path of file(s) to the clipboard'))
-    def copyPath(self, fds):
+    def copyPath(self, fds: List["FileData"]) -> None:
         paths = [e.absoluteFilePath() for e in fds]
         QApplication.clipboard().setText(os.linesep.join(paths))
 
     @actionSlot(_('Copy Relative Path'), None, None,
                 _('Copy repository relative path of file(s) to the clipboard'))
-    def copyRelativePath(self, fds):
+    def copyRelativePath(self, fds: List["FileData"]) -> None:
         paths = [QDir.toNativeSeparators(e.filePath()) for e in fds]
         QApplication.clipboard().setText(os.linesep.join(paths))
 
     @actionSlot(_('&Revert to Revision...'), 'hg-revert', 'Shift+Ctrl+R',
                 _('Revert file(s) to contents at this revision'),
                 _notpatch)
-    def revertFile(self, fds):
+    def revertFile(self, fds: List["FileData"]) -> None:
         repoagent = self._repoAgentFor(fds[0])
         fileSelection = [e.canonicalFilePath() for e in fds]
         rev = fds[0].rev()
@@ -449,7 +530,7 @@ class FilectxActions(QObject):
     @actionSlot(_('Open S&ubrepository'), 'thg-repository-open', None,
                 _('Open the selected subrepository'),
                 _subrepotype('hg'))
-    def openSubrepo(self, fds):
+    def openSubrepo(self, fds: List["FileData"]) -> None:
         for fd in fds:
             if fd.rev() is None:
                 link = 'repo:%s' % fd.absoluteFilePath()
@@ -463,20 +544,20 @@ class FilectxActions(QObject):
     @actionSlot(_('E&xplore Folder'), 'system-file-manager', None,
                 _('Open the selected folder in the system file manager'),
                 _isdir)
-    def explore(self, fds):
+    def explore(self, fds: List["FileData"]) -> None:
         for fd in fds:
             qtlib.openlocalurl(fd.absoluteFilePath())
 
     @actionSlot(_('Open &Terminal'), 'utilities-terminal', None,
                 _('Open a shell terminal in the selected folder'),
                 _isdir)
-    def terminal(self, fds):
+    def terminal(self, fds: List["FileData"]) -> None:
         for fd in fds:
             root = hglib.fromunicode(fd.absoluteFilePath())
             currentfile = hglib.fromunicode(fd.filePath())
             qtlib.openshell(root, currentfile, self._ui)
 
-    def setupCustomToolsMenu(self, location):
+    def setupCustomToolsMenu(self, location: Text) -> None:
         tools, toollist = hglib.tortoisehgtools(self._ui, location)
         submenu = QMenu(_('Custom Tools'), self._parentWidget())
         submenu.triggered.connect(self._runCustomCommandByMenu)
@@ -493,6 +574,7 @@ class FilectxActions(QObject):
             label = info.get('label', name)
             icon = info.get('icon', customtools.DEFAULTICONNAME)
             status = info.get('status')
+            assert isinstance(label, str)  # help pytype
             a = submenu.addAction(label)
             a.setData(name)
             if icon:
@@ -507,7 +589,7 @@ class FilectxActions(QObject):
         self._updateActions()
 
     @pyqtSlot(QAction)
-    def _runCustomCommandByMenu(self, action):
+    def _runCustomCommandByMenu(self, action: QAction) -> None:
         name = str(action.data())
         fdfilters = self._customactions[name][1]
         fds = _filterby(fdfilters, self._selfds)
@@ -520,10 +602,10 @@ class WctxActions(FilectxActions):
 
     refreshNeeded = pyqtSignal()
 
-    _actiontable = FilectxActions._actiontable.copy()
+    _actiontable: _ActionTable = FilectxActions._actiontable.copy()
     actionSlot = _tablebuilder(_actiontable)
 
-    def _initAdditionalActions(self):
+    def _initAdditionalActions(self) -> None:
         repo = self._repoagent.rawRepo()
         # the same shortcut as editFile that is disabled for working rev
         a = self.action('editLocalFile')
@@ -535,10 +617,15 @@ class WctxActions(FilectxActions):
         self._addAction('remergeFileMenu', *self._createRemergeFileMenu())
 
     @property
-    def repo(self):
+    def repo(self) -> "localrepo.localrepository":
         return self._repoagent.rawRepo()
 
-    def _runWorkingFileCommand(self, cmdname, fds, opts=None):
+    def _runWorkingFileCommand(
+        self,
+        cmdname: Text,
+        fds: List["FileData"],
+        opts: Optional[Dict[Text, Any]]=None,
+    ) -> "CmdSession":
         if not opts:
             opts = {}
         paths = [hglib.escapepath(fd.filePath()) for fd in fds]
@@ -548,11 +635,11 @@ class WctxActions(FilectxActions):
         return sess
 
     @pyqtSlot(int)
-    def _notifyChangesOnCommandFinished(self, ret):
+    def _notifyChangesOnCommandFinished(self, ret: int) -> None:
         if ret == 0:
             self._notifyChanges()
 
-    def _notifyChanges(self):
+    def _notifyChanges(self) -> None:
         # include all selected files for maximum possibility
         wfiles = [hglib.fromunicode(fd.absoluteFilePath())
                   for fd in self._selfds]
@@ -563,31 +650,31 @@ class WctxActions(FilectxActions):
     # base revision in amend/qrefresh mode
     @actionSlot(_('Diff &Local'), 'ldiff', 'Ctrl+Shift+D', '',
                 (_indirectbaserev, _notsubroot, _filestatus('MARC!')))
-    def visualDiffLocalFile(self, fds):
+    def visualDiffLocalFile(self, fds: List["FileData"]) -> None:
         self._visualDiff(fds[0], fds)
 
     @actionSlot(_('&View Missing'), None, None, '',
                 (_isfile, _filestatus('R!')))
-    def editMissingFile(self, fds):
+    def editMissingFile(self, fds: List["FileData"]) -> None:
         wctx = fds[0].rawContext()
         self._editFileAt(fds, wctx.p1())
 
     @actionSlot(_('View O&ther'), None, None, '',
                 (_isfile, _merged, _filestatus('MA')))
-    def editOtherFile(self, fds):
+    def editOtherFile(self, fds: List["FileData"]) -> None:
         wctx = fds[0].rawContext()
         self._editFileAt(fds, wctx.p2())
 
     @actionSlot(_('&Add'), 'hg-add', None, '',
                 (_notsubroot, _filestatus('RI?')))
-    def addFile(self, fds):
+    def addFile(self, fds: List["FileData"]) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         if b'largefiles' in repo.extensions():
             self._addFileWithPrompt(fds)
         else:
             self._runWorkingFileCommand('add', fds)
 
-    def _addFileWithPrompt(self, fds):
+    def _addFileWithPrompt(self, fds: List["FileData"]) -> None:
         repo = self._repoAgentFor(fds[0]).rawRepo()
         result = lfprompt.promptForLfiles(self._parentWidget(), repo.ui, repo,
                                           _lcanonpaths(fds))
@@ -604,17 +691,17 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('Add &Largefiles...'), None, None, '',
                 (_notsubroot, _filestatus('I?')))
-    def addLargefile(self, fds):
+    def addLargefile(self, fds: List["FileData"]) -> None:
         self._runWorkingFileCommand('add', fds, {'large': True})
 
     @actionSlot(_('&Forget'), 'hg-remove', None, '',
                 (_notsubroot, _filestatus('MAC!')))
-    def forgetFile(self, fds):
+    def forgetFile(self, fds: List["FileData"]) -> None:
         self._runWorkingFileCommand('forget', fds)
 
     @actionSlot(_('&Delete Unversioned...'), 'hg-purge', 'Delete', '',
                 (_notsubroot, _filestatus('?I')))
-    def purgeFile(self, fds):
+    def purgeFile(self, fds: List["FileData"]) -> None:
         parent = self._parentWidget()
         files = [hglib.fromunicode(fd.filePath()) for fd in fds]
         res = qtlib.CustomPrompt(
@@ -628,15 +715,15 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('Re&move Versioned'), 'hg-remove', None, '',
                 (_notsubroot, _filestatus('C')))
-    def removeFile(self, fds):
+    def removeFile(self, fds: List["FileData"]) -> None:
         self._runWorkingFileCommand('remove', fds)
 
     @actionSlot(_('&Revert...'), 'hg-revert', None, '',
                 _filestatus('MAR!'))
-    def revertWorkingFile(self, fds):
+    def revertWorkingFile(self, fds: List["FileData"]) -> None:
         parent = self._parentWidget()
         files = _lcanonpaths(fds)
-        wctx = fds[0].rawContext()
+        wctx = cast(context.workingctx, fds[0].rawContext())
         revertopts = {'date': None, 'rev': '.', 'all': False}
         if len(wctx.parents()) > 1:
             res = qtlib.CustomPrompt(
@@ -670,15 +757,15 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('&Copy...'), 'edit-copy', None, '',
                 (_single, _isfile, _filestatus('MC')))
-    def copyFile(self, fds):
+    def copyFile(self, fds: List["FileData"]) -> None:
         self._openRenameDialog(fds, iscopy=True)
 
     @actionSlot(_('Re&name...'), 'hg-rename', None, '',
                 (_single, _isfile, _filestatus('MC')))
-    def renameFile(self, fds):
+    def renameFile(self, fds: List["FileData"]) -> None:
         self._openRenameDialog(fds, iscopy=False)
 
-    def _openRenameDialog(self, fds, iscopy):
+    def _openRenameDialog(self, fds: List["FileData"], iscopy: bool) -> None:
         from tortoisehg.hgqt.rename import RenameDialog
         srcfd, = fds
         repoagent = self._repoAgentFor(srcfd)
@@ -689,7 +776,7 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('&Ignore...'), 'thg-ignore', None, '',
                 (_notsubroot, _filestatus('?')))
-    def editHgignore(self, fds):
+    def editHgignore(self, fds: List["FileData"]) -> None:
         from tortoisehg.hgqt.hgignore import HgignoreDialog
         repoagent = self._repoAgentFor(fds[0])
         parent = self._parentWidget()
@@ -702,7 +789,7 @@ class WctxActions(FilectxActions):
     @actionSlot(_('Edit Re&jects'), None, None,
                 _('Manually resolve rejected patch chunks'),
                 (_single, _isfile, _filestatus('?I'), _filepath(r'\.rej$')))
-    def editRejects(self, fds):
+    def editRejects(self, fds: List["FileData"]) -> None:
         lpath = hglib.fromunicode(fds[0].absoluteFilePath()[:-4])  # drop .rej
         dlg = rejects.RejectsDialog(self._ui, lpath, self._parentWidget())
         if dlg.exec_():
@@ -710,7 +797,7 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('De&tect Renames...'), 'thg-guess', None, '',
                 (_isfile, _filestatus('A?!')))
-    def guessRename(self, fds):
+    def guessRename(self, fds: List["FileData"]) -> None:
         from tortoisehg.hgqt.guess import DetectRenameDialog
         repoagent = self._repoAgentFor(fds[0])
         parent = self._parentWidget()
@@ -727,20 +814,20 @@ class WctxActions(FilectxActions):
 
     @actionSlot(_('&Mark Resolved'), None, None, '',
                 (_notsubroot, _mergestatus('U')))
-    def markFileAsResolved(self, fds):
+    def markFileAsResolved(self, fds: List["FileData"]) -> None:
         self._runWorkingFileCommand('resolve', fds, {'mark': True})
 
     @actionSlot(_('&Mark Unresolved'), None, None, '',
                 (_notsubroot, _mergestatus('R')))
-    def markFileAsUnresolved(self, fds):
+    def markFileAsUnresolved(self, fds: List["FileData"]) -> None:
         self._runWorkingFileCommand('resolve', fds, {'unmark': True})
 
     @actionSlot(_('Restart Mer&ge'), None, None, '',
                 (_notsubroot, _mergestatus('U')))
-    def remergeFile(self, fds):
+    def remergeFile(self, fds: List["FileData"]) -> None:
         self._runWorkingFileCommand('resolve', fds)
 
-    def _createRenameFileMenu(self):
+    def _createRenameFileMenu(self) -> _MenuActionEntry:
         menu = QMenu(_('Was renamed from'), self._parentWidget())
         menu.aboutToShow.connect(self._updateRenameFileMenu)
         menu.triggered.connect(self._renameFrom)
@@ -748,7 +835,7 @@ class WctxActions(FilectxActions):
         return menu.menuAction(), fdfilters
 
     @pyqtSlot()
-    def _updateRenameFileMenu(self):
+    def _updateRenameFileMenu(self) -> None:
         menu = self.sender()
         assert isinstance(menu, QMenu), repr(menu)
         menu.clear()
@@ -760,7 +847,7 @@ class WctxActions(FilectxActions):
             menu.addAction(hglib.tounicode(d))
 
     @pyqtSlot(QAction)
-    def _renameFrom(self, action):
+    def _renameFrom(self, action: QAction) -> None:
         fds = self.fileDataListForAction('renameFileMenu')
         if not fds:
             # selection might be changed after menu is shown
@@ -772,14 +859,14 @@ class WctxActions(FilectxActions):
         sess = self._runCommandSequence(cmdlines)
         sess.commandFinished.connect(self._notifyChangesOnCommandFinished)
 
-    def _createRemergeFileMenu(self):
+    def _createRemergeFileMenu(self) -> _MenuActionEntry:
         menu = QMenu(_('Restart Merge &with'), self._parentWidget())
         menu.aboutToShow.connect(self._populateRemergeFileMenu)  # may be slow
         menu.triggered.connect(self._remergeFileWith)
         return menu.menuAction(), (_notsubroot, _mergestatus('U'))
 
     @pyqtSlot()
-    def _populateRemergeFileMenu(self):
+    def _populateRemergeFileMenu(self) -> None:
         menu = self.sender()
         assert isinstance(menu, QMenu), repr(menu)
         menu.aboutToShow.disconnect(self._populateRemergeFileMenu)
@@ -787,6 +874,6 @@ class WctxActions(FilectxActions):
             menu.addAction(hglib.tounicode(tool))
 
     @pyqtSlot(QAction)
-    def _remergeFileWith(self, action):
+    def _remergeFileWith(self, action: QAction) -> None:
         fds = self.fileDataListForAction('remergeFileMenu')
         self._runWorkingFileCommand('resolve', fds, {'tool': action.text()})
