@@ -7,6 +7,17 @@
 
 import os, posixpath
 
+from typing import (
+    List,
+    NoReturn,
+    Optional,
+    Text,
+    Tuple,
+    TypeVar,
+    Union,
+    cast,
+)
+
 from mercurial import (
     commands,
     copies,
@@ -27,12 +38,17 @@ from tortoisehg.util import hglib, patchctx
 from tortoisehg.util.i18n import _
 from tortoisehg.hgqt import fileencoding
 
+_TSubrepoData = TypeVar('_TSubrepoData', bound='SubrepoData')
+_T_AbstractFileData = TypeVar('_T_AbstractFileData', bound='_AbstractFileData')
+
 if hglib.TYPE_CHECKING:
-    from typing import (
-        Any,
-        List,
-        Text,
-        Tuple,
+    from mercurial import (
+        context,
+        localrepo,
+    )
+    from ..util.typelib import (
+        HgContext,
+        ThgContext,
     )
 
 
@@ -41,7 +57,7 @@ forcedisplaymsg = _('Display the file anyway')
 class _BadContent(Exception):
     """Failed to display file because it is binary or size limit exceeded"""
 
-def _exceedsMaxLineLength(data, maxlength=100000):
+def _exceedsMaxLineLength(data: bytes, maxlength: int = 100000) -> bool:
     if len(data) < maxlength:
         return False
     for line in data.splitlines():
@@ -49,7 +65,7 @@ def _exceedsMaxLineLength(data, maxlength=100000):
             return True
     return False
 
-def _checkdifferror(data, maxdiff):
+def _checkdifferror(data: bytes, maxdiff: int) -> Optional[Text]:
     p = _('Diff not displayed: ')
     size = len(data)
     if size > maxdiff:
@@ -61,7 +77,7 @@ def _checkdifferror(data, maxdiff):
         # it's incredibly slow to render long line by QScintilla
         return p + _('File may be binary (maximum line length exceeded)')
 
-def _trimdiffheader(diff):
+def _trimdiffheader(diff: Text) -> Text:
     # trim first three lines, for example:
     # diff -r f6bfc41af6d7 -r c1b18806486d tortoisehg/hgqt/mq.py
     # --- a/tortoisehg/hgqt/mq.py
@@ -76,33 +92,43 @@ def _trimdiffheader(diff):
 
 class _AbstractFileData(object):
 
-    def __init__(self, ctx, ctx2, wfile, status=None, rpath=None):
+    def __init__(
+        self,
+        ctx: "HgContext",
+        ctx2: Optional["HgContext"],
+        wfile: bytes,
+        status: Optional[Text] = None,
+        rpath: Optional[bytes] = None,
+    ) -> None:
         self._ctx = ctx
-        self._pctx = ctx2
+        self._pctx: Optional["HgContext"] = ctx2
         self._wfile = wfile
-        self._status = status
-        self._rpath = rpath or b''
-        self.contents = None
-        self.ucontents = None
-        self.error = None
-        self.olddata = None
-        self.diff = None
-        self.flabel = u''
-        self.elabel = u''
-        self.changes = None
+        self._status: Optional[Text] = status
+        self._rpath: bytes = rpath or b''
+        self.contents: Optional[bytes] = None
+        self.ucontents: Optional[Text] = None
+        self.error: Optional[Text] = None
+        self.olddata: Optional[bytes] = None
+        self.diff: Optional[bytes] = None
+        self.flabel: Text = u''
+        self.elabel: Text = u''
+        self.changes: Optional[patch.header] = None
 
         self._textencoding = fileencoding.contentencoding(ctx.repo().ui)
 
-    def createRebased(self, pctx):
+    def createRebased(
+        self: _T_AbstractFileData,
+        pctx: "HgContext",
+    ) -> _T_AbstractFileData:
         # new status is not known
         return self.__class__(self._ctx, pctx, self._wfile, rpath=self._rpath)
 
-    def load(self, changeselect=False, force=False):
+    def load(self, changeselect: bool = False, force: bool = False) -> NoReturn:
         # Note: changeselect may be set to True even if the underlying data
         # isn't chunk-selectable
         raise NotImplementedError
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         # unlike changectx, this also compares hash in case it was stripped and
         # recreated.  FileData may live longer than changectx in Mercurial.
         return (isinstance(other, self.__class__)
@@ -114,45 +140,45 @@ class _AbstractFileData(object):
                 and self._wfile == other._wfile
                 and self._rpath == other._rpath)
 
-    def __ne__(self, other):
+    def __ne__(self, other: object) -> bool:
         return not self == other
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash((self._ctx, self._ctx.node(),
                      self._pctx, self._pctx is None or self._pctx.node(),
                      self._wfile, self._rpath))
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return '<%s %s@%s>' % (self.__class__.__name__,
                                hglib.tounicode(
                                    posixpath.join(self._rpath, self._wfile)
                                ),
                                self._ctx)
 
-    def isLoaded(self):
+    def isLoaded(self) -> bool:
         loadables = [self.contents, self.ucontents, self.error, self.diff]
         return any(e is not None for e in loadables)
 
-    def isNull(self):
+    def isNull(self) -> bool:
         return self._ctx.rev() == nullrev and not self._wfile
 
-    def isValid(self):
+    def isValid(self) -> bool:
         return self.error is None and not self.isNull()
 
-    def rev(self):
+    def rev(self) -> Optional[int]:
         return self._ctx.rev()
 
-    def baseRev(self):
+    def baseRev(self) -> Optional[int]:  # Optional allows reverse diff from wdir
         return self._pctx.rev()
 
-    def parentRevs(self):
+    def parentRevs(self) -> List[int]:
         # may contain nullrev, which allows "nullrev in parentRevs()"
         return [p.rev() for p in self._ctx.parents()]
 
-    def rawContext(self):
+    def rawContext(self) -> "HgContext":
         return self._ctx
 
-    def rawBaseContext(self):
+    def rawBaseContext(self) -> Optional["HgContext"]:
         return self._pctx
 
     # absoluteFilePath    : "C:\\Documents\\repo\\foo\\subrepo\\bar\\baz"
@@ -161,49 +187,49 @@ class _AbstractFileData(object):
     # filePath         : "foo/subrepo/bar/baz"
     # repoRootPath     : "foo/subrepo"
 
-    def absoluteFilePath(self):
+    def absoluteFilePath(self) -> Text:
         """Absolute file-system path of this file"""
         repo = self._ctx.repo()
         return hglib.tounicode(os.path.normpath(repo.wjoin(self._wfile)))
 
-    def absoluteRepoRootPath(self):
+    def absoluteRepoRootPath(self) -> Text:
         """Absolute file-system path to the root of the container repository"""
         # repo.root should be normalized
         repo = self._ctx.repo()
         return hglib.tounicode(repo.root)
 
-    def canonicalFilePath(self):
+    def canonicalFilePath(self) -> Text:
         """Path relative to the repository root which contains this file"""
         return hglib.tounicode(self._wfile)
 
-    def filePath(self):
+    def filePath(self) -> Text:
         """Path relative to the top repository root in the current context"""
         return hglib.tounicode(posixpath.join(self._rpath, self._wfile))
 
-    def repoRootPath(self):
+    def repoRootPath(self) -> Text:
         """Root path of the container repository relative to the top repository
         in the current context; '' for top repository"""
         return hglib.tounicode(self._rpath)
 
-    def fileStatus(self):
+    def fileStatus(self) -> Optional[Text]:
         return self._status
 
-    def isDir(self):
+    def isDir(self) -> bool:
         return not self._wfile
 
-    def mergeStatus(self):
+    def mergeStatus(self) -> Optional[Text]:
         pass
 
-    def subrepoType(self):
+    def subrepoType(self) -> Optional[Text]:
         pass
 
-    def textEncoding(self):
+    def textEncoding(self) -> Text:
         return self._textencoding
 
-    def setTextEncoding(self, name):
+    def setTextEncoding(self, name: Text) -> None:
         self._textencoding = fileencoding.canonname(name)
 
-    def detectTextEncoding(self):
+    def detectTextEncoding(self) -> None:
         ui = self._ctx.repo().ui
         # use file content for better guess; diff may be mixed encoding or
         # have immature multi-byte sequence
@@ -211,23 +237,31 @@ class _AbstractFileData(object):
         fallbackenc = self._textencoding
         self._textencoding = fileencoding.guessencoding(ui, data, fallbackenc)
 
-    def _textToUnicode(self, s):
+    def _textToUnicode(self, s: bytes) -> Text:
         return s.decode(self._textencoding, 'replace')
 
-    def diffText(self):
+    def diffText(self) -> Text:
         return self._textToUnicode(self.diff or b'')
 
-    def fileText(self):
+    def fileText(self) -> Text:
         return self._textToUnicode(self.contents or b'')
 
 
 class FileData(_AbstractFileData):
 
-    def __init__(self, ctx, pctx, path, status=None, rpath=None, mstatus=None):
+    def __init__(
+        self,
+        ctx: "HgContext",
+        pctx: Optional["HgContext"],
+        path: bytes,
+        status: Optional[Text] = None,
+        rpath: Optional[bytes] = None,
+        mstatus: Optional[Text] = None,
+    ) -> None:
         super(FileData, self).__init__(ctx, pctx, path, status, rpath)
-        self._mstatus = mstatus
+        self._mstatus: Optional[Text] = mstatus
 
-    def load(self, changeselect=False, force=False):
+    def load(self, changeselect: bool = False, force: bool = False) -> None:
         if self.rev() == nullrev:
             return
         ctx = self._ctx
@@ -242,7 +276,13 @@ class FileData(_AbstractFileData):
         except (EnvironmentError, error.LookupError, error.Abort) as e:
             self.error = errorprefix + hglib.tounicode(str(e))
 
-    def _checkMaxDiff(self, ctx, wfile, maxdiff, force):
+    def _checkMaxDiff(
+        self,
+        ctx: "HgContext",
+        wfile: bytes,
+        maxdiff: int,
+        force: bool
+    ) -> Tuple["context.basefilectx", bytes]:
         self.error = None
         fctx = ctx.filectx(wfile)
         size = hglib.getestimatedsize(fctx)
@@ -252,7 +292,9 @@ class FileData(_AbstractFileData):
 
         data = fctx.data()
         if not force:
-            if b'\0' in data or ctx.isStandin(wfile):
+            # ctx is really thgrepo.thgchangectx (i.e. a ThgContext without
+            # patchctx, with additional methods).
+            if b'\0' in data or ctx.isStandin(wfile):  # pytype: disable=attribute-error
                 raise _BadContent(_('File is binary'))
             elif _exceedsMaxLineLength(data):
                 # it's incredibly slow to render long line by QScintilla
@@ -260,7 +302,13 @@ class FileData(_AbstractFileData):
                                     'exceeded)'))
         return fctx, data
 
-    def _checkRenamed(self, repo, ctx, pctx, wfile):
+    def _checkRenamed(
+        self,
+        repo: "localrepo.localrepository",
+        ctx: "HgContext",
+        pctx: Optional["HgContext"],
+        wfile: bytes
+    ) -> Optional[bytes]:
         m = scmutil.matchfiles(repo, [wfile])
         copy = copies.pathcopies(pctx, ctx, match=m)
         oldname = copy.get(wfile)
@@ -274,8 +322,21 @@ class FileData(_AbstractFileData):
             self.flabel += _(' <i>(renamed from %s)</i>') % fr
         return oldname
 
-    def _readStatus(self, ctx, ctx2, wfile, status, changeselect, force):
-        def getstatus(repo, n1, n2, wfile):
+    def _readStatus(
+        self,
+        ctx: "HgContext",
+        ctx2: Optional["HgContext"],
+        wfile: bytes,
+        status: Text,
+        changeselect: bool,
+        force: bool,
+    ) -> None:
+        def getstatus(
+            repo: "localrepo.localrepository",
+            n1: Optional[bytes],
+            n2: Optional[bytes],
+            wfile: bytes,
+        ) -> Optional[Text]:
             m = scmutil.matchfiles(repo, [wfile])
             st = repo.status(n1, n2, match=m)
             if wfile in st.modified:
@@ -315,6 +376,8 @@ class FileData(_AbstractFileData):
 
         if ctx2 is None:
             ctx2 = ctx.p1()
+        assert ctx2 is not None  # help pytype
+
         if status is None:
             status = getstatus(repo, ctx2.node(), ctx.node(), wfile)
 
@@ -355,8 +418,12 @@ class FileData(_AbstractFileData):
             return
 
         if status in ('M', 'A', 'C'):
+            # pytype: disable=attribute-error
+            # The actual type is thgrepo.thgcontext, which has these methods
+            # TODO: make these module functions
             if ctx.hasStandin(wfile):
                 wfile = ctx.findStandin(wfile)
+                # pytype: enable=attribute-error
                 isbfile = True
             try:
                 fctx, newdata = self._checkMaxDiff(ctx, wfile, maxdiff, force)
@@ -445,30 +512,35 @@ class FileData(_AbstractFileData):
             else:
                 self.diff = b''
 
-    def mergeStatus(self):
+    def mergeStatus(self) -> Optional[Text]:
         return self._mstatus
 
-    def diffText(self):
+    def diffText(self) -> Text:
         udiff = self._textToUnicode(self.diff or b'')
         if self.changes:
             return udiff
         return _trimdiffheader(udiff)
 
-    def setChunkExcluded(self, chunk, exclude):
+    def setChunkExcluded(self, chunk: patch.recordhunk, exclude: bool) -> None:
+        # The `excluded` field is set in the hunk above when `self.changes` is
+        # initialized, thus the assertion that it is in the changes list.
+        # Therefore, the pytype warning about the missing field can be disabled.
+        # Additionally, the `excludecount` field is added to `self.changes` in
+        # the same area, so the missing field error can be disabled for it too.
         assert chunk in self.changes.hunks, repr(chunk)
-        if chunk.excluded == exclude:
+        if chunk.excluded == exclude:  # pytype: disable=attribute-error
             return
         if exclude:
             chunk.excluded = True
-            self.changes.excludecount += 1
+            self.changes.excludecount += 1  # pytype: disable=attribute-error
         else:
             chunk.excluded = False
-            self.changes.excludecount -= 1
+            self.changes.excludecount -= 1  # pytype: disable=attribute-error
 
 
 class DirData(_AbstractFileData):
 
-    def load(self, changeselect=False, force=False):
+    def load(self, changeselect: bool = False, force: bool = False) -> None:
         self.error = None
         self.flabel = u'<b>%s</b>' % self.filePath()
 
@@ -487,14 +559,14 @@ class DirData(_AbstractFileData):
             if self.error:
                 self.error += u'\n\n' + forcedisplaymsg
 
-    def isDir(self):
+    def isDir(self) -> bool:
         return True
 
 
 class PatchFileData(_AbstractFileData):
 
-    def load(self, changeselect=False, force=False):
-        ctx = self._ctx
+    def load(self, changeselect: bool = False, force: bool = False) -> None:
+        ctx = cast(patchctx.patchctx, self._ctx)
         wfile = self._wfile
         maxdiff = ctx.repo().maxdiff
 
@@ -523,28 +595,28 @@ class PatchFileData(_AbstractFileData):
             if self.error:
                 self.error += u'\n\n' + forcedisplaymsg
 
-    def rev(self):
+    def rev(self) -> int:
         # avoid mixing integer and localstr
         return nullrev
 
-    def baseRev(self):
+    def baseRev(self) -> int:
         # patch has no comparison base
         return nullrev
 
-    def diffText(self):
+    def diffText(self) -> Text:
         return _trimdiffheader(self._textToUnicode(self.diff or b''))
 
 
 class PatchDirData(_AbstractFileData):
 
-    def load(self, changeselect=False, force=False):
+    def load(self, changeselect: bool = False, force: bool = False) -> None:
         self.error = None
         self.flabel = u'<b>%s</b>' % self.filePath()
 
-        ctx = self._ctx
+        ctx = cast(patchctx.patchctx, self._ctx)
         try:
-            self.diff = ''.join([ctx.thgmqpatchdata(f) for f in ctx.files()
-                                 if f.startswith(self._wfile + b'/')])
+            self.diff = b''.join([ctx.thgmqpatchdata(f) for f in ctx.files()
+                                  if f.startswith(self._wfile + b'/')])
         except EnvironmentError as e:
             self.error = hglib.tounicode(str(e))
             return
@@ -554,36 +626,48 @@ class PatchDirData(_AbstractFileData):
             if self.error:
                 self.error += u'\n\n' + forcedisplaymsg
 
-    def rev(self):
+    def rev(self) -> int:
         # avoid mixing integer and localstr
         return nullrev
 
-    def baseRev(self):
+    def baseRev(self) -> int:
         # patch has no comparison base
         return nullrev
 
-    def isDir(self):
+    def isDir(self) -> bool:
         return True
 
 
 class SubrepoData(_AbstractFileData):
 
-    def __init__(self, ctx, pctx, path, status, rpath, subkind):
+    def __init__(
+        self,
+        ctx: "HgContext",
+        pctx: Optional["HgContext"],
+        path: bytes,
+        status: Optional[Text],
+        rpath: Optional[bytes],
+        subkind: Text,
+    ) -> None:
         super(SubrepoData, self).__init__(ctx, pctx, path, status, rpath)
         self._subkind = subkind
 
-    def createRebased(self, pctx):
+    def createRebased(
+        self: _TSubrepoData,
+        pctx: Optional["HgContext"],
+    ) -> _TSubrepoData:
         # new status should be unknown, but currently it is 'S'
         # TODO: replace 'S' by subrepo's status
         assert self._status == 'S', self._status
         return self.__class__(self._ctx, pctx, self._wfile, status=self._status,
                               rpath=self._rpath, subkind=self._subkind)
 
-    def load(self, changeselect=False, force=False):
+    def load(self, changeselect: bool = False, force: bool = False) -> None:
         ctx = self._ctx
         ctx2 = self._pctx
         if ctx2 is None:
             ctx2 = ctx.p1()
+        assert ctx2 is not None  # help pytype
         wfile = self._wfile
 
         self.error = None
@@ -592,7 +676,7 @@ class SubrepoData(_AbstractFileData):
         try:
             def genSubrepoRevChangedDescription(subrelpath, sfrom, sto,
                                                 repo):
-                # type: (bytes, Text, Text, Any) -> Tuple[List[Text], Text]
+                # type: (bytes, Text, Text, localrepo.localrepository) -> Tuple[List[Text], Text]
                 """Generate a subrepository revision change description"""
                 out = []
                 def getLog(_ui, srepo, opts):
@@ -800,26 +884,63 @@ class SubrepoData(_AbstractFileData):
             self.error = _('Error previewing subrepo: %s') % \
                     hglib.tounicode(str(e))
 
-    def isDir(self):
+    def isDir(self) -> bool:
         return True
 
-    def subrepoType(self):
+    def subrepoType(self) -> Text:
         return self._subkind
 
 
-def createFileData(ctx, ctx2, wfile, status=None, rpath=None, mstatus=None):
+def createFileData(
+    ctx: "ThgContext",
+    ctx2: Optional["HgContext"],
+    wfile: bytes,
+    status: Optional[Text] = None,
+    rpath: Optional[bytes] = None,
+    mstatus: Optional[Text] = None,
+) -> Union[FileData, PatchFileData]:
     if isinstance(ctx, patchctx.patchctx):
         if mstatus:
             raise ValueError('invalid merge status for patch: %r' % mstatus)
+
+        # `patchctx.patchctx` is ducktype compatible with changectx/workingctx
+        # as far as the abstract class methods are concerned, so ignore the type
+        # mismatch in order to avoid applying patchctx to the other data types
+        # where it never applies.
+
+        # pytype: disable=wrong-arg-types
         return PatchFileData(ctx, ctx2, wfile, status, rpath)
+        # pytype: enable=wrong-arg-types
+
     return FileData(ctx, ctx2, wfile, status, rpath, mstatus)
 
-def createDirData(ctx, pctx, path, rpath=None):
+def createDirData(
+    ctx: "ThgContext",
+    pctx: Optional["HgContext"],
+    path: bytes,
+    rpath: Optional[bytes] = None,
+) -> Union[DirData, PatchDirData]:
     if isinstance(ctx, patchctx.patchctx):
+
+        # `patchctx.patchctx` is ducktype compatible with changectx/workingctx
+        # as far as the abstract class methods are concerned, so ignore the type
+        # mismatch in order to avoid applying patchctx to the other data types
+        # where it never applies.
+
+        # pytype: disable=wrong-arg-types
         return PatchDirData(ctx, pctx, path, rpath=rpath)
+        # pytype: enable=wrong-arg-types
+
     return DirData(ctx, pctx, path, rpath=rpath)
 
-def createSubrepoData(ctx, pctx, path, status=None, rpath=None, subkind=None):
+def createSubrepoData(
+    ctx: "HgContext",
+    pctx: Optional["HgContext"],
+    path: bytes,
+    status: Optional[Text] = None,
+    rpath: Optional[bytes] = None,
+    subkind: Optional[Text] = None,
+) -> SubrepoData:
     if not subkind:
         subkind = pycompat.sysstr(
             ctx.substate.get(path, hglib.nullsubrepostate)[2]
@@ -827,7 +948,7 @@ def createSubrepoData(ctx, pctx, path, status=None, rpath=None, subkind=None):
     # TODO: replace 'S' by subrepo's status
     return SubrepoData(ctx, pctx, path, 'S', rpath, subkind)
 
-def createNullData(repo):
+def createNullData(repo: "localrepo.localrepository") -> FileData:
     ctx = repo[nullrev]
     fd = FileData(ctx, ctx.p1(), b'', 'C')
     return fd
