@@ -134,7 +134,7 @@ class _FileDiffScintilla(Scintilla):
                 lines.append((i + 1, _colormap['-'], ))
 
         p = QPainter(viewport)
-        p.setRenderHint(QPainter.Antialiasing)
+        p.setRenderHint(QPainter.RenderHint.Antialiasing)
         for (line, color) in lines:
             p.setPen(QPen(color, 3.0))
             y = line * scale
@@ -245,16 +245,16 @@ class FileLogDialog(_AbstractFileDialog):
 
     def setupUi(self):
         self.editToolbar = QToolBar(self)
-        self.editToolbar.setContextMenuPolicy(Qt.PreventContextMenu)
-        self.addToolBar(Qt.ToolBarArea(Qt.TopToolBarArea), self.editToolbar)
+        self.editToolbar.setContextMenuPolicy(Qt.ContextMenuPolicy.PreventContextMenu)
+        self.addToolBar(Qt.ToolBarArea(Qt.ToolBarArea.TopToolBarArea), self.editToolbar)
         self.actionClose = QAction(self)
-        self.actionClose.setShortcuts(QKeySequence.Close)
+        self.actionClose.setShortcuts(QKeySequence.StandardKey.Close)
         self.actionReload = QAction(self)
-        self.actionReload.setShortcuts(QKeySequence.Refresh)
+        self.actionReload.setShortcuts(QKeySequence.StandardKey.Refresh)
         self.editToolbar.addAction(self.actionReload)
         self.addAction(self.actionClose)
 
-        self.splitter = QSplitter(Qt.Vertical)
+        self.splitter = QSplitter(Qt.Orientation.Vertical)
         self.setCentralWidget(self.splitter)
         cs = ('fileLogDialog', _('File History Log Columns'))
         self.repoview = repoview.HgRepoView(self._repoagent, cs[0], cs,
@@ -301,16 +301,19 @@ class FileLogDialog(_AbstractFileDialog):
         self.actionReload.setIcon(qtlib.geticon('view-refresh'))
 
         self.actionBack = QAction(_('Back'), self, enabled=False,
-                                  shortcut=QKeySequence.Back,
+                                  shortcut=QKeySequence.StandardKey.Back,
                                   icon=qtlib.geticon('go-previous'))
         self.actionForward = QAction(_('Forward'), self, enabled=False,
-                                     shortcut=QKeySequence.Forward,
+                                     shortcut=QKeySequence.StandardKey.Forward,
                                      icon=qtlib.geticon('go-next'))
         self.repoview.revisionSelected.connect(self._updateHistoryActions)
         self.actionBack.triggered.connect(self.repoview.back)
         self.actionForward.triggered.connect(self.repoview.forward)
 
+        # TODO: remove this when the unfiltered proxy hack goes away
+        # pytype: disable=wrong-arg-types
         self._fileactions = filectxactions.FilectxActions(self._repoagent, self)
+        # pytype: enable=wrong-arg-types
         self.addActions(self._fileactions.actions())
 
     def _updateFileActions(self):
@@ -358,7 +361,7 @@ class FileLogDialog(_AbstractFileDialog):
             a = menu.addAction(_('Show Revision &Details'))
             a.setIcon(qtlib.geticon('hg-log'))
             a.triggered.connect(self.onShowRevisionDetails)
-        menu.setAttribute(Qt.WA_DeleteOnClose)
+        menu.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         menu.popup(point)
 
     def onShowRevisionDetails(self):
@@ -460,12 +463,12 @@ class FileDiffDialog(_AbstractFileDialog):
 
     def setupUi(self):
         self.editToolbar = QToolBar(self)
-        self.editToolbar.setContextMenuPolicy(Qt.PreventContextMenu)
-        self.addToolBar(Qt.ToolBarArea(Qt.TopToolBarArea), self.editToolbar)
+        self.editToolbar.setContextMenuPolicy(Qt.ContextMenuPolicy.PreventContextMenu)
+        self.addToolBar(Qt.ToolBarArea(Qt.ToolBarArea.TopToolBarArea), self.editToolbar)
         self.actionClose = QAction(self)
-        self.actionClose.setShortcuts(QKeySequence.Close)
+        self.actionClose.setShortcuts(QKeySequence.StandardKey.Close)
         self.actionReload = QAction(self)
-        self.actionReload.setShortcuts(QKeySequence.Refresh)
+        self.actionReload.setShortcuts(QKeySequence.StandardKey.Refresh)
         self.editToolbar.addAction(self.actionReload)
         self.addAction(self.actionClose)
 
@@ -474,14 +477,14 @@ class FileDiffDialog(_AbstractFileDialog):
             w.setLayout(layout)
             return w
 
-        self.splitter = QSplitter(Qt.Vertical)
+        self.splitter = QSplitter(Qt.Orientation.Vertical)
         self.setCentralWidget(self.splitter)
         self.horizontalLayout = QHBoxLayout()
         self._repoViews = []
         cs = ('fileDiffDialogLeft', _('File Differences Log Columns'))
         for cfgname in [cs[0], 'fileDiffDialogRight']:
             w = repoview.HgRepoView(self._repoagent, cfgname, cs, self)
-            w.setSelectionMode(QAbstractItemView.SingleSelection)
+            w.setSelectionMode(QAbstractItemView.SelectionMode.SingleSelection)
             self.horizontalLayout.addWidget(w)
             self._repoViews.append(w)
         self.frame = QFrame()
@@ -510,11 +513,11 @@ class FileDiffDialog(_AbstractFileDialog):
         for side, idx  in (('left', 0), ('right', 3)):
             sci = _FileDiffScintilla(self.frame)
             sci.installEventFilter(self)
-            sci.verticalScrollBar().setFocusPolicy(Qt.StrongFocus)
+            sci.verticalScrollBar().setFocusPolicy(Qt.FocusPolicy.StrongFocus)
             sci.setFocusProxy(sci.verticalScrollBar())
             sci.verticalScrollBar().installEventFilter(self)
 
-            sci.setFrameShape(QFrame.NoFrame)
+            sci.setFrameShape(QFrame.Shape.NoFrame)
             sci.setMarginLineNumbers(1, True)
             sci.SendScintilla(sci.SCI_SETSELEOLFILLED, True)
 
@@ -535,20 +538,20 @@ class FileDiffDialog(_AbstractFileDialog):
             sci.SendScintilla(sci.SCI_SETMARGINMASKN, 1, 0)
 
             # define markers for colorize zones of diff
-            self.markerplus = sci.markerDefine(QsciScintilla.Background)
+            self.markerplus = sci.markerDefine(QsciScintilla.MarkerSymbol.Background)
             sci.setMarkerBackgroundColor(_colormap['+'], self.markerplus)
-            self.markerminus = sci.markerDefine(QsciScintilla.Background)
+            self.markerminus = sci.markerDefine(QsciScintilla.MarkerSymbol.Background)
             sci.setMarkerBackgroundColor(_colormap['-'], self.markerminus)
-            self.markertriangle = sci.markerDefine(QsciScintilla.Background)
+            self.markertriangle = sci.markerDefine(QsciScintilla.MarkerSymbol.Background)
             sci.setMarkerBackgroundColor(_colormap['x'], self.markertriangle)
 
-            self.markerplusline = sci.markerDefine(QsciScintilla.Invisible,
+            self.markerplusline = sci.markerDefine(QsciScintilla.MarkerSymbol.Invisible,
                                                    _MARKERPLUSLINE)
-            self.markerminusline = sci.markerDefine(QsciScintilla.Invisible,
+            self.markerminusline = sci.markerDefine(QsciScintilla.MarkerSymbol.Invisible,
                                                     _MARKERMINUSLINE)
-            self.markerplusunderline = sci.markerDefine(QsciScintilla.Invisible,
+            self.markerplusunderline = sci.markerDefine(QsciScintilla.MarkerSymbol.Invisible,
                                                         _MARKERPLUSUNDERLINE)
-            self.markerminusunderline = sci.markerDefine(QsciScintilla.Invisible,
+            self.markerminusunderline = sci.markerDefine(QsciScintilla.MarkerSymbol.Invisible,
                                                          _MARKERMINUSUNDERLINE)
 
             self.viewers[side] = sci
@@ -616,7 +619,10 @@ class FileDiffDialog(_AbstractFileDialog):
         self.actionNextDiff.setEnabled(False)
         self.actionPrevDiff.setEnabled(False)
 
+        # TODO: remove this when the unfiltered proxy hack goes away
+        # pytype: disable=wrong-arg-types
         self._fileactions = filectxactions.FilectxActions(self._repoagent, self)
+        # pytype: enable=wrong-arg-types
         self.addActions(self._fileactions.actions())
 
     def _updateFileActionsForSelection(self, selmodel):
@@ -644,11 +650,11 @@ class FileDiffDialog(_AbstractFileDialog):
         if watched in self.viewers.values():
             # copy page steps to diffblock _after_ viewers are resized; resize
             # events will be posted in arbitrary order.
-            if event.type() == QEvent.Resize:
+            if event.type() == QEvent.Type.Resize:
                 self._delayedSyncPageStep.start()
             return False
         elif watched in self._repoViews:
-            if event.type() == QEvent.FocusIn:
+            if event.type() == QEvent.Type.FocusIn:
                 self._updateFileActionsForSelection(watched.selectionModel())
             return False
         else:
@@ -855,5 +861,5 @@ class FileDiffDialog(_AbstractFileDialog):
             return
         menu = QMenu(self)
         _setupFileMenu(menu, self._fileactions)
-        menu.setAttribute(Qt.WA_DeleteOnClose)
+        menu.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         menu.popup(point)
