@@ -9,6 +9,14 @@ from __future__ import absolute_import
 
 import codecs
 
+from typing import (
+    Dict,
+    List,
+    Optional,
+    Text,
+    Tuple,
+)
+
 from .qtgui import (
     QActionGroup,
 )
@@ -20,13 +28,26 @@ from mercurial import (
 
 from ..util.i18n import _
 
+
+if pycompat.TYPE_CHECKING:
+    from mercurial import (
+        ui as uimod,
+    )
+    from .qtcore import (
+        QObject,
+    )
+    from .qtgui import (
+        QAction,
+        QMenu,
+    )
+
 # List of encoding names which are likely used, based on the Chromium
 # source <chrome/browser/character_encoding.cc> and the Python documentation
 # <https://docs.python.org/2.7/library/codecs.html>.
 #
 # - no UTF-16 or -32, which is binary in Mercurial
 # - no ASCII because it can be represented in other encodings
-_ENCODINGNAMES = [
+_ENCODINGNAMES: List[Tuple[Text, Text]] = [
     ('utf-8', _('Unicode')),
     ('iso8859-1', _('Western Europe')),
     ('cp1252', _('Western Europe')),
@@ -64,7 +85,7 @@ _ENCODINGNAMES = [
     ]
 
 # map to wider encoding included in the table
-_SUBSTMAP = {
+_SUBSTMAP: Dict[Text, Text] = {
     'ascii': 'utf-8',
     'shift_jis': 'cp932',
     }
@@ -82,10 +103,10 @@ _SUBSTMAP = {
 # cp1251, koi8-r, koi8-u, iso8859-7, cp1253, cp1254, cp1256, iso8859-6,
 # cp1255, iso8859-8, cp1258, iso8859-4, iso8859-13, cp1257, iso8859-3,
 # iso8859-10, iso8859-14, iso8859-16
-_LOCALEENCODINGS = _('$FILE_ENCODINGS').replace('$FILE_ENCODINGS', '')
+_LOCALEENCODINGS: Text = _('$FILE_ENCODINGS').replace('$FILE_ENCODINGS', '')
 
 
-def canonname(name):
+def canonname(name: Text) -> Text:
     """Resolve aliases and substitutions of the specified encoding
 
     >>> canonname('Shift_JIS')
@@ -103,7 +124,7 @@ def canonname(name):
     name = codecs.lookup(name).name
     return _SUBSTMAP.get(name, name)
 
-def contentencoding(ui, fallbackenc=None):
+def contentencoding(ui: "uimod.ui", fallbackenc: Optional[Text] = None) -> Text:
     """Preferred encoding of file contents in repository"""
     # assumes web.encoding is the content encoding, not the filename one
     enc = pycompat.sysstr(ui.config(b'web', b'encoding'))
@@ -115,11 +136,11 @@ def contentencoding(ui, fallbackenc=None):
                      % pycompat.sysbytes(enc))
     return canonname(fallbackenc or pycompat.sysstr(encoding.encoding))
 
-def knownencodings():
+def knownencodings() -> List[Text]:
     """List of encoding names which are likely used"""
     return [enc for enc, _region in _ENCODINGNAMES]
 
-def _localeencodings():
+def _localeencodings() -> List[Text]:
     localeencs = []
     if _LOCALEENCODINGS:
         localeencs.extend(canonname(e) for e in _LOCALEENCODINGS.split(','))
@@ -131,7 +152,11 @@ def _localeencodings():
         localeencs.append(enc)
     return localeencs
 
-def guessencoding(ui, data, fallbackenc=None):
+def guessencoding(
+    ui: "uimod.ui",
+    data: bytes,
+    fallbackenc: Optional[Text] = None
+) -> Text:
     """Guess encoding of the specified data from locale-specific candidates
 
     This is faster than chardet.detect() and works well for structured
@@ -156,7 +181,7 @@ def guessencoding(ui, data, fallbackenc=None):
     return prefenc
 
 
-def createActionGroup(parent):
+def createActionGroup(parent: "QObject") -> QActionGroup:
     group = QActionGroup(parent)
     for enc, region in _ENCODINGNAMES:
         a = group.addAction('%s (%s)' % (region, enc))
@@ -164,14 +189,14 @@ def createActionGroup(parent):
         a.setData(enc)
     return group
 
-def addCustomAction(group, name):
+def addCustomAction(group: QActionGroup, name: Text) -> "QAction":
     cname = canonname(name)  # will raise LookupError for invalid name
     a = group.addAction(name)
     a.setCheckable(True)
     a.setData(cname)
     return a
 
-def addActionsToMenu(menu, group):
+def addActionsToMenu(menu: "QMenu", group: QActionGroup) -> None:
     localeencs = set(_localeencodings())
     localeacts = []
     otheracts = []
@@ -187,20 +212,20 @@ def addActionsToMenu(menu, group):
         menu.addSeparator()
     menu.addActions(otheracts)
 
-def findActionByName(group, name):
+def findActionByName(group: QActionGroup, name: Text) -> "QAction":
     cname = canonname(name)
     for a in group.actions():
         if str(a.data()) == cname:
             return a
     raise LookupError('no encoding action: %s' % name)
 
-def checkedActionName(group):
+def checkedActionName(group: QActionGroup) -> Text:
     a = group.checkedAction()
     if not a:
         return ''
     return str(a.data())
 
-def checkActionByName(group, name):
+def checkActionByName(group: QActionGroup, name: Text) -> None:
     try:
         a = findActionByName(group, name)
     except LookupError:
