@@ -53,10 +53,10 @@ class HgFileListView(QTreeView):
         # type: (Optional[QWidget]) -> None
         QTreeView.__init__(self, parent)
         self.setHeaderHidden(True)
-        self.setDragDropMode(QAbstractItemView.DragOnly)
-        self.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        self.setDragDropMode(QAbstractItemView.DragDropMode.DragOnly)
+        self.setSelectionMode(QAbstractItemView.SelectionMode.ExtendedSelection)
         self.setRootIsDecorated(False)
-        self.setTextElideMode(Qt.ElideLeft)
+        self.setTextElideMode(Qt.TextElideMode.ElideLeft)
 
         # give consistent height and enable optimization
         self.setIconSize(qtlib.smallIconSize())
