@@ -135,7 +135,7 @@ class HgFileView(QFrame):
         self.filenamelabel = w = QLabel()
         w.setWordWrap(True)
         f = w.textInteractionFlags()
-        w.setTextInteractionFlags(f | Qt.TextSelectableByMouse)
+        w.setTextInteractionFlags(f | Qt.TextInteractionFlag.TextSelectableByMouse)
         w.linkActivated.connect(self.linkActivated)
         hbox.addWidget(w, 1)
 
@@ -161,7 +161,7 @@ class HgFileView(QFrame):
         hbox.addWidget(self.blksearch)
 
         self.sci.cursorPositionChanged.connect(self._updateDiffActions)
-        self.sci.setContextMenuPolicy(Qt.CustomContextMenu)
+        self.sci.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.sci.customContextMenuRequested.connect(self._onMenuRequested)
         self.sci.SCN_ZOOM.connect(self._updateScrollBar)
 
@@ -175,10 +175,10 @@ class HgFileView(QFrame):
         self.sci.installEventFilter(qscilib.KeyPressInterceptor(self))
         self.sci.setCaretLineVisible(False)
 
-        self.sci.markerDefine(qsci.Invisible, _ChunkStartMarker)
+        self.sci.markerDefine(qsci.MarkerSymbol.Invisible, _ChunkStartMarker)
 
         # hide margin 0 (markers)
-        self.sci.setMarginType(0, qsci.SymbolMargin)
+        self.sci.setMarginType(0, qsci.MarginType.SymbolMargin)
         self.sci.setMarginWidth(0, 0)
 
         self.searchbar = qscilib.SearchToolBar()
@@ -259,7 +259,7 @@ class HgFileView(QFrame):
         self.actionFind.setIcon(qtlib.geticon('edit-find'))
         self.actionFind.setToolTip(_('Toggle display of text search bar'))
         self.actionFind.triggered.connect(self._onSearchbarTriggered)
-        qtlib.newshortcutsforstdkey(QKeySequence.Find, self,
+        qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Find, self,
                                     self._showSearchbar)
 
         self.actionShelf = QAction('Shelve', self)
@@ -695,7 +695,7 @@ class HgFileView(QFrame):
             # assume that the longest line has the largest width;
             # fm.width() is too slow to apply to each line.
             longestline = max(lines, key=len)
-            maxWidth = fm.width(longestline)
+            maxWidth = fm.horizontalAdvance(longestline)
         else:
             maxWidth = 0
         # setScrollWidth() expects the value to be > 0
@@ -740,7 +740,7 @@ class _DiffViewControl(_AbstractViewControl):
         self._firstlinetoprocess = 0
 
     def open(self):
-        self._sci.markerDefine(qsci.Background, _ChunkStartMarker)
+        self._sci.markerDefine(qsci.MarkerSymbol.Background, _ChunkStartMarker)
         if qtlib.isDarkTheme(self._sci.palette()):
             self._sci.setMarkerBackgroundColor(QColor('#204820'),
                                                _ChunkStartMarker)
@@ -750,7 +750,7 @@ class _DiffViewControl(_AbstractViewControl):
         self._sci.setLexer(lexers.difflexer(self))
 
     def close(self):
-        self._sci.markerDefine(qsci.Invisible, _ChunkStartMarker)
+        self._sci.markerDefine(qsci.MarkerSymbol.Invisible, _ChunkStartMarker)
         self._sci.setLexer(None)
         self._buildtimer.stop()
 
@@ -798,8 +798,8 @@ class _FileViewControl(_AbstractViewControl):
         self._sci.setMarginWidth(_LineNumberMargin, 0)
 
         # define markers for colorize zones of diff
-        self._sci.markerDefine(qsci.Background, _InsertedLineMarker)
-        self._sci.markerDefine(qsci.Background, _ReplacedLineMarker)
+        self._sci.markerDefine(qsci.MarkerSymbol.Background, _InsertedLineMarker)
+        self._sci.markerDefine(qsci.MarkerSymbol.Background, _ReplacedLineMarker)
         if qtlib.isDarkTheme(self._sci.palette()):
             self._sci.setMarkerBackgroundColor(QColor('#204820'),
                                                _InsertedLineMarker)
@@ -945,13 +945,13 @@ class _MessageViewControl(_AbstractViewControl):
         if self._forceviewindicator is not None:
             return
         self._forceviewindicator = self._sci.indicatorDefine(
-            self._sci.PlainIndicator)
+            self._sci.IndicatorStyle.PlainIndicator)
         self._sci.setIndicatorDrawUnder(True, self._forceviewindicator)
         self._sci.setIndicatorForegroundColor(
             QColor('blue'), self._forceviewindicator)
         # delay until next event-loop in order to complete mouse release
         self._sci.SCN_INDICATORRELEASE.connect(self._requestForceDisplay,
-                                               Qt.QueuedConnection)
+                                               Qt.ConnectionType.QueuedConnection)
 
     @pyqtSlot()
     def _requestForceDisplay(self):
@@ -977,7 +977,7 @@ class _AnnotateViewControl(_AbstractViewControl):
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         self._sci = sci
-        self._sci.setMarginType(_AnnotateMargin, qsci.TextMarginRightJustified)
+        self._sci.setMarginType(_AnnotateMargin, qsci.MarginType.TextMarginRightJustified)
         self._sci.setMarginSensitivity(_AnnotateMargin, True)
         self._sci.marginClicked.connect(self._onMarginClicked)
 
@@ -1010,7 +1010,7 @@ class _AnnotateViewControl(_AbstractViewControl):
         except RuntimeError:
             sciviewport = None
         if watched is sciviewport:
-            if event.type() == QEvent.MouseMove:
+            if event.type() == QEvent.Type.MouseMove:
                 line = self._sci.lineNearPoint(event.pos())
                 self._emitRevisionHintAtLine(line)
             return False
@@ -1183,7 +1183,7 @@ class _AnnotateViewControl(_AbstractViewControl):
                                                isdarktheme=self._isdarktheme)
         for i, (color, fctxs) in enumerate(palette.items()):
             m = _FirstAnnotateLineMarker + i
-            self._sci.markerDefine(qsci.Background, m)
+            self._sci.markerDefine(qsci.MarkerSymbol.Background, m)
             self._sci.setMarkerBackgroundColor(QColor(color), m)
             for fctx in fctxs:
                 self._revmarkers[fctx.rev()] = m
@@ -1192,7 +1192,7 @@ class _AnnotateViewControl(_AbstractViewControl):
     def _margin_style(self):
         """Style for margin area"""
         s = Qsci.QsciStyle(qscilib.STYLE_FILEVIEW_MARGIN)
-        s.setPaper(QApplication.palette().color(QPalette.Window))
+        s.setPaper(QApplication.palette().color(QPalette.ColorRole.Window))
         s.setFont(self._sci.font())
         return s
 
@@ -1269,7 +1269,7 @@ class _AnnotateViewControl(_AbstractViewControl):
             return
 
         lastclick = self._lastmarginclick
-        if (state == Qt.ControlModifier
+        if (state == Qt.KeyboardModifier.ControlModifier
             or lastclick.elapsed() < QApplication.doubleClickInterval()):
             if line >= len(self._links):
                 # empty line next to the last line
@@ -1282,7 +1282,7 @@ class _AnnotateViewControl(_AbstractViewControl):
 
             # mimic the default "border selection" behavior,
             # which is disabled when you use setMarginSensitivity()
-            if state == Qt.ShiftModifier:
+            if state == Qt.KeyboardModifier.ShiftModifier:
                 r = self._sci.getSelection()
                 sellinetop, selchartop, sellinebottom, selcharbottom = r
                 if sellinetop <= line:
@@ -1307,19 +1307,19 @@ class _ChunkSelectionViewControl(_AbstractViewControl):
     def __init__(self, sci, fd, parent=None):
         super(_ChunkSelectionViewControl, self).__init__(parent)
         self._sci = sci
-        p = qtlib.getcheckboxpixmap(QStyle.State_On, QColor('#B0FFA0'), sci)
+        p = qtlib.getcheckboxpixmap(QStyle.StateFlag.State_On, QColor('#B0FFA0'), sci)
         self._sci.markerDefine(p, _IncludedChunkStartMarker)
-        p = qtlib.getcheckboxpixmap(QStyle.State_Off, QColor('#B0FFA0'), sci)
+        p = qtlib.getcheckboxpixmap(QStyle.StateFlag.State_Off, QColor('#B0FFA0'), sci)
         self._sci.markerDefine(p, _ExcludedChunkStartMarker)
 
-        self._sci.markerDefine(qsci.Background, _ExcludedLineMarker)
+        self._sci.markerDefine(qsci.MarkerSymbol.Background, _ExcludedLineMarker)
         if qtlib.isDarkTheme(self._sci.palette()):
             bg, fg = QColor(44, 44, 44), QColor(86, 86, 86)
         else:
             bg, fg = QColor('lightgrey'), QColor('darkgrey')
         self._sci.setMarkerBackgroundColor(bg, _ExcludedLineMarker)
         self._sci.setMarkerForegroundColor(fg, _ExcludedLineMarker)
-        self._sci.setMarginType(_ChunkSelectionMargin, qsci.SymbolMargin)
+        self._sci.setMarginType(_ChunkSelectionMargin, qsci.MarginType.SymbolMargin)
         self._sci.setMarginMarkerMask(_ChunkSelectionMargin,
                                       _ChunkSelectionMarkerMask)
         self._sci.setMarginSensitivity(_ChunkSelectionMargin, True)
@@ -1335,8 +1335,8 @@ class _ChunkSelectionViewControl(_AbstractViewControl):
         self._sci.setIndicatorForegroundColor(QColor('gray'),
                                               self._excludeindicator)
 
-        self._toggleshortcut = a = QShortcut(Qt.Key_Space, sci)
-        a.setContext(Qt.WidgetShortcut)
+        self._toggleshortcut = a = QShortcut(Qt.Key.Key_Space, sci)
+        a.setContext(Qt.ShortcutContext.WidgetShortcut)
         a.setEnabled(False)
         a.activated.connect(self._toggleCurrentChunk)
 
@@ -1408,7 +1408,7 @@ class _ChunkSelectionViewControl(_AbstractViewControl):
             return
         if line not in self._chunkatline:
             return
-        if state & Qt.ShiftModifier:
+        if state & Qt.KeyboardModifier.ShiftModifier:
             excluded = self._getChunkAtLine(line)
             cl = self._currentChunkLine()
             end = max(line, cl)
@@ -1459,7 +1459,7 @@ class _ChunkSelectionViewControl(_AbstractViewControl):
         - self.excludeindicator MUST be set to -1 before calling this
         method for the first time
         '''
-        indicatortypes = (qsci.HiddenIndicator, qsci.StrikeIndicator)
+        indicatortypes = (qsci.IndicatorStyle.HiddenIndicator, qsci.IndicatorStyle.StrikeIndicator)
         self._excludeindicator = self._sci.indicatorDefine(
             indicatortypes[checked],
             self._excludeindicator)
