@@ -59,7 +59,7 @@ class GraftDialog(QDialog):
         super(GraftDialog, self).__init__(parent)
         self.setWindowIcon(qtlib.geticon('hg-transplant'))
         self.setWindowFlags(self.windowFlags()
-                            & ~Qt.WindowContextHelpButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
@@ -136,11 +136,11 @@ class GraftDialog(QDialog):
         box.addWidget(self._stbar)
 
         bbox = QDialogButtonBox()
-        self.cancelbtn = bbox.addButton(QDialogButtonBox.Cancel)
+        self.cancelbtn = bbox.addButton(QDialogButtonBox.StandardButton.Cancel)
         self.cancelbtn.clicked.connect(self.reject)
-        self.graftbtn = bbox.addButton(_('Graft'), QDialogButtonBox.ActionRole)
+        self.graftbtn = bbox.addButton(_('Graft'), QDialogButtonBox.ButtonRole.ActionRole)
         self.graftbtn.clicked.connect(self.graft)
-        self.abortbtn = bbox.addButton(_('Abort'), QDialogButtonBox.ActionRole)
+        self.abortbtn = bbox.addButton(_('Abort'), QDialogButtonBox.ButtonRole.ActionRole)
         self.abortbtn.clicked.connect(self.abort)
         box.addWidget(bbox)
         self.bbox = bbox
@@ -326,8 +326,8 @@ class GraftDialog(QDialog):
         if hglib.graft_in_progress(self.repo):
             main = _('Exiting with an unfinished graft is not recommended.')
             text = _('Consider aborting the graft first.')
-            labels = ((QMessageBox.Yes, _('&Exit')),
-                      (QMessageBox.No, _('Cancel')))
+            labels = ((QMessageBox.StandardButton.Yes, _('&Exit')),
+                      (QMessageBox.StandardButton.No, _('Cancel')))
             if not qtlib.QuestionMsgBox(_('Confirm Exit'), main, text,
                                         labels=labels, parent=self):
                 return
