@@ -49,6 +49,7 @@ from mercurial import (
     hg,
     match,
     pycompat,
+    scmutil,
     subrepo,
     ui,
 )
@@ -513,8 +514,9 @@ class CtxSearchThread(QThread):
         self.canceled = True
 
     def run(self):
+        uipathfn = scmutil.getuipathfn(self.repo, legacyrelativevalue=True)
         def badfn(f, msg):
-            e = hglib.tounicode("%s: %s" % (matchfn.rel(f), msg))
+            e = hglib.tounicode(b"%s: %s" % (uipathfn(f), msg))
             self.showMessage.emit(e)
         self.hu = htmlui.htmlui(self.repo.ui)
         try:
@@ -682,7 +684,7 @@ class MatchTree(QTableView):
                 seen.add(path)
             if rev is None and path not in repo[None]:
                 abs = repo.wjoin(path)
-                root = paths.find_root(abs)
+                root = paths.find_root_bytes(abs)
                 if root and abs.startswith(root):
                     uroot = hglib.tounicode(root)
                     srepoagent = self._repoagent.subRepoAgent(uroot)
