@@ -78,14 +78,14 @@ class DetectRenameDialog(QDialog):
         self.setWindowTitle(_('Detect Copies/Renames in %s')
                             % repoagent.displayName())
         self.setWindowIcon(qtlib.geticon('thg-guess'))
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
 
         layout = QVBoxLayout()
         layout.setContentsMargins(*(2,)*4)
         self.setLayout(layout)
 
         # vsplit for top & diff
-        vsplit = QSplitter(Qt.Horizontal)
+        vsplit = QSplitter(Qt.Orientation.Horizontal)
         utframe = QFrame(vsplit)
         matchframe = QFrame(vsplit)
 
@@ -96,7 +96,7 @@ class DetectRenameDialog(QDialog):
         matchvbox.setContentsMargins(*(2,)*4)
         matchframe.setLayout(matchvbox)
 
-        hsplit = QSplitter(Qt.Vertical)
+        hsplit = QSplitter(Qt.Orientation.Vertical)
         layout.addWidget(hsplit)
         hsplit.addWidget(vsplit)
         utheader = QHBoxLayout()
@@ -112,18 +112,18 @@ class DetectRenameDialog(QDialog):
         utheader.addWidget(tb)
 
         self.unrevlist = QListWidget()
-        self.unrevlist.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        self.unrevlist.setSelectionMode(QAbstractItemView.SelectionMode.ExtendedSelection)
         self.unrevlist.doubleClicked.connect(self.onUnrevDoubleClicked)
         utvbox.addWidget(self.unrevlist)
 
         simhbox = QHBoxLayout()
         utvbox.addLayout(simhbox)
         lbl = QLabel()
-        slider = QSlider(Qt.Horizontal)
+        slider = QSlider(Qt.Orientation.Horizontal)
         slider.setRange(0, 100)
         slider.setTickInterval(10)
         slider.setPageStep(10)
-        slider.setTickPosition(QSlider.TicksBelow)
+        slider.setTickPosition(QSlider.TickPosition.TicksBelow)
         slider.changefunc = lambda v: lbl.setText(
                             _('Min Similarity: %d%%') % v)
         slider.valueChanged.connect(slider.changefunc)
@@ -150,7 +150,7 @@ class DetectRenameDialog(QDialog):
         matchlbl = QLabel(_('<b>Candidate Matches</b>'))
         matchvbox.addWidget(matchlbl)
         matchtv = QTreeView()
-        matchtv.setSelectionMode(QTreeView.ExtendedSelection)
+        matchtv.setSelectionMode(QTreeView.SelectionMode.ExtendedSelection)
         matchtv.setItemsExpandable(False)
         matchtv.setRootIsDecorated(False)
         matchtv.setModel(MatchModel())
@@ -174,7 +174,7 @@ class DetectRenameDialog(QDialog):
         selmodel = matchtv.selectionModel()
         selmodel.selectionChanged.connect(matchselect)
 
-        sp = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+        sp = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
         sp.setHorizontalStretch(1)
         matchframe.setSizePolicy(sp)
 
@@ -384,30 +384,30 @@ class MatchModel(QAbstractTableModel):
     def data(self, index, role):
         if not index.isValid():
             return None
-        if role == Qt.DisplayRole:
+        if role == Qt.ItemDataRole.DisplayRole:
             s = self.rows[index.row()][index.column()]
             f = self.displayformats[index.column()]
             return f(s)
         '''
-        elif role == Qt.TextColorRole:
+        elif role == Qt.ItemDataRole.ForegroundRole:
             src, dst, pct = self.rows[index.row()]
             if pct == 1.0:
                 return QColor('green')
             else:
                 return QColor('black')
-        elif role == Qt.ToolTipRole:
+        elif role == Qt.ItemDataRole.ToolTipRole:
             # explain what row means?
         '''
         return None
 
     def headerData(self, col, orientation, role):
-        if role != Qt.DisplayRole or orientation != Qt.Horizontal:
+        if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         else:
             return self.headers[col]
 
     def flags(self, index):
-        return Qt.ItemIsSelectable | Qt.ItemIsEnabled
+        return Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsEnabled
 
     # Custom methods
 
@@ -442,7 +442,7 @@ class MatchModel(QAbstractTableModel):
         self.beginResetModel()
         self.layoutAboutToBeChanged.emit()
         self.rows.sort(key=lambda x: x[col],
-                       reverse=(order == Qt.DescendingOrder))
+                       reverse=(order == Qt.SortOrder.DescendingOrder))
         self.layoutChanged.emit()
         self.endResetModel()
 
