@@ -65,8 +65,8 @@ class HgignoreDialog(QDialog):
         'Initialize the Dialog'
         QDialog.__init__(self, parent)
         self.setWindowFlags(self.windowFlags()
-            & ~Qt.WindowContextHelpButtonHint
-            | Qt.WindowMaximizeButtonHint)
+            & ~Qt.WindowType.WindowContextHelpButtonHint
+            | Qt.WindowType.WindowMaximizeButtonHint)
 
         self._repoagent = repoagent
         self.pats = pats
@@ -134,21 +134,20 @@ class HgignoreDialog(QDialog):
 
         ignorelist = QListWidget()
         ivbox.addWidget(ignorelist)
-        ignorelist.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        ignorelist.setSelectionMode(QAbstractItemView.SelectionMode.ExtendedSelection)
         unknownlist = QListWidget()
         uvbox.addWidget(unknownlist)
-        unknownlist.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        unknownlist.setSelectionMode(QAbstractItemView.SelectionMode.ExtendedSelection)
         unknownlist.currentTextChanged.connect(self.setGlobFilter)
-        unknownlist.setContextMenuPolicy(Qt.CustomContextMenu)
+        unknownlist.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         unknownlist.customContextMenuRequested.connect(self.menuRequest)
         unknownlist.itemDoubleClicked.connect(self.unknownDoubleClicked)
         lbl = QLabel(_('Backspace or Del to remove row(s)'))
         ivbox.addWidget(lbl)
 
         # layer 4 - dialog buttons
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Close)
-        bb.button(BB.Close).setAutoDefault(False)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Close)
+        bb.button(QDialogButtonBox.StandardButton.Close).setAutoDefault(False)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         vbox.addWidget(bb)
@@ -170,9 +169,9 @@ class HgignoreDialog(QDialog):
     def eventFilter(self, obj, event):
         if obj != self.ignorelist:
             return False
-        if event.type() != QEvent.KeyPress:
+        if event.type() != QEvent.Type.KeyPress:
             return False
-        elif event.key() not in (Qt.Key_Backspace, Qt.Key_Delete):
+        elif event.key() not in (Qt.Key.Key_Backspace, Qt.Key.Key_Delete):
             return False
         if obj.currentRow() < 0:
             return False
@@ -250,7 +249,7 @@ class HgignoreDialog(QDialog):
 
     def editClicked(self):
         ignfile = hglib.tounicode(self.ignorefile)
-        if qscilib.fileEditor(ignfile) == QDialog.Accepted:
+        if qscilib.fileEditor(ignfile) == QDialog.DialogCode.Accepted:
             self.refresh()
 
     def addEntry(self):
