@@ -56,7 +56,7 @@ class InitWidget(cmdui.AbstractCmdWidget):
     def __init__(self, ui, cmdagent, destdir='.', parent=None):
         # type: (uimod.ui, cmdcore.CmdAgent, Text, Optional[QWidget]) -> None
         super(InitWidget, self).__init__(parent)
-        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._cmdagent = cmdagent
 
         form = QFormLayout()
