@@ -15,7 +15,7 @@ from .qtgui import (
     QAbstractTextDocumentLayout,
     QPalette,
     QStyle,
-    QStyleOptionViewItemV4,
+    QStyleOptionViewItem,
     QStyledItemDelegate,
     QTextDocument,
 )
@@ -24,8 +24,8 @@ class HTMLDelegate(QStyledItemDelegate):
 
     def paint(self, painter, option, index):
         # draw selection
-        option = QStyleOptionViewItemV4(option)
-        self.parent().style().drawControl(QStyle.CE_ItemViewItem, option, painter)
+        option = QStyleOptionViewItem(option)
+        self.parent().style().drawControl(QStyle.ControlElement.CE_ItemViewItem, option, painter)
 
         # draw text
         doc = self._builddoc(option, index)
@@ -36,21 +36,21 @@ class HTMLDelegate(QStyledItemDelegate):
             option.rect.top() + (option.rect.height() - doc.size().height()) / 2))
         ctx = QAbstractTextDocumentLayout.PaintContext()
         ctx.palette = option.palette
-        if option.state & QStyle.State_Selected:
-            if option.state & QStyle.State_Active:
-                ctx.palette.setCurrentColorGroup(QPalette.Active)
+        if option.state & QStyle.StateFlag.State_Selected:
+            if option.state & QStyle.StateFlag.State_Active:
+                ctx.palette.setCurrentColorGroup(QPalette.ColorGroup.Active)
             else:
-                ctx.palette.setCurrentColorGroup(QPalette.Inactive)
-            ctx.palette.setBrush(QPalette.Text, ctx.palette.highlightedText())
-        elif not option.state & QStyle.State_Enabled:
-            ctx.palette.setCurrentColorGroup(QPalette.Disabled)
+                ctx.palette.setCurrentColorGroup(QPalette.ColorGroup.Inactive)
+            ctx.palette.setBrush(QPalette.ColorRole.Text, ctx.palette.highlightedText())
+        elif not option.state & QStyle.StateFlag.State_Enabled:
+            ctx.palette.setCurrentColorGroup(QPalette.ColorGroup.Disabled)
 
         doc.documentLayout().draw(painter, ctx)
         painter.restore()
 
     def sizeHint(self, option, index):
         doc = self._builddoc(option, index)
-        return QSize(doc.idealWidth() + 5, doc.size().height())
+        return QSize(int(doc.idealWidth() + 5), int(doc.size().height()))
 
     def _builddoc(self, option, index):
         doc = QTextDocument(defaultFont=option.font)
