@@ -120,12 +120,12 @@ class InfoBar(QFrame):
         }
 
     def __init__(self, parent=None):
-        super(InfoBar, self).__init__(parent, frameShape=QFrame.StyledPanel,
-                                      frameShadow=QFrame.Plain)
+        super(InfoBar, self).__init__(parent, frameShape=QFrame.Shape.StyledPanel,
+                                      frameShadow=QFrame.Shadow.Plain)
         self.setAutoFillBackground(True)
         p = self.palette()
-        p.setColor(QPalette.Window, QColor(self._colormap[self.infobartype]))
-        p.setColor(QPalette.WindowText, QColor("black"))
+        p.setColor(QPalette.ColorRole.Window, QColor(self._colormap[self.infobartype]))
+        p.setColor(QPalette.ColorRole.WindowText, QColor("black"))
         self.setPalette(p)
 
         self.setLayout(QHBoxLayout())
@@ -133,7 +133,7 @@ class InfoBar(QFrame):
 
         self.layout().addStretch()
         self._closebutton = QPushButton(self, flat=True, autoDefault=False,
-            icon=self.style().standardIcon(QStyle.SP_TitleBarCloseButton))
+            icon=self.style().standardIcon(QStyle.StandardPixmap.SP_TitleBarCloseButton))
         if qtlib.IS_RETINA:
             self._closebutton.setIconSize(qtlib.barRetinaIconSize())
         self._closebutton.clicked.connect(self.close)
@@ -151,7 +151,7 @@ class InfoBar(QFrame):
         super(InfoBar, self).closeEvent(event)
 
     def keyPressEvent(self, event):
-        if event.key() == Qt.Key_Escape:
+        if event.key() == Qt.Key.Key_Escape:
             self.close()
         super(InfoBar, self).keyPressEvent(event)
 
@@ -170,8 +170,8 @@ class StatusInfoBar(InfoBar):
         super(StatusInfoBar, self).__init__(parent)
         self._msglabel = QLabel(message, self,
                                 wordWrap=True,
-                                textInteractionFlags=Qt.TextSelectableByMouse \
-                                | Qt.LinksAccessibleByMouse)
+                                textInteractionFlags=Qt.TextInteractionFlag.TextSelectableByMouse \
+                                | Qt.TextInteractionFlag.LinksAccessibleByMouse)
         self._msglabel.linkActivated.connect(self.linkActivated)
         self.addWidget(self._msglabel, stretch=1)
 
@@ -186,8 +186,8 @@ class CommandErrorInfoBar(InfoBar):
 
         self._msglabel = QLabel(message, self,
                                 wordWrap=True,
-                                textInteractionFlags=Qt.TextSelectableByMouse \
-                                | Qt.LinksAccessibleByMouse)
+                                textInteractionFlags=Qt.TextInteractionFlag.TextSelectableByMouse \
+                                | Qt.TextInteractionFlag.LinksAccessibleByMouse)
         self._msglabel.linkActivated.connect(self.linkActivated)
         self.addWidget(self._msglabel, stretch=1)
 
@@ -209,15 +209,15 @@ class ConfirmInfoBar(InfoBar):
         # no wordWrap=True and stretch=1, which inserts unwanted space
         # between _msglabel and _buttons.
         self._msglabel = QLabel(message, self,
-                                textInteractionFlags=Qt.TextSelectableByMouse \
-                                | Qt.LinksAccessibleByMouse)
+                                textInteractionFlags=Qt.TextInteractionFlag.TextSelectableByMouse \
+                                | Qt.TextInteractionFlag.LinksAccessibleByMouse)
         self._msglabel.linkActivated.connect(self.linkActivated)
         self.addWidget(self._msglabel)
 
         self._buttons = QDialogButtonBox(self)
-        self._buttons.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
-        self.acceptButton = self._buttons.addButton(QDialogButtonBox.Ok)
-        self.rejectButton = self._buttons.addButton(QDialogButtonBox.Cancel)
+        self._buttons.setSizePolicy(QSizePolicy.Policy.Fixed, QSizePolicy.Policy.Fixed)
+        self.acceptButton = self._buttons.addButton(QDialogButtonBox.StandardButton.Ok)
+        self.rejectButton = self._buttons.addButton(QDialogButtonBox.StandardButton.Cancel)
         self._buttons.accepted.connect(self._accept)
         self._buttons.rejected.connect(self._reject)
         self.addWidget(self._buttons)
