@@ -269,9 +269,9 @@ class LockDialog(QDialog):
 
     def keyPressEvent(self, event):
         sess = self._cmdsession
-        if event.matches(QKeySequence.Refresh):
+        if event.matches(QKeySequence.StandardKey.Refresh):
             self.reload()
-        elif event.key() == Qt.Key_Escape and not sess.isFinished():
+        elif event.key() == Qt.Key.Key_Escape and not sess.isFinished():
             sess.abort()
         else:
             return super(LockDialog, self).keyPressEvent(event)
