@@ -90,7 +90,7 @@ class ManifestModel(QAbstractItemModel):
     # emitted when all files of the revision has been loaded successfully
     revLoaded = pyqtSignal(object)
 
-    StatusRole = Qt.UserRole + 1
+    StatusRole = Qt.ItemDataRole.UserRole + 1
     """Role for file change status"""
 
     # -1 and None are valid revision number
@@ -116,18 +116,18 @@ class ManifestModel(QAbstractItemModel):
         self._populate = _populaterepo
         self._rootpopulated = False
 
-    def data(self, index, role=Qt.DisplayRole):
+    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
         # type: (QModelIndex, Qt.ItemDataRole) -> Optional[Any]
         if not index.isValid():
             return
 
-        if role == Qt.DecorationRole:
+        if role == Qt.ItemDataRole.DecorationRole:
             return self.fileIcon(index)
         if role == self.StatusRole:
             return self.fileStatus(index)
 
         e = index.internalPointer()  # type: "_Entry"
-        if role in (Qt.DisplayRole, Qt.EditRole):
+        if role in (Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole):
             return e.name
 
     def filePath(self, index):
@@ -189,7 +189,7 @@ class ManifestModel(QAbstractItemModel):
                 return qtlib.getoverlaidicon(ic, qtlib.geticon(n))
             ic = qtlib.getoverlaidicon(ic, qtlib.geticon('thg-subrepo'))
         elif e.isdir:
-            ic = self._fileiconprovider.icon(QFileIconProvider.Folder)
+            ic = self._fileiconprovider.icon(QFileIconProvider.IconType.Folder)
         else:
             # do not use fileiconprovier.icon(fileinfo), which may return icon
             # with shell (i.e. status of working directory) overlay.
@@ -262,7 +262,7 @@ class ManifestModel(QAbstractItemModel):
             return f
         if not (self.isDir(index) or self.fileStatus(index) == 'R'
                 or self._populate is _populatepatch):
-            f |= Qt.ItemIsDragEnabled
+            f |= Qt.ItemFlag.ItemIsDragEnabled
         return f
 
     def index(self, row, column, parent=QModelIndex()):
