@@ -58,12 +58,12 @@ class MergeDialog(QWizard):
         assert isinstance(otherrev, int), repr(otherrev)
         self._repoagent = repoagent
         f = self.windowFlags()
-        self.setWindowFlags(f & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(f & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.setWindowTitle(_('Merge - %s') % repoagent.displayName())
         self.setWindowIcon(qtlib.geticon('hg-merge'))
-        self.setOption(QWizard.NoBackButtonOnStartPage, True)
-        self.setOption(QWizard.NoBackButtonOnLastPage, True)
-        self.setOption(QWizard.IndependentPages, True)
+        self.setOption(QWizard.WizardOption.NoBackButtonOnStartPage, True)
+        self.setOption(QWizard.WizardOption.NoBackButtonOnLastPage, True)
+        self.setOption(QWizard.WizardOption.IndependentPages, True)
 
         # set pages
         summarypage = SummaryPage(repoagent, otherrev, self)
@@ -75,7 +75,7 @@ class MergeDialog(QWizard):
 
         # move focus to "Next" button so that "Cancel" doesn't eat Enter key
         summarypage.refreshFinished.connect(
-            self.button(QWizard.NextButton).setFocus)
+            self.button(QWizard.WizardButton.NextButton).setFocus)
 
         self.resize(QSize(700, 489).expandedTo(self.minimumSizeHint()))
 
@@ -152,7 +152,7 @@ class BasePage(QWizardPage):
         pass
 
     def currentPage(self):
-        self.wizard().setOption(QWizard.NoDefaultButton, False)
+        self.wizard().setOption(QWizard.WizardOption.NoDefaultButton, False)
 
     def canExit(self):
         if len(self.repo[None].parents()) == 2:
@@ -161,8 +161,8 @@ class BasePage(QWizardPage):
                      'the working directory.\n\n'
                      'To cancel the merge you can update to one '
                      'of the merge parent revisions.')
-            labels = ((QMessageBox.Yes, _('&Exit')),
-                      (QMessageBox.No, _('Cancel')))
+            labels = ((QMessageBox.StandardButton.Yes, _('&Exit')),
+                      (QMessageBox.StandardButton.No, _('Cancel')))
             if not qtlib.QuestionMsgBox(_('Confirm Exit'), main, text,
                                         labels=labels, parent=self):
                 return False
@@ -277,8 +277,8 @@ class SummaryPage(BasePage):
     def validatePage(self):
         'validate that we can continue with the merge'
         if self.field('discard'):
-            labels = [(QMessageBox.Yes, _('&Discard')),
-                      (QMessageBox.No, _('Cancel'))]
+            labels = [(QMessageBox.StandardButton.Yes, _('&Discard')),
+                      (QMessageBox.StandardButton.No, _('Cancel'))]
             if not qtlib.QuestionMsgBox(_('Confirm Discard Changes'),
                 _('The changes from revision %s and all unmerged parents '
                   'will be discarded.\n\n'
@@ -539,7 +539,7 @@ class CommitPage(BasePage):
             if self.isComplete():
                 self.wizard().next()
         actionEnter = QAction('alt-enter', self)
-        actionEnter.setShortcuts([Qt.CTRL+Qt.Key_Return, Qt.CTRL+Qt.Key_Enter])
+        actionEnter.setShortcuts([Qt.Modifier.CTRL+Qt.Key.Key_Return, Qt.Modifier.CTRL+Qt.Key.Key_Enter])
         actionEnter.triggered.connect(tryperform)
         self.addAction(actionEnter)
 
@@ -559,9 +559,9 @@ class CommitPage(BasePage):
         hblayout.addStretch()
         self.layout().addLayout(hblayout)
 
-        self.setButtonText(QWizard.CommitButton, _('Commit Now'))
+        self.setButtonText(QWizard.WizardButton.CommitButton, _('Commit Now'))
         # The cancel button does not really "cancel" the merge
-        self.setButtonText(QWizard.CancelButton, _('Commit Later'))
+        self.setButtonText(QWizard.WizardButton.CancelButton, _('Commit Later'))
 
         # Update the options label
         self.refresh()
@@ -578,7 +578,7 @@ class CommitPage(BasePage):
 
     def currentPage(self):
         super(CommitPage, self).currentPage()
-        self.wizard().setOption(QWizard.NoDefaultButton, True)
+        self.wizard().setOption(QWizard.WizardOption.NoDefaultButton, True)
         self.mergeCsInfo.update()  # show post-merge state
 
         self.msgEntry.setText(commit.mergecommitmessage(self.repo))
@@ -661,9 +661,9 @@ class CommitPage(BasePage):
         dlg = commit.DetailsDialog(self._repoagent, self.opts, self.userhist,
                                    self, mode='merge')
         dlg.finished.connect(dlg.deleteLater)
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
-        if dlg.exec_() == QDialog.Accepted:
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
+        if dlg.exec_() == QDialog.DialogCode.Accepted:
             self.opts.update(dlg.outopts)
             self.refresh()
 
@@ -685,4 +685,4 @@ class ResultPage(BasePage):
     def currentPage(self):
         super(ResultPage, self).currentPage()
         self.mergeCsInfo.update(self.repo[b'tip'])
-        self.wizard().setOption(QWizard.NoCancelButton, True)
+        self.wizard().setOption(QWizard.WizardOption.NoCancelButton, True)
