@@ -29,6 +29,9 @@ from mercurial import (
 )
 
 from ..util.i18n import _
+from ..util import (
+    hglib,
+)
 from . import (
     qscilib,
     qtlib,
@@ -39,7 +42,7 @@ class MessageEntry(qscilib.Scintilla):
     def __init__(self, parent, getCheckedFunc=None):
         super(MessageEntry, self).__init__(parent)
         self.setEdgeColor(QColor('LightSalmon'))
-        self.setEdgeMode(QsciScintilla.EdgeLine)
+        self.setEdgeMode(QsciScintilla.EdgeMode.EdgeLine)
         self.setReadOnly(False)
         self.setMarginWidth(1, 0)
         self.setFont(qtlib.getfont('fontcomment').font())
@@ -47,19 +50,19 @@ class MessageEntry(qscilib.Scintilla):
         self.setCaretLineBackgroundColor(QColor("#e6fff0"))
         self.setCaretLineVisible(True)
         self.setAutoIndent(True)
-        self.setAutoCompletionSource(QsciScintilla.AcsAPIs)
+        self.setAutoCompletionSource(QsciScintilla.AutoCompletionSource.AcsAPIs)
         self.setAutoCompletionFillupsEnabled(True)
-        self.setMatchedBraceBackgroundColor(Qt.yellow)
+        self.setMatchedBraceBackgroundColor(Qt.GlobalColor.yellow)
         self.setIndentationsUseTabs(False)
-        self.setBraceMatching(QsciScintilla.SloppyBraceMatch)
+        self.setBraceMatching(QsciScintilla.BraceMatch.SloppyBraceMatch)
         # https://www.riverbankcomputing.com/pipermail/qscintilla/2009-February/000461.html
-        self.setHorizontalScrollBarPolicy(Qt.ScrollBarAsNeeded)
-        self.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
+        self.setHorizontalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAsNeeded)
+        self.setVerticalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAsNeeded)
         # default message entry widgets to word wrap, user may override
-        self.setWrapMode(QsciScintilla.WrapWord)
+        self.setWrapMode(QsciScintilla.WrapMode.WrapWord)
 
         self.getChecked = getCheckedFunc
-        self.setContextMenuPolicy(Qt.CustomContextMenu)
+        self.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.customContextMenuRequested.connect(self.menuRequested)
         self.applylexer()
 
@@ -75,7 +78,7 @@ class MessageEntry(qscilib.Scintilla):
         self.fontHeight = QFontMetrics(font).height()
         if qtlib.readBool(QSettings(), 'msgentry/lexer', True):
             self.setLexer(QsciLexerMakefile(self))
-            self.lexer().setColor(QColor(Qt.red), QsciLexerMakefile.Error)
+            self.lexer().setColor(QColor(Qt.GlobalColor.red), QsciLexerMakefile.Error)
             self.lexer().setFont(font)
         else:
             self.setLexer(None)
@@ -106,7 +109,7 @@ class MessageEntry(qscilib.Scintilla):
 
         def paste():
             files = self.getChecked()
-            self.insert('\n'.join(sorted(files)))
+            self.insert(hglib.tounicode(b'\n'.join(sorted(files))))
         def settings():
             from tortoisehg.hgqt.settings import SettingsDialog
             dlg = SettingsDialog(True, focus='tortoisehg.summarylen')
@@ -262,7 +265,7 @@ class MessageEntry(qscilib.Scintilla):
             self.horizontalScrollBar().setSliderPosition(0)
 
     def keyPressEvent(self, event):
-        if event.modifiers() == Qt.ControlModifier and event.key() == Qt.Key_E:
+        if event.modifiers() == Qt.KeyboardModifier.ControlModifier and event.key() == Qt.Key.Key_E:
             line, col = self.getCursorPosition()
             self.reflowBlock(line)
         else:
