@@ -81,7 +81,7 @@ def _checkForRejects(repo, rawoutput, parent=None):
                                 parent=parent):
             dlg = rejects.RejectsDialog(repo.ui, repo.wjoin(wfile), parent)
             r = dlg.exec_()
-            rejfiles[ufile] = (r == QDialog.Accepted)
+            rejfiles[ufile] = (r == QDialog.DialogCode.Accepted)
 
     # empty rejfiles means we failed to parse output message
     return bool(rejfiles) and all(rejfiles.values())
@@ -402,9 +402,9 @@ class PatchQueueActions(QObject):
     def launchOptionsDialog(self):
         dlg = OptionsDialog(self._opts, self._parentWidget())
         dlg.finished.connect(dlg.deleteLater)
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
-        if dlg.exec_() == QDialog.Accepted:
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
+        if dlg.exec_() == QDialog.DialogCode.Accepted:
             self._opts.update(dlg.outopts)
 
 
@@ -474,25 +474,25 @@ class PatchQueueModel(QAbstractListModel):
             elif why is not None:
                 self._statusmap[patch] = 'unguarded'
 
-    def data(self, index, role=Qt.DisplayRole):
+    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
         if not index.isValid():
             return
-        if role in (Qt.DisplayRole, Qt.EditRole):
+        if role in (Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole):
             return self.patchName(index)
-        if role == Qt.DecorationRole:
+        if role == Qt.ItemDataRole.DecorationRole:
             return self._statusIcon(index)
-        if role == Qt.FontRole:
+        if role == Qt.ItemDataRole.FontRole:
             return self._statusFont(index)
-        if role == Qt.ToolTipRole:
+        if role == Qt.ItemDataRole.ToolTipRole:
             return self._toolTip(index)
 
     def flags(self, index):
         flags = super(PatchQueueModel, self).flags(index)
         if not index.isValid():
-            return flags | Qt.ItemIsDropEnabled  # insertion point
+            return flags | Qt.ItemFlag.ItemIsDropEnabled  # insertion point
         patch = self._series[index.row()]
         if self._statusmap.get(patch) != 'applied':
-            flags |= Qt.ItemIsDragEnabled
+            flags |= Qt.ItemFlag.ItemIsDragEnabled
         return flags
 
     def rowCount(self, parent=QModelIndex()):
@@ -579,7 +579,7 @@ class PatchQueueModel(QAbstractListModel):
         return data
 
     def dropMimeData(self, data, action, row, column, parent):
-        if (action != Qt.MoveAction
+        if (action != Qt.DropAction.MoveAction
             or not data.hasFormat('application/vnd.thg.mq.series')
             or row < 0 or parent.isValid()):
             return False
@@ -599,7 +599,7 @@ class PatchQueueModel(QAbstractListModel):
         return True
 
     def supportedDropActions(self):
-        return Qt.MoveAction
+        return Qt.DropAction.MoveAction
 
 
 class MQPatchesWidget(QDockWidget):
@@ -610,9 +610,9 @@ class MQPatchesWidget(QDockWidget):
         self._actionregistry = actionregistry
         self._repoagent = None
 
-        self.setFeatures(QDockWidget.DockWidgetClosable |
-                         QDockWidget.DockWidgetMovable  |
-                         QDockWidget.DockWidgetFloatable)
+        self.setFeatures(QDockWidget.DockWidgetFeature.DockWidgetClosable |
+                         QDockWidget.DockWidgetFeature.DockWidgetMovable  |
+                         QDockWidget.DockWidgetFeature.DockWidgetFloatable)
         self.setWindowTitle(_('Patch Queue'))
 
         w = QWidget()
@@ -665,7 +665,7 @@ class MQPatchesWidget(QDockWidget):
         }
         for n, a in namedActions.items():
             self.addAction(a)
-            a.setShortcutContext(Qt.WidgetWithChildrenShortcut)
+            a.setShortcutContext(Qt.ShortcutContext.WidgetWithChildrenShortcut)
             self._actionregistry.registerAction(n, a)
 
         tbar = QToolBar(_('Patch Queue Actions Toolbar'), self)
@@ -700,19 +700,19 @@ class MQPatchesWidget(QDockWidget):
         qqueuehbox.addWidget(self._qqueueComboWidget, 1)
         self._qqueueConfigBtn = QToolButton(self)
         self._qqueueConfigBtn.setText('...')
-        self._qqueueConfigBtn.setPopupMode(QToolButton.InstantPopup)
+        self._qqueueConfigBtn.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
         qqueuehbox.addWidget(self._qqueueConfigBtn)
 
         self._qqueueActions = QueueManagementActions(self)
         self._qqueueConfigBtn.setMenu(self._qqueueActions.createMenu(self))
 
         self._queueListWidget = QListView(self)
-        self._queueListWidget.setDragDropMode(QAbstractItemView.InternalMove)
-        self._queueListWidget.setEditTriggers(QAbstractItemView.NoEditTriggers)
+        self._queueListWidget.setDragDropMode(QAbstractItemView.DragDropMode.InternalMove)
+        self._queueListWidget.setEditTriggers(QAbstractItemView.EditTrigger.NoEditTriggers)
         self._queueListWidget.setIconSize(qtlib.smallIconSize() * 0.75)
         self._queueListWidget.setSelectionMode(
-            QAbstractItemView.ExtendedSelection)
-        self._queueListWidget.setContextMenuPolicy(Qt.CustomContextMenu)
+            QAbstractItemView.SelectionMode.ExtendedSelection)
+        self._queueListWidget.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self._queueListWidget.customContextMenuRequested.connect(
             self._onMenuRequested)
         layout.addWidget(self._queueListWidget, 1)
@@ -795,7 +795,7 @@ class MQPatchesWidget(QDockWidget):
         menu.addAction(self._qdeleteAct)
         menu.addAction(self._qrenameAct)
         menu.addAction(self._setGuardsAct)
-        menu.setAttribute(Qt.WA_DeleteOnClose)
+        menu.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         menu.popup(self._queueListWidget.viewport().mapToGlobal(pos))
 
     def _currentPatchName(self):
@@ -885,7 +885,7 @@ class MQPatchesWidget(QDockWidget):
 
         if qtlib.QuestionMsgBox(_('Confirm patch queue switch'),
                 _("Do you really want to activate patch queue '%s' ?") % text,
-                parent=self, defaultbutton=QMessageBox.No):
+                parent=self, defaultbutton=QMessageBox.StandardButton.No):
             sess = self._qqueueActions.switchQueue(text)
             sess.commandFinished.connect(self._showActiveQueue)
         else:
@@ -949,7 +949,7 @@ class MQPatchesWidget(QDockWidget):
                                                          newguards))
 
     def keyPressEvent(self, event):
-        if event.key() == Qt.Key_Escape:
+        if event.key() == Qt.Key.Key_Escape:
             self._patchActions.abort()
             self._qqueueActions.abort()
         else:
@@ -979,8 +979,7 @@ class OptionsDialog(QDialog):
         for cb in [self.forcecb, self.keepcb]:
             cb.clicked.connect(self._resolveopts)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         self.bb = bb
