@@ -51,17 +51,16 @@ class PerforcePending(QDialog):
         self.cslist = cslist.ChangesetList(repo)
         layout.addWidget(self.cslist)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Cancel|BB.Discard)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel|QDialogButtonBox.StandardButton.Discard)
         bb.rejected.connect(self.reject)
-        bb.button(BB.Discard).setText('Revert')
-        bb.button(BB.Discard).setAutoDefault(False)
-        bb.button(BB.Discard).clicked.connect(self.revert)
-        bb.button(BB.Discard).setEnabled(False)
-        bb.button(BB.Ok).setText('Submit')
-        bb.button(BB.Ok).setAutoDefault(True)
-        bb.button(BB.Ok).clicked.connect(self.submit)
-        bb.button(BB.Ok).setEnabled(False)
+        bb.button(QDialogButtonBox.StandardButton.Discard).setText('Revert')
+        bb.button(QDialogButtonBox.StandardButton.Discard).setAutoDefault(False)
+        bb.button(QDialogButtonBox.StandardButton.Discard).clicked.connect(self.revert)
+        bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(False)
+        bb.button(QDialogButtonBox.StandardButton.Ok).setText('Submit')
+        bb.button(QDialogButtonBox.StandardButton.Ok).setAutoDefault(True)
+        bb.button(QDialogButtonBox.StandardButton.Ok).clicked.connect(self.submit)
+        bb.button(QDialogButtonBox.StandardButton.Ok).setEnabled(False)
         layout.addWidget(bb)
         self.bb = bb
 
@@ -73,7 +72,7 @@ class PerforcePending(QDialog):
         self.setWindowTitle(_('Pending Perforce Changelists - %s') %
                             repoagent.displayName())
         self.setWindowFlags(self.windowFlags() &
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
 
     @pyqtSlot(str)
     def p4clActivated(self, curcl):
@@ -88,8 +87,8 @@ class PerforcePending(QDialog):
         self.cslist.clear()
         self.cslist.update(revs)
         sensitive = not curcl.endswith(b'(submitted)')
-        self.bb.button(QDialogButtonBox.Ok).setEnabled(sensitive)
-        self.bb.button(QDialogButtonBox.Discard).setEnabled(sensitive)
+        self.bb.button(QDialogButtonBox.StandardButton.Ok).setEnabled(sensitive)
+        self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(sensitive)
         self.curcl = curcl
 
     def submit(self):
@@ -98,8 +97,8 @@ class PerforcePending(QDialog):
                    '--config', 'extensions.perfarce=',
                    '--repository', hglib.tounicode(self.url),
                    hglib.tounicode(self.curcl[:-10])]
-        self.bb.button(QDialogButtonBox.Ok).setEnabled(False)
-        self.bb.button(QDialogButtonBox.Discard).setEnabled(False)
+        self.bb.button(QDialogButtonBox.StandardButton.Ok).setEnabled(False)
+        self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(False)
         self.showMessage.emit(_('Submitting p4 changelist...'))
         self._cmdsession = sess = self._repoagent.runCommand(cmdline, self)
         sess.commandFinished.connect(self.commandFinished)
@@ -110,8 +109,8 @@ class PerforcePending(QDialog):
                    '--config', 'extensions.perfarce=',
                    '--repository', hglib.tounicode(self.url),
                    hglib.tounicode(self.curcl[:-10])]
-        self.bb.button(QDialogButtonBox.Ok).setEnabled(False)
-        self.bb.button(QDialogButtonBox.Discard).setEnabled(False)
+        self.bb.button(QDialogButtonBox.StandardButton.Ok).setEnabled(False)
+        self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(False)
         self.showMessage.emit(_('Reverting p4 changelist...'))
         self._cmdsession = sess = self._repoagent.runCommand(cmdline, self)
         sess.commandFinished.connect(self.commandFinished)
@@ -119,15 +118,15 @@ class PerforcePending(QDialog):
     @pyqtSlot(int)
     def commandFinished(self, ret):
         self.showMessage.emit('')
-        self.bb.button(QDialogButtonBox.Ok).setEnabled(True)
-        self.bb.button(QDialogButtonBox.Discard).setEnabled(True)
+        self.bb.button(QDialogButtonBox.StandardButton.Ok).setEnabled(True)
+        self.bb.button(QDialogButtonBox.StandardButton.Discard).setEnabled(True)
         if ret == 0:
             self.reject()
         else:
             cmdui.errorMessageBox(self._cmdsession, self)
 
     def keyPressEvent(self, event):
-        if event.key() == Qt.Key_Escape:
+        if event.key() == Qt.Key.Key_Escape:
             if not self._cmdsession.isFinished():
                 self._cmdsession.abort()
             else:
