@@ -103,7 +103,7 @@ class PhabReviewDialog(QDialog):
         :revs: List of revisions to be sent.
         """
         super(PhabReviewDialog, self).__init__(parent)
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         self._rescansession = cmdcore.nullCmdSession()
@@ -116,7 +116,7 @@ class PhabReviewDialog(QDialog):
         proxymodel = QSortFilterProxyModel(self._qui.available_reviewer_list)
         proxymodel.setDynamicSortFilter(True)
         proxymodel.setSourceModel(QStandardItemModel())
-        proxymodel.setFilterCaseSensitivity(Qt.CaseInsensitive)
+        proxymodel.setFilterCaseSensitivity(Qt.CaseSensitivity.CaseInsensitive)
         proxymodel.sort(0)
         self.availablereviewersmodel = proxymodel
 
@@ -251,7 +251,7 @@ class PhabReviewDialog(QDialog):
                 reviewer = history.get(username)
                 if reviewer:
                     witem = QListWidgetItem(pycompat.unicode(reviewer))
-                    witem.setData(Qt.UserRole + 1, reviewer)
+                    witem.setData(Qt.ItemDataRole.UserRole + 1, reviewer)
                     reviewers.addItem(witem)
             s.endArray()
 
@@ -274,7 +274,7 @@ class PhabReviewDialog(QDialog):
         selectedreviewers = self._qui.selected_reviewers_list
 
         for i in pycompat.xrange(selectedreviewers.count()):
-            reviewer = selectedreviewers.item(i).data(Qt.UserRole + 1)
+            reviewer = selectedreviewers.item(i).data(Qt.ItemDataRole.UserRole + 1)
             reviewers[reviewer.username] = reviewer
 
         s = QSettings()
@@ -297,7 +297,7 @@ class PhabReviewDialog(QDialog):
             for i in pycompat.xrange(reviewers.count()):
                 s.setArrayIndex(i)
                 s.setValue("username",
-                           reviewers.item(i).data(Qt.UserRole + 1).username)
+                           reviewers.item(i).data(Qt.ItemDataRole.UserRole + 1).username)
             s.endArray()
 
     def _initchangesets(self, revs):
@@ -336,7 +336,7 @@ class PhabReviewDialog(QDialog):
         opts['rev'] = hglib.compactrevs(self._revs)
 
         reviewerlist = self._qui.selected_reviewers_list
-        opts['reviewer'] = [reviewerlist.item(i).data(Qt.UserRole + 1).username
+        opts['reviewer'] = [reviewerlist.item(i).data(Qt.ItemDataRole.UserRole + 1).username
                             for i in pycompat.xrange(reviewerlist.count())]
 
         return opts
@@ -419,7 +419,7 @@ class PhabReviewDialog(QDialog):
             url = b'Not Configured!'
 
         reviewerlist = self._qui.selected_reviewers_list
-        role = Qt.UserRole + 1
+        role = Qt.ItemDataRole.UserRole + 1
 
         reviewers = [reviewerlist.item(i).data(role).username
                      for i in pycompat.xrange(reviewerlist.count())]
@@ -436,7 +436,7 @@ class PhabReviewDialog(QDialog):
         preview.append(exported)
 
     def _previewtabindex(self):
-        # type: () -> None
+        # type: () -> int
         """Index of preview tab"""
         return self._qui.main_tabs.indexOf(self._qui.preview_tab)
 
@@ -520,7 +520,7 @@ class PhabReviewDialog(QDialog):
                 }
             }''')
 
-        buf.open(QIODevice.ReadOnly)
+        buf.open(QIODevice.OpenModeFlag.ReadOnly)
 
         cmdline = hglib.buildcmdargs('debugcallconduit', 'user.search')
         self._rescansession = sess = self._repoagent.runCommand(cmdline)
@@ -549,7 +549,7 @@ class PhabReviewDialog(QDialog):
         buf = QBuffer()
 
         buf.setData(b'{}')
-        buf.open(QIODevice.ReadOnly)
+        buf.open(QIODevice.OpenModeFlag.ReadOnly)
 
         cmdline = hglib.buildcmdargs("debugcallconduit", "user.whoami")
         self._namesession = sess = self._repoagent.runCommand(cmdline)
@@ -621,9 +621,9 @@ class PhabReviewDialog(QDialog):
 
         for i in self._qui.available_reviewer_list.selectedIndexes():
             item = model.item(proxymodel.mapToSource(i).row())
-            if not reviewers.findItems(item.text(), Qt.MatchExactly):
+            if not reviewers.findItems(item.text(), Qt.MatchFlag.MatchExactly):
                 witem = QListWidgetItem(item.text())
-                witem.setData(Qt.UserRole + 1, item.data())
+                witem.setData(Qt.ItemDataRole.UserRole + 1, item.data())
                 reviewers.addItem(witem)
 
     @pyqtSlot()
