@@ -57,7 +57,7 @@ class PickDialog(QDialog):
 
         # TODO: self.setWindowIcon(qtlib.geticon('hg-pick'))
         self.setWindowFlags(self.windowFlags()
-                            & ~Qt.WindowContextHelpButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint)
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         self.opts = opts
@@ -93,15 +93,15 @@ class PickDialog(QDialog):
         box.addWidget(self._stbar)
 
         bbox = QDialogButtonBox()
-        self.cancelbtn = bbox.addButton(QDialogButtonBox.Cancel)
+        self.cancelbtn = bbox.addButton(QDialogButtonBox.StandardButton.Cancel)
         self.cancelbtn.clicked.connect(self.reject)
 
         self.runbtn = bbox.addButton(_('Pick'),
-                                     QDialogButtonBox.ActionRole)
+                                     QDialogButtonBox.ButtonRole.ActionRole)
         self.runbtn.clicked.connect(self.runCommand)
 
         self.abortbtn = bbox.addButton(_('Abort'),
-                                       QDialogButtonBox.ActionRole)
+                                       QDialogButtonBox.ButtonRole.ActionRole)
         self.abortbtn.clicked.connect(self.abort)
         box.addWidget(bbox)
 
@@ -275,8 +275,8 @@ class PickDialog(QDialog):
         if hglib.pick_in_progress(self.repo):
             main = _('Exiting with an unfinished pick is not recommended.')
             text = _('Consider aborting the pick first.')
-            labels = ((QMessageBox.Yes, _('&Exit')),
-                      (QMessageBox.No, _('Cancel')))
+            labels = ((QMessageBox.StandardButton.Yes, _('&Exit')),
+                      (QMessageBox.StandardButton.No, _('Cancel')))
             if not qtlib.QuestionMsgBox(_('Confirm Exit'), main, text,
                                         labels=labels, parent=self):
                 return
