@@ -137,7 +137,7 @@ class PostReviewDialog(QDialog):
     def __init__(self, ui, repoagent, revs, parent=None):
         # type: (uimod.ui, RepoAgent, Sequence[Union[bytes, int]], Optional[QWidget]) -> None
         super(PostReviewDialog, self).__init__(parent)
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.ui = ui
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
@@ -166,7 +166,7 @@ class PostReviewDialog(QDialog):
         pwd, ok = qtlib.getTextInput(self,
                                      _('Review Board'),
                                      _('Password:'),
-                                     mode=QLineEdit.Password)
+                                     mode=QLineEdit.EchoMode.Password)
         if ok and pwd:
             self.password = hglib.fromunicode(pwd)
             return True
