@@ -262,7 +262,7 @@ class PurgeThread(QThread):
 
         def remove(remove_func, name):
             try:
-                if keephg and name.startswith('.hg'):
+                if keephg and name.startswith(b'.hg'):
                     return
                 remove_func(repo.wjoin(name))
             except EnvironmentError:
@@ -280,7 +280,7 @@ class PurgeThread(QThread):
                 os.remove(path)
 
         for i, f in enumerate(sorted(files)):
-            data = ('deleting', i, f, '', len(files))
+            data = ('deleting', i, hglib.tounicode(f), '', len(files))
             self.progress.emit(*data)
             remove(removefile, f)
         data = ('deleting', None, '', '', len(files))
@@ -290,10 +290,10 @@ class PurgeThread(QThread):
         if opts['delfolders'] and directories:
             for i, f in enumerate(sorted(directories, reverse=True)):
                 if match(f) and not os.listdir(repo.wjoin(f)):
-                    data = ('rmdir', i, f, '', len(directories))
+                    data = ('rmdir', i, hglib.tounicode(f), '', len(directories))
                     self.progress.emit(*data)
                     remove(os.rmdir, f)
-            data = ('rmdir', None, f, '', len(directories))
+            data = ('rmdir', None, '', '', len(directories))
             self.progress.emit(*data)
             self.showMessage.emit(_('Deleted %d files and %d folders') % (
                                   len(files), len(directories)))
