@@ -29,7 +29,7 @@ class QDeleteDialog(QDialog):
         self.setWindowTitle(_('Delete Patches'))
         self.setWindowIcon(qtlib.geticon('hg-qdelete'))
         self.setWindowFlags(self.windowFlags()
-                            & ~Qt.WindowContextHelpButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self.setLayout(QVBoxLayout())
 
@@ -41,8 +41,7 @@ class QDeleteDialog(QDialog):
         self._keepchk = QCheckBox(_('Keep patch files'))
         self.layout().addWidget(self._keepchk)
 
-        BB = QDialogButtonBox
-        bbox = QDialogButtonBox(BB.Ok|BB.Cancel)
+        bbox = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel)
         bbox.accepted.connect(self.accept)
         bbox.rejected.connect(self.reject)
         self.layout().addWidget(bbox)
