@@ -383,7 +383,7 @@ class Scintilla(ScintillaCompat):
 
     def saveSettings(self, qs, prefix):
         if QT_VERSION >= 0x60000:
-            value = lambda e: e.value
+            value = lambda e: e.value  # pytype: disable=attribute-error
         else:
             value = lambda e: e
 
