@@ -109,10 +109,17 @@ _recoverableexc = {
 def earlyExceptionMsgBox(e):
     """Show message for recoverable error before the QApplication is started"""
     opts = {'cmd': ' '.join(sys.argv[1:]),
-            'values': e,
+            'values': [hglib.tounicode(str(e))],
             'error': traceback.format_exc(),
             'nofork': True}
     errstring = _recoverableexc[e.__class__]
+    if isinstance(e, error.ConfigError) and e.location:
+        # If ConfigError contained a location, the config file couldn't be
+        # parsed at all. So '#edit:<location>' is the only way to fix.
+        errstring = _recoverableexc[error.ParseError]
+        opts['values'] += [hglib.tounicode(e.location)]
+    elif isinstance(e, error.ParseError) and e.location:
+        opts['values'] += [hglib.tounicode(e.location)]
     if not QApplication.instance():
         main = QApplication(sys.argv)
     dlg = bugreport.ExceptionMsgBox(hglib.tounicode(str(e)), errstring, opts)
@@ -141,7 +148,7 @@ class ExceptionCatcher(QObject):
         # can be emitted by another thread; postpones it until next
         # eventloop of main (GUI) thread.
         self._exceptionOccured.connect(self.putexception,
-                                       Qt.QueuedConnection)
+                                       Qt.ConnectionType.QueuedConnection)
 
         self._origexcepthook = None
         if not self._ui.configbool(b'tortoisehg', b'traceback'):
@@ -231,7 +238,7 @@ class ExceptionCatcher(QObject):
             for fd in (rfd, wfd):
                 flags = fcntl.fcntl(fd, fcntl.F_GETFL)
                 fcntl.fcntl(fd, fcntl.F_SETFL, flags | os.O_NONBLOCK)
-            self._wakeupsn = QSocketNotifier(rfd, QSocketNotifier.Read, self)
+            self._wakeupsn = QSocketNotifier(rfd, QSocketNotifier.Type.Read, self)
             self._wakeupsn.activated.connect(self._handleWakeup)
             self._origwakeupfd = signal.set_wakeup_fd(wfd)
 
@@ -347,7 +354,7 @@ def connectToExistingWorkbench(root, revset=None):
         data = root
     servername = QApplication.applicationName() + '-' + _ugetuser()
     socket = QLocalSocket()
-    socket.connectToServer(servername, QIODevice.ReadWrite)
+    socket.connectToServer(servername, QIODevice.OpenModeFlag.ReadWrite)
     if socket.waitForConnected(10000):
         # Momentarily let any process set the foreground window
         # The server process with revoke this permission as soon as it gets
@@ -359,7 +366,7 @@ def connectToExistingWorkbench(root, revset=None):
         reply = socket.readAll()
         if data == reply:
             return True
-    elif socket.error() == QLocalSocket.ConnectionRefusedError:
+    elif socket.error() == QLocalSocket.LocalSocketError.ConnectionRefusedError:
         # last server process was crashed?
         QLocalServer.removeServer(servername)
     return False
@@ -379,8 +386,8 @@ def _fixapplicationfont():
     f = QFont(hglib.tounicode(lf.lfFaceName))
     f.setItalic(lf.lfItalic)
     if lf.lfWeight != win32con.FW_DONTCARE:
-        weights = [(0, QFont.Light), (400, QFont.Normal), (600, QFont.DemiBold),
-                   (700, QFont.Bold), (800, QFont.Black)]
+        weights = [(0, QFont.Weight.Light), (400, QFont.Weight.Normal), (600, QFont.Weight.DemiBold),
+                   (700, QFont.Weight.Bold), (800, QFont.Weight.Black)]
         n, w = [e for e in weights if e[0] <= lf.lfWeight][-1]
         f.setWeight(w)
     f.setPixelSize(abs(lf.lfHeight))
@@ -390,8 +397,14 @@ def _gettranslationpath():
     """Return path to Qt's translation file (.qm)"""
     if getattr(sys, 'frozen', False) and os.name == 'nt':
         return ':/translations'
-    else:
+    # pytype: disable=attribute-error
+    elif QT_API == 'PyQt5':
+        # QLibraryInfo.LibraryPath.PluginsPath is not available with
+        # PyQt 5.13.2/Qt 5.9.9
         return QLibraryInfo.location(QLibraryInfo.TranslationsPath)
+    else:
+        return QLibraryInfo.location(QLibraryInfo.LibraryPath.TranslationsPath)
+    # pytype: enable=attribute-error
 
 class QtRunner(QObject):
     """Run Qt app and hold its windows
@@ -419,15 +432,18 @@ class QtRunner(QObject):
             self._opendialog(dlgfunc, args, opts)
             return
 
-        QSettings.setDefaultFormat(QSettings.IniFormat)
+        QSettings.setDefaultFormat(QSettings.Format.IniFormat)
 
         self._ui = ui
         self._config = hgconfig.HgConfig(ui)
         self._mainapp = QApplication(sys.argv)
 
-        self._mainapp.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
+        if QT_API == "PyQt5":
+            # pytype: disable=attribute-error
+            self._mainapp.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
+            # pytype: enable=attribute-error
         if sys.platform == 'darwin':
-            self._mainapp.setAttribute(Qt.AA_DontShowIconsInMenus, True)
+            self._mainapp.setAttribute(Qt.ApplicationAttribute.AA_DontShowIconsInMenus, True)
 
         self._exccatcher = ExceptionCatcher(ui, self._mainapp, self)
         self._gc = GarbageCollector(ui, self)
@@ -457,7 +473,7 @@ class QtRunner(QObject):
         # stop services after control returns to the main event loop
         self._mainapp.setQuitOnLastWindowClosed(False)
         self._mainapp.lastWindowClosed.connect(self._quitGracefully,
-                                               Qt.QueuedConnection)
+                                               Qt.ConnectionType.QueuedConnection)
 
         dlg, reporoot = self._createdialog(dlgfunc, args, opts)
         self._mainreporoot = reporoot
@@ -540,7 +556,7 @@ class QtRunner(QObject):
         if not dlg:
             return
 
-        dlg.setAttribute(Qt.WA_DeleteOnClose)
+        dlg.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         if reporoot:
             dlg.destroyed.connect(self._reporeleaser.map)
             self._reporeleaser.setMapping(dlg, reporoot)
@@ -622,8 +638,8 @@ class QtRunner(QObject):
                 # This assumes that the client process has
                 # called allowSetForegroundWindow(-1) right before
                 # sending the request
-                wb.setWindowState(wb.windowState() & ~Qt.WindowMinimized
-                                  | Qt.WindowActive)
+                wb.setWindowState(wb.windowState() & ~Qt.WindowState.WindowMinimized
+                                  | Qt.WindowState.WindowActive)
                 wb.show()
                 wb.raise_()
                 wb.activateWindow()
