@@ -1,4 +1,4 @@
-# qtcore.py - PyQt4/5 compatibility wrapper
+# qtcore.py - PyQt5/6 compatibility wrapper
 #
 # Copyright 2015 Yuya Nishihara <yuya@tcha.org>
 #
@@ -13,7 +13,7 @@ import os
 import sys
 
 def _detectapi():
-    candidates = ['PyQt5']
+    candidates = ['PyQt5', 'PyQt6']
     if not getattr(sys, 'frozen', False):
         api = os.environ.get('THG_QT_API')
         if api:
@@ -32,7 +32,9 @@ try:
 except (AttributeError, ImportError):
     QT_API = _detectapi()
 
-if QT_API == 'PyQt5':
-    from PyQt5.QtCore import *
+if QT_API == 'PyQt6':
+    from PyQt6.QtCore import *  # pytype: disable=import-error
+elif QT_API == 'PyQt5':
+    from PyQt5.QtCore import *  # pytype: disable=import-error
 else:
     raise RuntimeError('unsupported Qt API: %s' % QT_API)
