@@ -9,6 +9,10 @@ from __future__ import absolute_import
 
 import os
 import sys
+from typing import (
+    Any,
+    List,
+)
 
 from .qtcore import (
     QObject,
@@ -64,7 +68,7 @@ class QuickOpDialog(QDialog):
     """ Dialog for performing quick dirstate operations """
     def __init__(self, repoagent, command, pats, parent):
         QDialog.__init__(self, parent)
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
         self.pats = pats
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
@@ -135,12 +139,11 @@ class QuickOpDialog(QDialog):
         self.statusbar = cmdui.ThgStatusBar(self)
         stwidget.showMessage.connect(self.statusbar.showMessage)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Close)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Close)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
-        bb.button(BB.Ok).setDefault(True)
-        bb.button(BB.Ok).setText(LABELS[command][1])
+        bb.button(QDialogButtonBox.StandardButton.Ok).setDefault(True)
+        bb.button(QDialogButtonBox.StandardButton.Ok).setText(LABELS[command][1])
         hbox.addStretch()
         hbox.addWidget(bb)
         toplayout.addLayout(hbox)
@@ -153,7 +156,7 @@ class QuickOpDialog(QDialog):
                 self.addLfilesButton = None
             if self.addLfilesButton:
                 self.addLfilesButton.clicked.connect(self.addLfiles)
-                bb.addButton(self.addLfilesButton, BB.ActionRole)
+                bb.addButton(self.addLfilesButton, QDialogButtonBox.ButtonRole.ActionRole)
 
         layout.addWidget(self.statusbar)
 
@@ -171,7 +174,7 @@ class QuickOpDialog(QDialog):
         self.stwidget.refreshWctx()
         QShortcut(QKeySequence('Ctrl+Return'), self, self.accept)
         QShortcut(QKeySequence('Ctrl+Enter'), self, self.accept)
-        qtlib.newshortcutsforstdkey(QKeySequence.Refresh, self,
+        qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Refresh, self,
                                     self.stwidget.refreshWctx)
         QShortcut(QKeySequence('Escape'), self, self.reject)
 
@@ -180,26 +183,30 @@ class QuickOpDialog(QDialog):
         return self._repoagent.rawRepo()
 
     def _runCommand(self, files, lfiles, opts):
+        # type: (List[bytes], List[bytes], Any) -> None
         cmdlines = []
         if files:
-            cmdlines.append(hglib.buildcmdargs(self.command, *files, **opts))
+            cmdlines.append(hglib.buildcmdargs(self.command, *[
+                hglib.escapepath(hglib.tounicode(f)) for f in files
+            ], **opts))
         if lfiles:
             assert self.command == 'add', self.command
             lopts = opts.copy()
             lopts['large'] = True
-            cmdlines.append(hglib.buildcmdargs(self.command, *lfiles, **lopts))
+            cmdlines.append(hglib.buildcmdargs(self.command, *[
+                hglib.escapepath(hglib.tounicode(f)) for f in lfiles
+            ], **lopts))
         self.files = files + lfiles
 
-        ucmdlines = [pycompat.maplist(hglib.tounicode, xs) for xs in cmdlines]
-        self._cmdsession = sess = self._repoagent.runCommandSequence(ucmdlines,
+        self._cmdsession = sess = self._repoagent.runCommandSequence(cmdlines,
                                                                      self)
         sess.commandFinished.connect(self.commandFinished)
         sess.progressReceived.connect(self.statusbar.setProgress)
         self._cmddialog.setSession(sess)
-        self.bb.button(QDialogButtonBox.Ok).setEnabled(False)
+        self.bb.button(QDialogButtonBox.StandardButton.Ok).setEnabled(False)
 
     def commandFinished(self, ret):
-        self.bb.button(QDialogButtonBox.Ok).setEnabled(True)
+        self.bb.button(QDialogButtonBox.StandardButton.Ok).setEnabled(True)
         self.statusbar.clearProgress()
         if ret == 0:
             shlib.shell_notify(self.files)
@@ -330,4 +337,4 @@ def run(ui, repoagent, *pats, **opts):
         return HeadlessQuickop(repoagent, cmdline)
     else:
         os.chdir(repo.root)  # for scmutil.match() in StatusThread
-        return QuickOpDialog(repoagent, command, pats, None)
+        return QuickOpDialog(repoagent, hglib.tounicode(command), pats, None)
