@@ -68,7 +68,7 @@ class RebaseDialog(QDialog):
         super(RebaseDialog, self).__init__(parent)
         self.setWindowIcon(qtlib.geticon('hg-rebase'))
         self.setWindowFlags(self.windowFlags()
-                            & ~Qt.WindowContextHelpButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint)
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         repo = repoagent.rawRepo()
@@ -147,13 +147,13 @@ class RebaseDialog(QDialog):
         box.addWidget(self._stbar)
 
         bbox = QDialogButtonBox()
-        self.cancelbtn = bbox.addButton(QDialogButtonBox.Cancel)
+        self.cancelbtn = bbox.addButton(QDialogButtonBox.StandardButton.Cancel)
         self.cancelbtn.clicked.connect(self.reject)
         self.rebasebtn = bbox.addButton(_('Rebase'),
-                                        QDialogButtonBox.ActionRole)
+                                        QDialogButtonBox.ButtonRole.ActionRole)
         self.rebasebtn.clicked.connect(self.rebase)
         self.abortbtn = bbox.addButton(_('Abort'),
-                                       QDialogButtonBox.ActionRole)
+                                       QDialogButtonBox.ButtonRole.ActionRole)
         self.abortbtn.clicked.connect(self.abort)
         box.addWidget(bbox)
         self.bbox = bbox
@@ -339,8 +339,8 @@ class RebaseDialog(QDialog):
         if hglib.rebase_in_progress(self.repo):
             main = _('Exiting with an unfinished rebase is not recommended.')
             text = _('Consider aborting the rebase first.')
-            labels = ((QMessageBox.Yes, _('&Exit')),
-                      (QMessageBox.No, _('Cancel')))
+            labels = ((QMessageBox.StandardButton.Yes, _('&Exit')),
+                      (QMessageBox.StandardButton.No, _('Cancel')))
             if not qtlib.QuestionMsgBox(_('Confirm Exit'), main, text,
                                         labels=labels, parent=self):
                 return
