@@ -30,7 +30,7 @@ from .qtgui import (
 
 from mercurial import (
     patch,
-    pycompat,
+    util,
 )
 
 from ..util import hglib
@@ -49,18 +49,18 @@ class RejectsDialog(QDialog):
         super(RejectsDialog, self).__init__(parent)
         self.setWindowTitle(_('Merge rejected patch chunks into %s') %
                             hglib.tounicode(path))
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
         self.path = path
 
         layout = QVBoxLayout()
         self.setLayout(layout)
         editor = qscilib.Scintilla()
-        editor.setBraceMatching(qsci.SloppyBraceMatch)
-        editor.setFolding(qsci.BoxedTreeFoldStyle)
+        editor.setBraceMatching(qsci.BraceMatch.SloppyBraceMatch)
+        editor.setFolding(qsci.FoldStyle.BoxedTreeFoldStyle)
         editor.installEventFilter(qscilib.KeyPressInterceptor(self))
-        editor.setContextMenuPolicy(Qt.CustomContextMenu)
+        editor.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         editor.customContextMenuRequested.connect(self._onMenuRequested)
-        self.baseLineColor = editor.markerDefine(qsci.Background, -1)
+        self.baseLineColor = editor.markerDefine(qsci.MarkerSymbol.Background, -1)
         editor.setMarkerBackgroundColor(QColor('lightblue'), self.baseLineColor)
         layout.addWidget(editor, 3)
 
@@ -70,8 +70,8 @@ class RejectsDialog(QDialog):
         searchbar.hide()
         def showsearchbar():
             searchbar.show()
-            searchbar.setFocus(Qt.OtherFocusReason)
-        qtlib.newshortcutsforstdkey(QKeySequence.Find, self, showsearchbar)
+            searchbar.setFocus(Qt.FocusReason.OtherFocusReason)
+        qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Find, self, showsearchbar)
         self.addActions(searchbar.editorActions())
         layout.addWidget(searchbar)
 
@@ -108,12 +108,11 @@ class RejectsDialog(QDialog):
         fileencoding.checkActionByName(self.textencgroup,
                                        fileencoding.contentencoding(ui))
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Save|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Save|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         layout.addWidget(bb)
-        self.saveButton = bb.button(BB.Save)
+        self.saveButton = bb.button(QDialogButtonBox.StandardButton.Save)
 
         s = QSettings()
         self.restoreGeometry(qtlib.readByteArray(s, 'rejects/geometry'))
@@ -133,7 +132,7 @@ class RejectsDialog(QDialog):
         editor.setMarginLineNumbers(1, True)
         editor.setMarginWidth(1, str(editor.lines())+'X')
 
-        buf = pycompat.bytesio()
+        buf = util.bytesio()
         try:
             buf.write(b'diff -r aaaaaaaaaaaa -r bbbbbbbbbbb %s\n' % path)
             with open(path + b'.rej', 'rb') as fp:
@@ -199,7 +198,7 @@ class RejectsDialog(QDialog):
     def showChunk(self, row):
         if row == -1 or self.updating:
             return
-        buf = pycompat.bytesio()
+        buf = util.bytesio()
         chunk = self.chunks[row]
         chunk.write(buf)
         chunkstr = buf.getvalue().decode(self._textEncoding(), 'replace')
@@ -251,8 +250,8 @@ class RejectsDialog(QDialog):
                   "would mean that you would lose them forever!\n\n"
                   "Click Yes to accept the file as is or No to continue "
                   "resolving the rejected patch chunks."),
-                QMessageBox.Yes, QMessageBox.No)
-            if action == QMessageBox.Yes:
+                QMessageBox.StandardButton.Yes, QMessageBox.StandardButton.No)
+            if action == QMessageBox.StandardButton.Yes:
                 acceptresolution = True
 
         if acceptresolution:
@@ -278,14 +277,14 @@ class RejectBrowser(qscilib.Scintilla):
         self.installEventFilter(qscilib.KeyPressInterceptor(self))
         self.setCaretLineVisible(False)
 
-        self.setMarginType(1, qsci.SymbolMargin)
+        self.setMarginType(1, qsci.MarginType.SymbolMargin)
         self.setMarginLineNumbers(1, False)
-        self.setMarginWidth(1, QFontMetrics(self.font()).width('XX'))
+        self.setMarginWidth(1, QFontMetrics(self.font()).horizontalAdvance('XX'))
         self.setMarginSensitivity(1, True)
-        self.addedMark = self.markerDefine(qsci.Plus, -1)
-        self.removedMark = self.markerDefine(qsci.Minus, -1)
-        self.addedColor = self.markerDefine(qsci.Background, -1)
-        self.removedColor = self.markerDefine(qsci.Background, -1)
+        self.addedMark = self.markerDefine(qsci.MarkerSymbol.Plus, -1)
+        self.removedMark = self.markerDefine(qsci.MarkerSymbol.Minus, -1)
+        self.addedColor = self.markerDefine(qsci.MarkerSymbol.Background, -1)
+        self.removedColor = self.markerDefine(qsci.MarkerSymbol.Background, -1)
         self.setMarkerBackgroundColor(QColor('lightgreen'), self.addedColor)
         self.setMarkerBackgroundColor(QColor('cyan'), self.removedColor)
         mask = (1 << self.addedMark) | (1 << self.removedMark) | \
