@@ -55,7 +55,7 @@ class RenameWidget(cmdui.AbstractCmdWidget):
                  iscopy=False):
         # type: (RepoAgent, Optional[QWidget], Optional[Text], Optional[Text], bool) -> None
         super(RenameWidget, self).__init__(parent)
-        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._repoagent = repoagent
 
         form = QFormLayout()
@@ -147,11 +147,11 @@ class RenameWidget(cmdui.AbstractCmdWidget):
         if os.path.isfile(self._sourceFile()):
             caption = _('Select Source File')
             path, _filter = FD.getOpenFileName(self, caption, '', '', '',
-                                               FD.ReadOnly)
+                                               QFileDialog.Option.ReadOnly)
         else:
             caption = _('Select Source Folder')
             path = FD.getExistingDirectory(self, caption, '',
-                                           FD.ShowDirsOnly | FD.ReadOnly)
+                                           QFileDialog.Option.ShowDirsOnly | QFileDialog.Option.ReadOnly)
         relpath = self.to_relative_path(path)
         if not relpath:
             return
@@ -232,7 +232,7 @@ class RenameWidget(cmdui.AbstractCmdWidget):
             res = qtlib.QuestionMsgBox(self.msgTitle, '<p>%s</p><p>%s</p>' %
                     (_('Destination file already exists.'),
                     _('Are you sure you want to overwrite it ?')),
-                    defaultbutton=QMessageBox.No)
+                    defaultbutton=QMessageBox.StandardButton.No)
             if not res:
                 return cmdcore.nullCmdSession()
 
