@@ -132,7 +132,7 @@ class SelectAllLineEdit(QLineEdit):
         self.just_got_focus = False
 
     def focusInEvent(self, ev):
-        if ev.reason() == Qt.MouseFocusReason:
+        if ev.reason() == Qt.FocusReason.MouseFocusReason:
             self.just_got_focus = True
         super(SelectAllLineEdit, self).focusInEvent(ev)
 
@@ -185,13 +185,13 @@ class RepoFilterBar(QToolBar):
 
         self.revsetcombo = combo = QComboBox()
         combo.setEditable(True)
-        combo.setInsertPolicy(QComboBox.NoInsert)
+        combo.setInsertPolicy(QComboBox.InsertPolicy.NoInsert)
         # don't calculate size hint from history contents, just use as much
         # space as possible. this way, the branch combo can be enlarged up
         # to its preferred width.
         combo.setSizeAdjustPolicy(
-            QComboBox.AdjustToMinimumContentsLengthWithIcon)
-        combo.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+            QComboBox.SizeAdjustPolicy.AdjustToMinimumContentsLengthWithIcon)
+        combo.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         combo.setMinimumContentsLength(20)
         qtlib.allowCaseChangingInput(combo)
         le = combo.lineEdit()
@@ -228,7 +228,7 @@ class RepoFilterBar(QToolBar):
         self.editorBtn.clicked.connect(self.openEditor)
         self.addWidget(self.editorBtn)
 
-        icon = self.style().standardIcon(QStyle.SP_TrashIcon)
+        icon = self.style().standardIcon(QStyle.StandardPixmap.SP_TrashIcon)
         self.deleteBtn = QToolButton()
         self.deleteBtn.setIcon(icon)
         self.deleteBtn.setToolTip(_('Delete selected query from history'))
@@ -293,7 +293,7 @@ class RepoFilterBar(QToolBar):
 
     def eventFilter(self, watched, event):
         if watched is self.revsetcombo.lineEdit():
-            if event.type() == QEvent.Resize:
+            if event.type() == QEvent.Type.Resize:
                 self._updateQueryTypeGeometry()
             return False
         return super(RepoFilterBar, self).eventFilter(watched, event)
@@ -422,7 +422,7 @@ class RepoFilterBar(QToolBar):
 
     def _initBranchFilter(self):
         self._branchLabel = QToolButton(
-            text=_('Branch'), popupMode=QToolButton.InstantPopup,
+            text=_('Branch'), popupMode=QToolButton.ToolButtonPopupMode.InstantPopup,
             statusTip=_('Display graph the named branch only'))
         self._branchMenu = QMenu(self._branchLabel)
         self._abranchAction = self._branchMenu.addAction(
@@ -438,8 +438,8 @@ class RepoFilterBar(QToolBar):
 
         self._branchCombo = QComboBox()
         self._branchCombo.setEditable(True)
-        self._branchCombo.setInsertPolicy(QComboBox.NoInsert)
-        self._branchCombo.setSizeAdjustPolicy(QComboBox.AdjustToContents)
+        self._branchCombo.setInsertPolicy(QComboBox.InsertPolicy.NoInsert)
+        self._branchCombo.setSizeAdjustPolicy(QComboBox.SizeAdjustPolicy.AdjustToContents)
         self._branchCombo.setLineEdit(SelectAllLineEdit())
         self._branchCombo.lineEdit().editingFinished.connect(
             self._lineBranchChanged)
@@ -448,7 +448,7 @@ class RepoFilterBar(QToolBar):
         self._branchCombo.currentIndexChanged.connect(self._emitBranchChanged)
         completer = QCompleter(self._branchCombo.model(), self._branchCombo)
         if hasattr(completer, 'setFilterMode'):  # Qt>=5.2
-            completer.setFilterMode(Qt.MatchContains)
+            completer.setFilterMode(Qt.MatchFlag.MatchContains)
         self._branchCombo.setCompleter(completer)
 
         self.addWidget(self._branchLabel)
@@ -502,7 +502,7 @@ class RepoFilterBar(QToolBar):
         self._branchCombo.setItemData(self._branchCombo.count() - 1, '')
         for i, branch in enumerate(branches, self._branchCombo.count()):
             self._branchCombo.addItem(branch)
-            self._branchCombo.setItemData(i, branch, Qt.ToolTipRole)
+            self._branchCombo.setItemData(i, branch, Qt.ItemDataRole.ToolTipRole)
             self._branchCombo.setItemData(i, branch)
         self._branchCombo.setEnabled(self.filterEnabled and bool(branches))
         self.setBranch(curbranch)
