@@ -119,9 +119,10 @@ ALLCOLUMNS = tuple(name for name, _text in COLUMNHEADERS)
 UNAPPLIED_PATCH_COLOR = QColor('#999999')
 HIDDENREV_COLOR = QColor('#666666')
 TROUBLED_COLOR = QColor(172, 34, 34)
+PUBLISHED_TOPIC_COLOR = QColor('#666666')
 
-GraphNodeRole = Qt.UserRole + 0
-LabelsRole = Qt.UserRole + 1  # [(text, style), ...]
+GraphNodeRole = Qt.ItemDataRole.UserRole + 0
+LabelsRole = Qt.ItemDataRole.UserRole + 1  # [(text, style), ...]
 
 def _parsebranchcolors(value):
     # type: (Text) -> List[Tuple[Text, Text]]
@@ -559,22 +560,22 @@ class HgRepoListModel(QAbstractTableModel):
             self._branch_colors[branch] = graph.COLORS[idx]
         return self._branch_colors[branch]
 
-    def data(self, index, role=Qt.DisplayRole):
+    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
         # type: (QModelIndex, int) -> Any
         if not index.isValid():
             return None
         gnode = self.graph[index.row()]
-        if role == Qt.DisplayRole:
+        if role == Qt.ItemDataRole.DisplayRole:
             if self._hasFileColumn() and index.column() == FileColumn:
                 return hglib.tounicode(gnode.extra[0])
-        if role == Qt.FontRole:
+        if role == Qt.ItemDataRole.FontRole:
             if index.column() in (NodeColumn, GitNodeColumn, ConvertedColumn):
                 return QFont("Monospace")
             if index.column() == DescColumn and gnode.wdparent:
                 font = QApplication.font('QAbstractItemView')
                 font.setBold(True)
                 return font
-        if role == Qt.ForegroundRole:
+        if role == Qt.ItemDataRole.ForegroundRole:
             if (gnode.shape == graph.NODE_SHAPE_UNAPPLIEDPATCH
                 and index.column() != DescColumn):
                 return UNAPPLIED_PATCH_COLOR
@@ -587,7 +588,7 @@ class HgRepoListModel(QAbstractTableModel):
         except error.RevlogError as e:
             if 'THGDEBUG' in os.environ:
                 raise
-            if role == Qt.DisplayRole:
+            if role == Qt.ItemDataRole.DisplayRole:
                 return hglib.tounicode(str(e))
             else:
                 return None
@@ -621,12 +622,12 @@ class HgRepoListModel(QAbstractTableModel):
         gnode = self.graph[row]
         ctx = self.repo[gnode.rev]
 
-        if role == Qt.DisplayRole:
+        if role == Qt.ItemDataRole.DisplayRole:
             textfunc = self._columnmap.get(column)
             if textfunc is None:
                 return None
             return textfunc(self, ctx)
-        elif role == Qt.ForegroundRole:
+        elif role == Qt.ItemDataRole.ForegroundRole:
             color = None
             if gnode.instabilities:
                 color = TROUBLED_COLOR
@@ -641,6 +642,11 @@ class HgRepoListModel(QAbstractTableModel):
                         color = HIDDENREV_COLOR
                     else:
                         color = color.lighter()
+            if column == TopicColumn and not ctx.mutable():
+                if color is None:
+                    color = PUBLISHED_TOPIC_COLOR
+                else:
+                    color = color.lighter()
             return color
         elif role == LabelsRole and column == DescColumn:
             return self._getrevlabels(ctx)
@@ -656,14 +662,14 @@ class HgRepoListModel(QAbstractTableModel):
         row = index.row()
         if row >= len(self.graph) and not self.repo.ui.debugflag:
             # TODO: should not happen; internal data went wrong (issue #754)
-            return Qt.NoItemFlags
+            return Qt.ItemFlag.NoItemFlags
         rev, isunapplied = self.graph.getrevstate(row)
         if not self.isActiveRev(rev):
-            return Qt.NoItemFlags
+            return Qt.ItemFlag.NoItemFlags
         if isunapplied:
-            flags |= Qt.ItemIsDragEnabled | Qt.ItemIsDropEnabled
+            flags |= Qt.ItemFlag.ItemIsDragEnabled | Qt.ItemFlag.ItemIsDropEnabled
         if rev is None:
-            flags |= Qt.ItemIsDropEnabled
+            flags |= Qt.ItemFlag.ItemIsDropEnabled
         return flags
 
     def isActiveRev(self, rev):
@@ -680,7 +686,7 @@ class HgRepoListModel(QAbstractTableModel):
         return [mqpatchmimetype]
 
     def supportedDropActions(self):
-        return Qt.MoveAction
+        return Qt.DropAction.MoveAction
 
     def mimeData(self, indexes):
         # type: (List[QModelIndex]) -> QMimeData
@@ -719,9 +725,9 @@ class HgRepoListModel(QAbstractTableModel):
         self._repoagent.runCommand(cmdline)
         return True
 
-    def headerData(self, section, orientation, role=Qt.DisplayRole):
+    def headerData(self, section, orientation, role=Qt.ItemDataRole.DisplayRole):
         # type: (int, int, int) -> Optional[Text]
-        if orientation == Qt.Horizontal and role == Qt.DisplayRole:
+        if orientation == Qt.Orientation.Horizontal and role == Qt.ItemDataRole.DisplayRole:
             return self.allColumnHeaders()[section][1]
 
     def defaultIndex(self):
@@ -739,7 +745,7 @@ class HgRepoListModel(QAbstractTableModel):
         if self._selectedrevs and rev not in self._selectedrevs:
             rev = max(self._selectedrevs)
         index = self.indexFromRev(rev)
-        if index.flags() & Qt.ItemIsEnabled:
+        if index.flags() & Qt.ItemFlag.ItemIsEnabled:
             return index
 
         if self._filterbranch:
@@ -750,7 +756,7 @@ class HgRepoListModel(QAbstractTableModel):
                 if not isinstance(gnode.rev, int):
                     continue
                 index = self.index(row, 0)
-                if index.flags() & Qt.ItemIsEnabled:
+                if index.flags() & Qt.ItemFlag.ItemIsEnabled:
                     return index
         return QModelIndex()
 
@@ -927,7 +933,7 @@ class HgRepoListModel(QAbstractTableModel):
             cvt = extra.get(b'convert_revision', b'')
             if cvt:
                 if cvt.startswith(b'svn:'):
-                    return hglib.tounicode(cvt.split(b'@')[-1])
+                    return pycompat.unicode(cvt.split(b'@')[-1], 'utf-8', 'replace')
                 if len(cvt) == 40:
                     try:
                         binascii.unhexlify(cvt)
