@@ -81,12 +81,12 @@ class RepoTreeView(QTreeView):
         self.setDragEnabled(True)
         self.setAcceptDrops(True)
         self.setAutoScroll(True)
-        self.setDragDropMode(QAbstractItemView.DragDrop)
-        self.setDefaultDropAction(Qt.MoveAction)
+        self.setDragDropMode(QAbstractItemView.DragDropMode.DragDrop)
+        self.setDefaultDropAction(Qt.DropAction.MoveAction)
         self.setDropIndicatorShown(True)
-        self.setEditTriggers(QAbstractItemView.DoubleClicked
-                             | QAbstractItemView.EditKeyPressed)
-        self.setSelectionBehavior(QAbstractItemView.SelectRows)
+        self.setEditTriggers(QAbstractItemView.EditTrigger.DoubleClicked
+                             | QAbstractItemView.EditTrigger.EditKeyPressed)
+        self.setSelectionBehavior(QAbstractItemView.SelectionBehavior.SelectRows)
 
     def dragEnterEvent(self, event):
         if event.source() is self:
@@ -98,9 +98,9 @@ class RepoTreeView(QTreeView):
         for u in d.urls():
             root = paths.find_root(u.toLocalFile())
             if root:
-                event.setDropAction(Qt.LinkAction)
+                event.setDropAction(Qt.DropAction.LinkAction)
                 event.accept()
-                self.setState(QAbstractItemView.DraggingState)
+                self.setState(QAbstractItemView.State.DraggingState)
                 break
 
     def dropLocation(self, event):
@@ -115,7 +115,7 @@ class RepoTreeView(QTreeView):
             indicator = self.dropIndicatorPosition()
             group = index.parent()
             row = index.row()
-            if indicator == QAbstractItemView.BelowItem:
+            if indicator == QAbstractItemView.DropIndicatorPosition.BelowItem:
                 row = index.row() + 1
 
         return index, group, row
@@ -164,22 +164,22 @@ class RepoTreeView(QTreeView):
                         m.loadSubrepos(repoindex)
                         accept = True
                 if accept:
-                    event.setDropAction(Qt.LinkAction)
+                    event.setDropAction(Qt.DropAction.LinkAction)
                     event.accept()
                     self.dropAccepted.emit()
         self.setAutoScroll(False)
-        self.setState(QAbstractItemView.NoState)
+        self.setState(QAbstractItemView.State.NoState)
         self.viewport().update()
         self.setAutoScroll(True)
 
     def keyPressEvent(self, event):
-        if (event.key() in (Qt.Key_Enter, Qt.Key_Return)
-            and self.state() != QAbstractItemView.EditingState):
+        if (event.key() in (Qt.Key.Key_Enter, Qt.Key.Key_Return)
+            and self.state() != QAbstractItemView.State.EditingState):
             index = self.currentIndex()
             if index.isValid():
                 self.openRequested.emit(index)
                 return
-        if event.key() == Qt.Key_Delete:
+        if event.key() == Qt.Key.Key_Delete:
             index = self.currentIndex()
             if index.isValid():
                 self.removeRequested.emit(index)
@@ -195,7 +195,7 @@ class RepoTreeView(QTreeView):
             self.msg  = item.details()
         self.showMessage.emit(self.msg)
 
-        if event.buttons() == Qt.NoButton:
+        if event.buttons() == Qt.MouseButton.NoButton:
             # Bail out early to avoid tripping over this bug:
             # https://bugreports.qt.io/browse/QTBUG-10180
             return
@@ -215,7 +215,7 @@ class RepoTreeView(QTreeView):
 
     def sizeHint(self):
         size = super(RepoTreeView, self).sizeHint()
-        size.setWidth(QFontMetrics(self.font()).width('M') * 15)
+        size.setWidth(QFontMetrics(self.font()).horizontalAdvance('M') * 15)
         return size
 
 class RepoRegistryView(QDockWidget):
@@ -234,9 +234,9 @@ class RepoRegistryView(QDockWidget):
         self.watcher = None
         self._setupSettingActions()
 
-        self.setFeatures(QDockWidget.DockWidgetClosable |
-                         QDockWidget.DockWidgetMovable  |
-                         QDockWidget.DockWidgetFloatable)
+        self.setFeatures(QDockWidget.DockWidgetFeature.DockWidgetClosable |
+                         QDockWidget.DockWidgetFeature.DockWidgetMovable  |
+                         QDockWidget.DockWidgetFeature.DockWidgetFloatable)
         self.setWindowTitle(_('Repository Registry'))
 
         mainframe = QFrame()
@@ -252,7 +252,7 @@ class RepoRegistryView(QDockWidget):
         tv.setFirstColumnSpanned(0, QModelIndex(), True)
         tv.setColumnHidden(1, True)
 
-        tv.setContextMenuPolicy(Qt.CustomContextMenu)
+        tv.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         tv.customContextMenuRequested.connect(self._onMenuRequested)
         tv.showMessage.connect(self.showMessage)
         tv.openRequested.connect(self._openRepoAt)
@@ -556,7 +556,15 @@ class RepoRegistryView(QDockWidget):
         self.cloneRepoRequested.emit(self._currentRepoRoot())
 
     def explore(self):
-        qtlib.openlocalurl(self._currentRepoRoot())
+        # On Windows, opening a directory URL can lead to running an
+        # executable file instead if this file has the same base name
+        # than the directory (ex: opening "C:\MyDir" will run
+        # "C:\MyDir.bat" instead if it exists).
+        # Make sure that there is a directory separator at the end of
+        # the path to be explicit about the fact that this URL is
+        # expected to be a directory.
+        repoRootDirectory = os.path.join(self._currentRepoRoot(), '')
+        qtlib.openlocalurl(repoRootDirectory)
 
     def terminal(self):
         model = self.tview.model()
@@ -571,7 +579,7 @@ class RepoRegistryView(QDockWidget):
         caption = _('Select repository directory to add')
         FD = QFileDialog
         path = FD.getExistingDirectory(caption=caption,
-                                       options=FD.ShowDirsOnly | FD.ReadOnly)
+                                       options=QFileDialog.Option.ShowDirsOnly | QFileDialog.Option.ReadOnly)
         if path:
             m = self.tview.model()
             assert m is not None
@@ -586,7 +594,7 @@ class RepoRegistryView(QDockWidget):
         caption = _('Select an existing repository to add as a subrepo')
         FD = QFileDialog
         path = pycompat.unicode(FD.getExistingDirectory(caption=caption,
-            directory=root, options=FD.ShowDirsOnly | FD.ReadOnly))
+            directory=root, options=QFileDialog.Option.ShowDirsOnly | QFileDialog.Option.ReadOnly))
         if path:
             path = os.path.normpath(path)
             sroot = paths.find_root(path)
@@ -838,8 +846,8 @@ class RepoRegistryView(QDockWidget):
         if 'remove' not in item.menulist():  # check capability
             return
         if not item.okToDelete():
-            labels = [(QMessageBox.Yes, _('&Delete')),
-                      (QMessageBox.No, _('Cancel'))]
+            labels = [(QMessageBox.StandardButton.Yes, _('&Delete')),
+                      (QMessageBox.StandardButton.No, _('Cancel'))]
             if not qtlib.QuestionMsgBox(_('Confirm Delete'),
                                         _("Delete Group '%s' and all its "
                                           "entries?") % item.name,
