@@ -215,7 +215,7 @@ class RepoTreeItem(object):
         return []
 
     def flags(self):
-        return Qt.NoItemFlags
+        return Qt.ItemFlag.NoItemFlags
 
     def removeRows(self, row, count):
         cs = self.childs
@@ -253,7 +253,7 @@ class RepoTreeItem(object):
         return True
 
     def getSupportedDragDropActions(self):
-        return Qt.MoveAction
+        return Qt.DropAction.MoveAction
 
 
 class RepoItem(RepoTreeItem):
@@ -297,7 +297,7 @@ class RepoItem(RepoTreeItem):
             self._shortname = uname
 
     def data(self, column, role):
-        if role == Qt.DecorationRole and column == 0:
+        if role == Qt.ItemDataRole.DecorationRole and column == 0:
             baseiconname = 'hg'
             if paths.is_unc_path(self.rootpath()):
                 baseiconname = 'thg-remote-repo'
@@ -307,7 +307,7 @@ class RepoItem(RepoTreeItem):
             elif self._sharedpath:
                 ico = qtlib.getoverlaidicon(ico, qtlib.geticon('hg-sharedrepo'))
             return ico
-        elif role in (Qt.DisplayRole, Qt.EditRole):
+        elif role in (Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole):
             return [self.shortname, self.shortpath][column]()
 
     def getCommonPath(self):
@@ -341,8 +341,8 @@ class RepoItem(RepoTreeItem):
         return acts
 
     def flags(self):
-        return (Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsDragEnabled
-            | Qt.ItemIsEditable)
+        return (Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsDragEnabled
+            | Qt.ItemFlag.ItemIsEditable)
 
     def dump(self, xw):
         xw.writeAttribute('root', self._root)
@@ -440,9 +440,9 @@ class RepoItem(RepoTreeItem):
                 % (rootpath, hglib.tounicode(str(e)))
             res = qtlib.WarningMsgBox(_('Error loading subrepos'),
                                 warningMessage,
-                                buttons = QMessageBox.Ok | QMessageBox.Abort)
+                                buttons = QMessageBox.StandardButton.Ok | QMessageBox.StandardButton.Abort)
             # Let the user abort so that he gets the full exception info
-            if res == QMessageBox.Abort:
+            if res == QMessageBox.StandardButton.Abort:
                 raise
         return invalidRepoList
 
@@ -483,7 +483,7 @@ class StandaloneSubrepoItem(RepoItem):
     xmltagname = 'subrepo'
 
     def data(self, column, role):
-        if role == Qt.DecorationRole and column == 0:
+        if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon('hg', valid=self._valid)
         else:
             return super(StandaloneSubrepoItem, self).data(column, role)
@@ -493,7 +493,7 @@ class SubrepoItem(RepoItem):
     xmltagname = 'subrepo'
 
     def data(self, column, role):
-        if role == Qt.DecorationRole and column == 0:
+        if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon('hg', valid=self._valid)
         else:
             return super(SubrepoItem, self).data(column, role)
@@ -507,10 +507,10 @@ class SubrepoItem(RepoItem):
         return acts
 
     def getSupportedDragDropActions(self):
-        return Qt.CopyAction
+        return Qt.DropAction.CopyAction
 
     def flags(self):
-        return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsDragEnabled
+        return Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsDragEnabled
 
 # possibly this should not be a RepoItem because it lacks common functions
 class AlienSubrepoItem(RepoItem):
@@ -522,7 +522,7 @@ class AlienSubrepoItem(RepoItem):
         self._repotype = repotype
 
     def data(self, column, role):
-        if role == Qt.DecorationRole and column == 0:
+        if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon(self._repotype)
         else:
             return super(AlienSubrepoItem, self).data(column, role)
@@ -531,7 +531,7 @@ class AlienSubrepoItem(RepoItem):
         return ['explore', 'terminal', 'copypath']
 
     def flags(self):
-        return Qt.ItemIsEnabled | Qt.ItemIsSelectable
+        return Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsSelectable
 
     def repotype(self):
         return self._repotype
@@ -574,10 +574,10 @@ class RepoGroupItem(RepoTreeItem):
         self._commonpath = ''
 
     def data(self, column, role):
-        if role == Qt.DecorationRole:
+        if role == Qt.ItemDataRole.DecorationRole:
             if column == 0:
                 s = QApplication.style()
-                ico = s.standardIcon(QStyle.SP_DirIcon)
+                ico = s.standardIcon(QStyle.StandardPixmap.SP_DirIcon)
                 return ico
             return None
         if column == 0:
@@ -604,8 +604,8 @@ class RepoGroupItem(RepoTreeItem):
             'reloadRegistry']
 
     def flags(self):
-        return (Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsDropEnabled
-            | Qt.ItemIsDragEnabled | Qt.ItemIsEditable)
+        return (Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsDropEnabled
+            | Qt.ItemFlag.ItemIsDragEnabled | Qt.ItemFlag.ItemIsEditable)
 
     def childRoots(self):
         return [c._root for c in self.childs if isinstance(c, RepoItem)]
