@@ -74,7 +74,7 @@ def iterRepoItemFromXml(source):
     xr = QXmlStreamReader(source)
     while not xr.atEnd():
         t = xr.readNext()
-        if (t == QXmlStreamReader.StartElement
+        if (t == QXmlStreamReader.TokenType.StartElement
             and xr.name() in ('repo', 'subrepo')):
             rti = repotreeitem.undumpObject(xr)
             assert isinstance(rti, repotreeitem.RepoItem)
@@ -104,7 +104,7 @@ class RepoTreeModel(QAbstractItemModel):
 
         root = None
         if f:
-            if f.open(QIODevice.ReadOnly):
+            if f.open(QIODevice.OpenModeFlag.ReadOnly):
                 root = readXml(f, reporegistryXmlElementName)
                 f.close()
 
@@ -163,35 +163,35 @@ class RepoTreeModel(QAbstractItemModel):
         else:
             return self.rootItem.columnCount()
 
-    def data(self, index, role=Qt.DisplayRole):
+    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
         if not index.isValid():
             return None
-        if role not in (Qt.DisplayRole, Qt.EditRole, Qt.DecorationRole,
-                Qt.FontRole):
+        if role not in (Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole, Qt.ItemDataRole.DecorationRole,
+                Qt.ItemDataRole.FontRole):
             return None
         item = index.internalPointer()
-        if role == Qt.FontRole and item is self._activeRepoItem:
+        if role == Qt.ItemDataRole.FontRole and item is self._activeRepoItem:
             font = QFont()
             font.setBold(True)
             return font
         else:
             return item.data(index.column(), role)
 
-    def headerData(self, section, orientation, role=Qt.DisplayRole):
-        if role == Qt.DisplayRole:
-            if orientation == Qt.Horizontal:
+    def headerData(self, section, orientation, role=Qt.ItemDataRole.DisplayRole):
+        if role == Qt.ItemDataRole.DisplayRole:
+            if orientation == Qt.Orientation.Horizontal:
                 if section == 1:
                     return _('Path')
         return None
 
     def flags(self, index):
         if not index.isValid():
-            return Qt.NoItemFlags
+            return Qt.ItemFlag.NoItemFlags
         item = index.internalPointer()
         return item.flags()
 
     def supportedDropActions(self):
-        return Qt.CopyAction | Qt.MoveAction | Qt.LinkAction
+        return Qt.DropAction.CopyAction | Qt.DropAction.MoveAction | Qt.DropAction.LinkAction
 
     def removeRows(self, row, count, parent=QModelIndex()):
         item = parent.internalPointer()
@@ -244,7 +244,7 @@ class RepoTreeModel(QAbstractItemModel):
         if group is None:
             return False
         # Avoid copying subrepos multiple times
-        if Qt.CopyAction == action and self.getRepoItem(itemread.rootpath()):
+        if Qt.DropAction.CopyAction == action and self.getRepoItem(itemread.rootpath()):
             return False
         if row < 0:
             row = 0
@@ -255,8 +255,8 @@ class RepoTreeModel(QAbstractItemModel):
             self.allrepos = itemread
         return True
 
-    def setData(self, index, value, role=Qt.EditRole):
-        if not index.isValid() or role != Qt.EditRole:
+    def setData(self, index, value, role=Qt.ItemDataRole.EditRole):
+        if not index.isValid() or role != Qt.ItemDataRole.EditRole:
             return False
         if not value:
             return False
@@ -351,7 +351,7 @@ class RepoTreeModel(QAbstractItemModel):
 
     def write(self, fn):
         f = QFile(fn)
-        f.open(QIODevice.WriteOnly)
+        f.open(QIODevice.OpenModeFlag.WriteOnly)
         writeXml(f, self.rootItem, reporegistryXmlElementName)
         f.close()
 
