@@ -55,8 +55,7 @@ from .qtgui import (
     QProxyStyle,
     QSpinBox,
     QStyle,
-    QStyleOptionViewItemV2,
-    QStyleOptionViewItemV4,
+    QStyleOptionViewItem,
     QStyledItemDelegate,
     QTableView,
 )
@@ -95,14 +94,14 @@ class HgRepoView(QTableView):
         vh = self.verticalHeader()
         vh.hide()
         vh.setMinimumSectionSize(0)  # we'll set fixed size later
-        vh.setSectionResizeMode(QHeaderView.Fixed)
+        vh.setSectionResizeMode(QHeaderView.ResizeMode.Fixed)
 
         header = self.horizontalHeader()
         header.setSectionsClickable(False)
         header.setSectionsMovable(True)
-        header.setDefaultAlignment(Qt.AlignLeft)
+        header.setDefaultAlignment(Qt.AlignmentFlag.AlignLeft)
         header.setHighlightSections(False)
-        header.setContextMenuPolicy(Qt.CustomContextMenu)
+        header.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         header.customContextMenuRequested.connect(self.headerMenuRequest)
         header.sectionMoved.connect(self.columnsVisibilityChanged)
         header.sectionMoved.connect(self._saveColumnSettings)
@@ -116,10 +115,10 @@ class HgRepoView(QTableView):
                                       LabeledDelegate(self, margin=0))
 
         self.setAcceptDrops(True)
-        self.setDefaultDropAction(Qt.MoveAction)
+        self.setDefaultDropAction(Qt.DropAction.MoveAction)
         self.setDragEnabled(True)
         self.setDropIndicatorShown(True)
-        self.setDragDropMode(QAbstractItemView.InternalMove)
+        self.setDragDropMode(QAbstractItemView.DragDropMode.InternalMove)
 
         # do not pass self.style() to HgRepoViewStyle() because it would steal
         # the ownership from QApplication and cause SEGV after the deletion of
@@ -127,8 +126,8 @@ class HgRepoView(QTableView):
         self.setStyle(HgRepoViewStyle())
         self._paletteswitcher = qtlib.PaletteSwitcher(self)
 
-        self.setSelectionMode(QAbstractItemView.ExtendedSelection)
-        self.setSelectionBehavior(QAbstractItemView.SelectRows)
+        self.setSelectionMode(QAbstractItemView.SelectionMode.ExtendedSelection)
+        self.setSelectionBehavior(QAbstractItemView.SelectionBehavior.SelectRows)
 
         self.doubleClicked.connect(self.revActivated)
         if repoagent.configBool('tortoisehg', 'copy_hash_selection'):
@@ -142,7 +141,7 @@ class HgRepoView(QTableView):
         index = self.indexAt(event.pos())
         if not index.isValid():
             return
-        if event.button() == Qt.MidButton:
+        if event.button() == Qt.MouseButton.MiddleButton:
             self.gotoAncestor(index)
             return
         QTableView.mousePressEvent(self, event)
@@ -168,7 +167,7 @@ class HgRepoView(QTableView):
         dlg = ColumnSelectDialog(self.colselect[1],
                                  self.model(), self.visibleColumns())
         dlg.setRowHeight(self.defaultRowHeight())
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec_() == QDialog.DialogCode.Accepted:
             self.setVisibleColumns(dlg.selectedColumns())
             self.resizeColumns()
             self.setDefaultRowHeight(dlg.rowHeight())
@@ -305,7 +304,7 @@ class HgRepoView(QTableView):
             if isinstance(w, int):
                 pass
             elif w is not None:
-                w = fontm.width(hglib.tounicode(str(w)) + 'w')
+                w = fontm.horizontalAdvance(hglib.tounicode(str(w)) + 'w')
             else:
                 w = super(HgRepoView, self).sizeHintForColumn(c)
             self.setColumnWidth(c, w)
@@ -327,7 +326,7 @@ class HgRepoView(QTableView):
         if rev is not None:
             clip = QApplication.clipboard()
             if clip.supportsSelection():
-                clip.setText(str(self.repo[rev]), QClipboard.Selection)
+                clip.setText(str(self.repo[rev]), QClipboard.Mode.Selection)
 
     def revActivated(self, index):
         rev = self.revFromindex(index)
@@ -464,8 +463,8 @@ class HgRepoView(QTableView):
         assert model is not None
         idx = model.indexFromRev(rev)
         if idx.isValid():
-            flags = (QItemSelectionModel.ClearAndSelect
-                     | QItemSelectionModel.Rows)
+            flags = (QItemSelectionModel.SelectionFlag.ClearAndSelect
+                     | QItemSelectionModel.SelectionFlag.Rows)
             self.selectionModel().setCurrentIndex(idx, flags)
             self.scrollTo(idx)
 
@@ -528,7 +527,7 @@ class HgRepoViewStyle(QProxyStyle):
     "Override a style's drawPrimitive method to customize the drop indicator"
 
     def drawPrimitive(self, element, option, painter, widget=None):
-        if element == QStyle.PE_IndicatorItemViewItemDrop:
+        if element == QStyle.PrimitiveElement.PE_IndicatorItemViewItemDrop:
             # Drop indicators should be painted using the full viewport width
             if option.rect.height() != 0:
                 vp = widget.viewport().rect()
@@ -541,10 +540,10 @@ class HgRepoViewStyle(QProxyStyle):
 
 def get_style(line_type, active):
     if line_type == graph.LINE_TYPE_GRAFT:
-        return Qt.DashLine
+        return Qt.PenStyle.DashLine
     if line_type == graph.LINE_TYPE_OBSOLETE:
-        return Qt.DotLine
-    return Qt.SolidLine
+        return Qt.PenStyle.DotLine
+    return Qt.PenStyle.SolidLine
 
 def get_width(line_type, active):
     if line_type >= graph.LINE_TYPE_FAMILY or not active:
@@ -585,7 +584,7 @@ class GraphDelegate(QStyledItemDelegate):
         painter.save()
         try:
             painter.setClipRect(option.rect)
-            painter.setRenderHint(QPainter.Antialiasing)
+            painter.setRenderHint(QPainter.RenderHint.Antialiasing)
             painter.translate(option.rect.topLeft())
             self._drawEdges(painter, index, gnode, visibleend)
             if gnode.x < visibleend:
@@ -645,7 +644,7 @@ class GraphDelegate(QStyledItemDelegate):
             dot_color = QColor("gray")
             radius = self._dotradius() * 0.8
         else:
-            fg = index.data(Qt.ForegroundRole)
+            fg = index.data(Qt.ItemDataRole.ForegroundRole)
             if not fg:
                 # work around integrity error in HgRepoListModel, which may
                 # provide a valid index for stripped revision and data()
@@ -760,7 +759,7 @@ class _LabelsLayout(object):
             font.setBold(False)
         self._font = font
         fm = QFontMetrics(font)
-        self._twidths = [fm.width(t) for t, _s in labels]
+        self._twidths = [fm.horizontalAdvance(t) for t, _s in labels]
         self._th = fm.height()
         self._padw = 2
         self._padh = 1  # may overwrite horizontal frame to fit row
@@ -817,8 +816,8 @@ class LabeledDelegate(QStyledItemDelegate):
             return
         lay = self._makeLabelsLayout(labels, option)
         option.decorationSize = QSize(lay.width(), lay.height())
-        if isinstance(option, QStyleOptionViewItemV2):
-            option.features |= QStyleOptionViewItemV2.HasDecoration
+        if isinstance(option, QStyleOptionViewItem):
+            option.features |= QStyleOptionViewItem.ViewItemFeature.HasDecoration
 
     def paint(self, painter, option, index):
         super(LabeledDelegate, self).paint(painter, option, index)
@@ -826,13 +825,13 @@ class LabeledDelegate(QStyledItemDelegate):
         if not labels:
             return
 
-        option = QStyleOptionViewItemV4(option)
+        option = QStyleOptionViewItem(option)
         self.initStyleOption(option, index)
         if option.widget:
             style = option.widget.style()
         else:
             style = QApplication.style()
-        rect = style.subElementRect(QStyle.SE_ItemViewItemDecoration, option,
+        rect = style.subElementRect(QStyle.SubElement.SE_ItemViewItemDecoration, option,
                                     option.widget)
 
         # for maximum readability, use vivid color regardless of option.state
@@ -848,7 +847,7 @@ class LabeledDelegate(QStyledItemDelegate):
         size = super(LabeledDelegate, self).sizeHint(option, index)
         # give additional margins for each row (even if it has no labels
         # because all rows must have the same height)
-        option = QStyleOptionViewItemV4(option)
+        option = QStyleOptionViewItem(option)
         self.initStyleOption(option, index)
         lay = self._makeLabelsLayout([], option)
         return QSize(size.width(), max(size.height(), lay.height() + 2))
@@ -863,7 +862,7 @@ class ColumnSelectDialog(QDialog):
 
         self.setWindowTitle(name)
         self.setWindowFlags(self.windowFlags() & \
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
         self.setMinimumSize(250, 265)
 
         disabled = [c for c in all if c not in curcolumns]
@@ -877,16 +876,16 @@ class ColumnSelectDialog(QDialog):
         for c in curcolumns + disabled:
             item = QListWidgetItem(colnames[c])
             item.columnid = c
-            item.setFlags(Qt.ItemIsSelectable |
-                          Qt.ItemIsEnabled |
-                          Qt.ItemIsDragEnabled |
-                          Qt.ItemIsUserCheckable)
+            item.setFlags(Qt.ItemFlag.ItemIsSelectable |
+                          Qt.ItemFlag.ItemIsEnabled |
+                          Qt.ItemFlag.ItemIsDragEnabled |
+                          Qt.ItemFlag.ItemIsUserCheckable)
             if c in curcolumns:
-                item.setCheckState(Qt.Checked)
+                item.setCheckState(Qt.CheckState.Checked)
             else:
-                item.setCheckState(Qt.Unchecked)
+                item.setCheckState(Qt.CheckState.Unchecked)
             list.addItem(item)
-        list.setDragDropMode(QListView.InternalMove)
+        list.setDragDropMode(QListView.DragDropMode.InternalMove)
         layout.addRow(list)
         self.list = list
 
@@ -898,8 +897,7 @@ class ColumnSelectDialog(QDialog):
         layout.addRow(_('Row height'), edit)
 
         # dialog buttons
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         layout.addWidget(bb)
@@ -908,7 +906,7 @@ class ColumnSelectDialog(QDialog):
         cols = []
         for i in pycompat.xrange(self.list.count()):
             item = self.list.item(i)
-            if item.checkState() == Qt.Checked:
+            if item.checkState() == Qt.CheckState.Checked:
                 # TODO: better to use data(role) instead
                 cols.append(item.columnid)  # pytype: disable=attribute-error
         return cols
