@@ -71,8 +71,8 @@ class ResolveDialog(QDialog):
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         self.setWindowFlags(self.windowFlags()
-                            & ~Qt.WindowContextHelpButtonHint
-                            | Qt.WindowMaximizeButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint
+                            | Qt.WindowType.WindowMaximizeButtonHint)
         self.setWindowTitle(_('Resolve Conflicts - %s')
                             % repoagent.displayName())
         self.setWindowIcon(qtlib.geticon('hg-merge'))
@@ -87,7 +87,7 @@ class ResolveDialog(QDialog):
 
         self.refreshButton = tb = QToolButton(self)
         tb.setIcon(qtlib.geticon('view-refresh'))
-        tb.setShortcut(QKeySequence.Refresh)
+        tb.setShortcut(QKeySequence.StandardKey.Refresh)
         tb.clicked.connect(self.refresh)
         self.stlabel = QLabel()
         hbox.addWidget(tb)
@@ -138,12 +138,12 @@ class ResolveDialog(QDialog):
         self.layout().addLayout(hbox)
 
         self.utree = QTreeView(self)
-        self.utree.setDragDropMode(QTreeView.DragOnly)
-        self.utree.setSelectionMode(QTreeView.ExtendedSelection)
+        self.utree.setDragDropMode(QTreeView.DragDropMode.DragOnly)
+        self.utree.setSelectionMode(QTreeView.SelectionMode.ExtendedSelection)
         self.utree.setSortingEnabled(True)
         hbox.addWidget(self.utree)
 
-        self.utree.setContextMenuPolicy(Qt.CustomContextMenu)
+        self.utree.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.utreecmenu = QMenu(self)
         mergeactions = QActionGroup(self)
         mergeactions.triggered.connect(self._mergeByAction)
@@ -192,12 +192,12 @@ class ResolveDialog(QDialog):
         self.layout().addLayout(hbox)
 
         self.rtree = QTreeView(self)
-        self.rtree.setDragDropMode(QTreeView.DragOnly)
-        self.rtree.setSelectionMode(QTreeView.ExtendedSelection)
+        self.rtree.setDragDropMode(QTreeView.DragDropMode.DragOnly)
+        self.rtree.setSelectionMode(QTreeView.SelectionMode.ExtendedSelection)
         self.rtree.setSortingEnabled(True)
         hbox.addWidget(self.rtree)
 
-        self.rtree.setContextMenuPolicy(Qt.CustomContextMenu)
+        self.rtree.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.rtreecmenu = QMenu(self)
         cmedit = self.rtreecmenu.addAction(_('&Edit File'))
         cmedit.setToolTip(_('Edit resolved file'))
@@ -235,7 +235,7 @@ class ResolveDialog(QDialog):
         self.layout().addLayout(hbox)
 
         self.tcombo = ToolsCombo(self.repo, self)
-        self.tcombo.setSizeAdjustPolicy(QComboBox.AdjustToContents)
+        self.tcombo.setSizeAdjustPolicy(QComboBox.SizeAdjustPolicy.AdjustToContents)
 
         hbox.addWidget(QLabel(_('Detected merge/diff tools:')))
         hbox.addWidget(self.tcombo)
@@ -246,8 +246,7 @@ class ResolveDialog(QDialog):
         self._cmdlog = cmdui.LogWidget(self)
         self.layout().addWidget(self._cmdlog)
 
-        BB = QDialogButtonBox
-        bbox = QDialogButtonBox(BB.Close)
+        bbox = QDialogButtonBox(QDialogButtonBox.StandardButton.Close)
         bbox.rejected.connect(self.reject)
         self.layout().addWidget(bbox)
         self.bbox = bbox
@@ -414,7 +413,7 @@ class ResolveDialog(QDialog):
         model = self.utree.model()
         smodel = self.utree.selectionModel()
         assert model is not None
-        sflags = QItemSelectionModel.Select | QItemSelectionModel.Rows
+        sflags = QItemSelectionModel.SelectionFlag.Select | QItemSelectionModel.SelectionFlag.Rows
         for i, path in enumerate(u):
             if path in paths:
                 smodel.select(model.index(i, 0), sflags)
@@ -456,8 +455,8 @@ class ResolveDialog(QDialog):
         if model.rowCount() > 0:
             main = _('Exit without finishing resolve?')
             text = _('Unresolved conflicts remain. Are you sure?')
-            labels = ((QMessageBox.Yes, _('E&xit')),
-                      (QMessageBox.No, _('Cancel')))
+            labels = ((QMessageBox.StandardButton.Yes, _('E&xit')),
+                      (QMessageBox.StandardButton.No, _('Cancel')))
             if not qtlib.QuestionMsgBox(_('Confirm Exit'), main, text,
                                 labels=labels, parent=self):
                 return
@@ -523,11 +522,11 @@ class PathsModel(QAbstractTableModel):
             return 0 # no child
         return len(self.headers)
 
-    def data(self, index, role=Qt.DisplayRole):
+    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
         # type: (QModelIndex, int) -> Optional[Text]
         if not index.isValid():
             return None
-        if role == Qt.DisplayRole:
+        if role == Qt.ItemDataRole.DisplayRole:
             data = self.rows[index.row()][index.column()]
             return hglib.tounicode(data)
         return None
@@ -537,12 +536,12 @@ class PathsModel(QAbstractTableModel):
         flags = super(PathsModel, self).flags(index)
         if not index.isValid():
             return flags
-        flags |= Qt.ItemIsDragEnabled
+        flags |= Qt.ItemFlag.ItemIsDragEnabled
         return flags
 
-    def headerData(self, col, orientation, role=Qt.DisplayRole):
+    def headerData(self, col, orientation, role=Qt.ItemDataRole.DisplayRole):
         # type: (int, int, int) -> Optional[Text]
-        if role != Qt.DisplayRole or orientation != Qt.Horizontal:
+        if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         else:
             return self.headers[col]
