@@ -3,15 +3,15 @@
 # Copyright (C) 2007-2010 Logilab. All rights reserved.
 # Copyright (C) 2010 Adrian Buehlmann <adrian@cadifra.com>
 #
-# This software may be used and distributed according to the terms
-# of the GNU General Public License, incorporated herein by reference.
+# This software may be used and distributed according to the terms of the
+# GNU General Public License version 2 or any later version.
 
 from __future__ import absolute_import
 
 from mercurial import (
     cmdutil,
+    context,
     error,
-    scmutil,
 )
 
 from ..util import hglib, obsoleteutil
@@ -90,7 +90,7 @@ def data_func(widget, item, ctx):
         if not ts:
             return None
         try:
-            tctx = scmutil.revsymbol(ctx.repo(), hglib.fromunicode(ts))
+            tctx = hglib.revsymbol(ctx.repo(), hglib.fromunicode(ts))
             return revline_data(tctx)
         except (error.LookupError, error.RepoLookupError, error.RepoError):
             return ts
