@@ -248,9 +248,10 @@ class RevisionSetQuery(QDialog):
             start = self.entry.positionFromLineIndex(lineFrom, indexFrom)
             end = self.entry.positionFromLineIndex(lineTo, indexTo)
             sel = self.entry.selectedText()
-            if sel.count('(') and sel.contains(')'):
-                bopen = sel.indexOf('(')
-                bclose = sel.lastIndexOf(')')
+
+            if sel.count('(') and ')' in sel:
+                bopen = sel.index('(')
+                bclose = sel.rindex(')')
                 if bopen < bclose:
                     self.entry.setSelection(lineFrom, start+bopen+1,
                                             lineFrom, start+bclose)
@@ -299,7 +300,7 @@ class RevisionSetQuery(QDialog):
                     start = start-1
                 while end < len(text) and text[end] != u' ':
                     end = end+1
-                bopen = itext.indexOf('(')
+                bopen = itext.index('(')
                 newtext = text[:start] + itext[:bopen+1] + text[start:end] + \
                           ')' + text[end:]
                 self.entry.setText(newtext)
