@@ -93,7 +93,7 @@ def run():
         # TODO: Figure out if this hack for py2exe is still needed, and possibly
         #       wrap this to handle unicode on py3
         if not pycompat.ispy3:
-            mystderr = pycompat.bytesio()
+            mystderr = util.bytesio()
             sys.stderr = mystderr
             sys.__stdout__ = sys.stdout
             sys.__stderr__ = sys.stderr
@@ -137,16 +137,20 @@ def dispatch(args, u=None):
         if b'--debugger' in args:
             pdb.set_trace()
         return _runcatch(u, args)
-    except error.ParseError as e:
-        qtapp.earlyExceptionMsgBox(hglib.tounicode(str(e)))
+    except error.ConfigError as e:
+        qtapp.earlyExceptionMsgBox(e)
     except SystemExit as e:
         return e.code
     except Exception as e:
         if b'--debugger' in args:
             pdb.post_mortem(sys.exc_info()[2])
-        if u.configbool(b'tortoisehg', b'traceback'):
+        if u and u.configbool(b'tortoisehg', b'traceback'):
             raise
         qtapp.earlyBugReport(e)
+
+        if not u:
+            raise
+
         return -1
     except KeyboardInterrupt:
         print(_('\nCaught keyboard interrupt, aborting.\n'))
@@ -226,8 +230,8 @@ def get_lines_from_listfile(filename, isutf8):
         if filename == b'-':
             lines = [x.replace(b"\n", b"") for x in procutil.stdin.readlines()]
         else:
-            fd = open(filename, "r")
-            lines = [ x.replace("\n", "") for x in fd.readlines() ]
+            fd = open(filename, "rb")
+            lines = [ x.replace(b"\n", b"") for x in fd.readlines() ]
             fd.close()
             os.unlink(filename)
         if isutf8:
@@ -314,7 +318,7 @@ def _parse(ui, args):
     try:
         args = fancyopts.fancyopts(args, c, cmdoptions, True)
     except getopt.GetoptError as inst:
-        raise error.CommandError(cmd, inst)
+        raise error.CommandError(cmd, stringutil.forcebytestr(inst))
 
     # separate global options back out
     for o in globalopts:
@@ -880,8 +884,9 @@ def help_(ui, name=None, with_version=False, **opts):
                 continue
             #doc = gettext(doc)
             if not doc:
-                doc = _("(no help text available)")
-            h[f] = hglib.fromunicode(doc.splitlines()[0].rstrip())
+                h[f] = _("(no help text available)")
+            else:
+                h[f] = hglib.fromunicode(doc.splitlines()[0].rstrip())
             cmds[f] = c
 
         if not h:
