@@ -63,8 +63,8 @@ class ServeDialog(QDialog):
     def __init__(self, ui, webconf, parent=None):
         # type: (uimod.ui, Optional[IniConfig], Optional[QWidget]) -> None
         super(ServeDialog, self).__init__(parent)
-        self.setWindowFlags((self.windowFlags() | Qt.WindowMinimizeButtonHint)
-                            & ~Qt.WindowContextHelpButtonHint)
+        self.setWindowFlags((self.windowFlags() | Qt.WindowType.WindowMinimizeButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint)
         self.setWindowIcon(qtlib.geticon('hg-serve'))
 
         self._qui = Ui_ServeDialog()
@@ -206,7 +206,7 @@ class ServeDialog(QDialog):
         self._qui.port_edit.setValue(port)
 
     def keyPressEvent(self, event):
-        if self.isstarted() and event.key() == Qt.Key_Escape:
+        if self.isstarted() and event.key() == Qt.Key.Key_Escape:
             self.stop()
             return
 
