@@ -106,7 +106,7 @@ ENTRY_WIDTH = 300
 
 def hasExtension(extname):
     for name, module in extensions.extensions():
-        if name == extname:
+        if hglib.tounicode(name) == extname:
             return True
     return False
 
@@ -260,7 +260,7 @@ class PasswordEntry(LineEditBox):
         QLineEdit.__init__(self, parent, toolTip=opts['tooltip'])
         self.opts = opts
         self.curvalue = None
-        self.setEchoMode(QLineEdit.Password)
+        self.setEchoMode(QLineEdit.EchoMode.Password)
         self.setMinimumWidth(ENTRY_WIDTH)
 
 class TextEntry(QTextEdit):
@@ -600,13 +600,13 @@ def findMergeTools():
     return [hglib.tounicode(t) for t in hglib.mergetools(hglib.loadui())]
 
 def findEditors():
-    return editor.findeditors(hglib.loadui())
+    return [hglib.tounicode(e) for e in editor.findeditors(hglib.loadui())]
 
 def findTerminals():
-    return terminal.findterminals(hglib.loadui())
+    return [hglib.tounicode(t) for t in terminal.findterminals(hglib.loadui())]
 
 def findGpg():
-    return gpg.findgpg(hglib.loadui())
+    return [hglib.tounicode(t) for t in gpg.findgpg(hglib.loadui())]
 
 def genCheckBox(opts):
     opts['nohist'] = True
@@ -1018,7 +1018,7 @@ INFO = (
           'of the deny_push list are examined before the allow_push list.')),
     )),
 
-({'name': 'proxy', 'label': _('Proxy'), 'icon': QStyle.SP_DriveNetIcon}, (
+({'name': 'proxy', 'label': _('Proxy'), 'icon': QStyle.StandardPixmap.SP_DriveNetIcon}, (
     _fi(_('Host'), 'http_proxy.host', genEditCombo,
         _('Host name and (optional) port of proxy server, for '
           'example "myproxy:8000"')),
@@ -1068,7 +1068,7 @@ INFO = (
     )),
 
 ({'name': 'diff', 'label': _('Diff and Annotate'),
-  'icon': QStyle.SP_FileDialogContentsView}, (
+  'icon': QStyle.StandardPixmap.SP_FileDialogContentsView}, (
     _fi(_('Patch EOL'), 'patch.eol',
         (genDefaultCombo, ['auto', 'strict', 'crlf', 'lf']),
         _('Normalize file line endings during and after patch to lf or '
@@ -1310,8 +1310,8 @@ class SettingsDialog(QDialog):
     def __init__(self, configrepo=False, focus=None, parent=None, root=None):
         QDialog.__init__(self, parent)
         self.setWindowTitle(_('TortoiseHg Settings'))
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint
-                            | Qt.WindowMaximizeButtonHint)
+        self.setWindowFlags(self.windowFlags() & ~Qt.WindowType.WindowContextHelpButtonHint
+                            | Qt.WindowType.WindowMaximizeButtonHint)
         self.setWindowIcon(qtlib.geticon('thg-repoconfig'))
 
         if not hasattr(wconfig.config(), 'write'):
@@ -1385,8 +1385,7 @@ class SettingsDialog(QDialog):
                                  % repoagent.shortName())
             rtab.restartRequested.connect(self._pushRestartRequest)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         layout.addWidget(bb)
@@ -1482,9 +1481,9 @@ class SettingsForm(QWidget):
         self.fnedit = QLineEdit()
         self.fnedit.setReadOnly(True)
         self.fnedit.setFrame(False)
-        self.fnedit.setFocusPolicy(Qt.ClickFocus)
+        self.fnedit.setFocusPolicy(Qt.FocusPolicy.ClickFocus)
         p = self.fnedit.palette()
-        p.setColor(QPalette.Base, Qt.transparent)
+        p.setColor(QPalette.ColorRole.Base, Qt.GlobalColor.transparent)
         self.fnedit.setPalette(p)
         edit = QPushButton(_('Edit File'))
         edit.clicked.connect(self.editClicked)
@@ -1500,7 +1499,7 @@ class SettingsForm(QWidget):
         bothbox = QHBoxLayout()
         layout.addLayout(bothbox, 8)
         pageList = QListWidget()
-        pageList.setResizeMode(QListView.Fixed)
+        pageList.setResizeMode(QListView.ResizeMode.Fixed)
         if qtlib.IS_RETINA:
             pageList.setIconSize(qtlib.listviewRetinaIconSize())
         stack = QStackedWidget()
@@ -1633,8 +1632,8 @@ class SettingsForm(QWidget):
             d = QMessageBox.question(self, _('Confirm Reload'),
                             _('Unsaved changes will be lost.\n'
                             'Do you want to reload?'),
-                            QMessageBox.Ok | QMessageBox.Cancel)
-            if d != QMessageBox.Ok:
+                            QMessageBox.StandardButton.Ok | QMessageBox.StandardButton.Cancel)
+            if d != QMessageBox.StandardButton.Ok:
                 return
         self.refresh()
 
@@ -1736,9 +1735,9 @@ class SettingsForm(QWidget):
         return (), [frame]
 
     def eventFilter(self, obj, event):
-        if event.type() in (QEvent.Enter, QEvent.FocusIn):
+        if event.type() in (QEvent.Type.Enter, QEvent.Type.FocusIn):
             self.desctext.setHtml(obj.toolTip())
-        if event.type() == QEvent.ToolTip:
+        if event.type() == QEvent.Type.ToolTip:
             return True  # tooltip is shown in self.desctext
         return False
 
