@@ -120,11 +120,11 @@ class ShellConfigWindow(QDialog):
         w.itemClicked.connect(self.listItemClicked)
 
         style = QApplication.style()
-        icon = style.standardIcon(QStyle.SP_ArrowLeft)
+        icon = style.standardIcon(QStyle.StandardPixmap.SP_ArrowLeft)
         self.top_button = w = QPushButton(icon, '')
         grid.addWidget(w, 2, 1)
         w.clicked.connect(self.top_clicked)
-        icon = style.standardIcon(QStyle.SP_ArrowRight)
+        icon = style.standardIcon(QStyle.StandardPixmap.SP_ArrowRight)
         self.sub_button = w = QPushButton(icon, '')
         grid.addWidget(w, 3, 1)
         w.clicked.connect(self.sub_clicked)
@@ -208,13 +208,12 @@ class ShellConfigWindow(QDialog):
         iconslayout.addWidget(w)
 
         # dialog buttons
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Ok|BB.Cancel|BB.Apply)
-        self.apply_button = bb.button(BB.Apply)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel|QDialogButtonBox.StandardButton.Apply)
+        self.apply_button = bb.button(QDialogButtonBox.StandardButton.Apply)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
-        bb.button(BB.Apply).clicked.connect(self.apply)
-        bb.button(BB.Ok).setDefault(True)
+        bb.button(QDialogButtonBox.StandardButton.Apply).clicked.connect(self.apply)
+        bb.button(QDialogButtonBox.StandardButton.Ok).setDefault(True)
         layout.addWidget(bb)
 
         self.setLayout(layout)
@@ -249,7 +248,7 @@ class ShellConfigWindow(QDialog):
         promoted = [pi.strip() for pi in promoteditems.split(',')]
         for cmd, info in menuthg.thgcmenu.items():
             label = info['label']
-            item = QListWidgetItem(label['str'].decode('utf-8'))
+            item = QListWidgetItem(label['str'])
             item._id = label['id']
             if cmd in promoted:
                 self.topmenulist.addItem(item)
