@@ -49,7 +49,7 @@ class ShelveDialog(QDialog):
 
     def __init__(self, repoagent, parent=None):
         QDialog.__init__(self, parent)
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
 
         self.setWindowIcon(qtlib.geticon('hg-shelve'))
 
@@ -69,7 +69,7 @@ class ShelveDialog(QDialog):
         layout.addLayout(self.tbarhbox)
 
         self.splitter = QSplitter(self)
-        self.splitter.setOrientation(Qt.Horizontal)
+        self.splitter.setOrientation(Qt.Orientation.Horizontal)
         self.splitter.setChildrenCollapsible(False)
         self.splitter.setObjectName('splitter')
         layout.addWidget(self.splitter, 1)
@@ -161,7 +161,7 @@ class ShelveDialog(QDialog):
         self.tbarhbox.addWidget(self.rbar)
         self.refreshAction = a = QAction(_('Refresh'), self)
         a.setIcon(qtlib.geticon('view-refresh'))
-        a.setShortcuts(QKeySequence.Refresh)
+        a.setShortcuts(QKeySequence.StandardKey.Refresh)
         a.triggered.connect(self.refreshCombos)
         self.rbar.addAction(self.refreshAction)
         self.actionNew = a = QAction(_('New Shelf'), self)
