@@ -344,7 +344,7 @@ class ActionRegistry(ShortcutRegistry):
         # C++ object is deleted. Since QAction will be instantiated per
         # context (e.g. window), more than one instances may be registered
         # to the same slot.
-        self._actionsMap = collections.defaultdict(weakref.WeakSet)  # type: Dict[Text, Set[QAction]]
+        self._actionsMap = collections.defaultdict(weakref.WeakSet)  # type: Dict[Text, weakref.WeakSet[QAction]]
 
     def applyChangesToActions(self):
         """Applies changes to registered QAction instances"""
