@@ -40,7 +40,7 @@ class SignDialog(QDialog):
         if opts is None:
             opts = {}
         self.setWindowFlags(self.windowFlags() &
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
@@ -50,13 +50,13 @@ class SignDialog(QDialog):
         base = QVBoxLayout()
         base.setSpacing(0)
         base.setContentsMargins(*(0,)*4)
-        base.setSizeConstraint(QLayout.SetMinAndMaxSize)
+        base.setSizeConstraint(QLayout.SizeConstraint.SetMinAndMaxSize)
         self.setLayout(base)
 
         ## main layout grid
         formwidget = QWidget(self)
-        formwidget.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
-        form = QFormLayout(fieldGrowthPolicy=QFormLayout.AllNonFixedFieldsGrow)
+        formwidget.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
+        form = QFormLayout(fieldGrowthPolicy=QFormLayout.FieldGrowthPolicy.AllNonFixedFieldsGrow)
         formwidget.setLayout(form)
         base.addWidget(formwidget)
 
@@ -99,10 +99,9 @@ class SignDialog(QDialog):
         optbox.addWidget(self.customTextLineEdit)
 
         ## bottom buttons
-        BB = QDialogButtonBox
         bbox = QDialogButtonBox()
-        self.signBtn = bbox.addButton(_('&Sign'), BB.ActionRole)
-        bbox.addButton(BB.Close)
+        self.signBtn = bbox.addButton(_('&Sign'), QDialogButtonBox.ButtonRole.ActionRole)
+        bbox.addButton(QDialogButtonBox.StandardButton.Close)
         bbox.rejected.connect(self.reject)
         form.addRow(bbox)
 
@@ -110,8 +109,8 @@ class SignDialog(QDialog):
 
         ## horizontal separator
         self.sep = QFrame()
-        self.sep.setFrameShadow(QFrame.Sunken)
-        self.sep.setFrameShape(QFrame.HLine)
+        self.sep.setFrameShadow(QFrame.Shadow.Sunken)
+        self.sep.setFrameShape(QFrame.Shape.HLine)
         self.layout().addWidget(self.sep)
 
         ## status line
