@@ -133,9 +133,7 @@ class StatusWidget(QWidget):
                     _colors[stat] = QColor(e[7:])
                     break
 
-        SP = QSizePolicy
-
-        split = QSplitter(Qt.Horizontal)
+        split = QSplitter(Qt.Orientation.Horizontal)
         split.setChildrenCollapsible(False)
         layout = QVBoxLayout()
         layout.setContentsMargins(0, 0, 0, 0)
@@ -145,7 +143,7 @@ class StatusWidget(QWidget):
         vbox = QVBoxLayout()
         vbox.setContentsMargins(0, 0, 0, 0)
         frame = QFrame(split)
-        sp = SP(SP.Expanding, SP.Expanding)
+        sp = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
         sp.setHorizontalStretch(0)
         sp.setVerticalStretch(0)
         frame.setSizePolicy(sp)
@@ -207,13 +205,13 @@ class StatusWidget(QWidget):
         self.clearPatternBtn.setVisible(bool(self.pats))
 
         tv.setAllColumnsShowFocus(True)
-        tv.setContextMenuPolicy(Qt.CustomContextMenu)
-        tv.setDragDropMode(QTreeView.DragOnly)
+        tv.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
+        tv.setDragDropMode(QTreeView.DragDropMode.DragOnly)
         tv.setItemsExpandable(False)
         tv.setRootIsDecorated(False)
-        tv.setSelectionMode(QTreeView.ExtendedSelection)
-        tv.setTextElideMode(Qt.ElideLeft)
-        tv.sortByColumn(COL_STATUS, Qt.AscendingOrder)
+        tv.setSelectionMode(QTreeView.SelectionMode.ExtendedSelection)
+        tv.setTextElideMode(Qt.TextElideMode.ElideLeft)
+        tv.sortByColumn(COL_STATUS, Qt.SortOrder.AscendingOrder)
         tv.doubleClicked.connect(self.onRowDoubleClicked)
         tv.customContextMenuRequested.connect(self.onMenuRequest)
         le.textEdited.connect(self.setFilter)
@@ -224,8 +222,8 @@ class StatusWidget(QWidget):
         self.le = le
         self._tvpaletteswitcher = qtlib.PaletteSwitcher(tv)
 
-        self._togglefileshortcut = a = QShortcut(Qt.Key_Space, tv)
-        a.setContext(Qt.WidgetShortcut)
+        self._togglefileshortcut = a = QShortcut(Qt.Key.Key_Space, tv)
+        a.setContext(Qt.ShortcutContext.WidgetShortcut)
         a.setEnabled(False)
         a.activated.connect(self._toggleSelectedFiles)
 
@@ -234,7 +232,7 @@ class StatusWidget(QWidget):
         vbox.setSpacing(0)
         vbox.setContentsMargins(0, 0, 0, 0)
         docf = QFrame(split)
-        sp = SP(SP.Expanding, SP.Expanding)
+        sp = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
         sp.setHorizontalStretch(1)
         sp.setVerticalStretch(0)
         docf.setSizePolicy(sp)
@@ -276,14 +274,14 @@ class StatusWidget(QWidget):
     @pyqtSlot()
     def checkAllNone(self):
         state = self.checkAllNoneBtn.checkState()
-        if state == Qt.Checked:
+        if state == Qt.CheckState.Checked:
             self.checkAll()
             self.checkAllNoneBtn.setToolTip(self.checkNoneTT)
         else:
-            if state == Qt.Unchecked:
+            if state == Qt.CheckState.Unchecked:
                 self.checkNone()
             self.checkAllNoneBtn.setToolTip(self.checkAllTT)
-        if state != Qt.PartiallyChecked:
+        if state != Qt.CheckState.PartiallyChecked:
             self.checkAllNoneBtn.setTristate(False)
 
     def getTitle(self):
@@ -364,7 +362,7 @@ class StatusWidget(QWidget):
             optmenu = menu
         optmenu.addActions(self.statusfilter.actions())
 
-        menu.setAttribute(Qt.WA_DeleteOnClose)
+        menu.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         menu.popup(self.tv.viewport().mapToGlobal(point))
 
     def _setupFileMenu(self, menu):
@@ -506,7 +504,7 @@ class StatusWidget(QWidget):
         # reset selection, or select first row
         curidx = tm.index(0, 0)
         selmodel = self.tv.selectionModel()
-        flags = QItemSelectionModel.Select | QItemSelectionModel.Rows
+        flags = QItemSelectionModel.SelectionFlag.Select | QItemSelectionModel.SelectionFlag.Rows
         if self.reselection:
             selected, current = self.reselection
             for i, row in enumerate(tm.getAllRows()):
@@ -519,7 +517,7 @@ class StatusWidget(QWidget):
         selmodel.currentChanged.connect(self.onCurrentChange)
         selmodel.selectionChanged.connect(self.onSelectionChange)
         if curidx and curidx.isValid():
-            selmodel.setCurrentIndex(curidx, QItemSelectionModel.Current)
+            selmodel.setCurrentIndex(curidx, QItemSelectionModel.SelectionFlag.Current)
         self.onSelectionChange()
 
         self._togglefileshortcut.setEnabled(True)
@@ -569,12 +567,12 @@ class StatusWidget(QWidget):
         if model:
             model.checkCount = len(self.getChecked())
             if model.checkCount == 0:
-                state = Qt.Unchecked
+                state = Qt.CheckState.Unchecked
             elif model.checkCount == len(model.rows):
-                state = Qt.Checked
+                state = Qt.CheckState.Checked
             else:
-                state = Qt.PartiallyChecked
-            self.checkAllNoneBtn.setTristate(state == Qt.PartiallyChecked)
+                state = Qt.CheckState.PartiallyChecked
+            self.checkAllNoneBtn.setTristate(state == Qt.CheckState.PartiallyChecked)
             self.checkAllNoneBtn.setCheckState(state)
 
     @pyqtSlot(str, bool)
@@ -661,15 +659,15 @@ class StatusWidget(QWidget):
         assert model is not None
         selmodel = self.tv.selectionModel()
         for index in selmodel.selectedRows(COL_PATH):
-            model.setData(index, value, Qt.CheckStateRole)
+            model.setData(index, value, Qt.ItemDataRole.CheckStateRole)
 
     @pyqtSlot()
     def _checkSelectedFiles(self):
-        self._setCheckStateOfSelectedFiles(Qt.Checked)
+        self._setCheckStateOfSelectedFiles(Qt.CheckState.Checked)
 
     @pyqtSlot()
     def _uncheckSelectedFiles(self):
-        self._setCheckStateOfSelectedFiles(Qt.Unchecked)
+        self._setCheckStateOfSelectedFiles(Qt.CheckState.Unchecked)
 
     @pyqtSlot()
     def _toggleSelectedFiles(self):
@@ -678,11 +676,11 @@ class StatusWidget(QWidget):
         assert model is not None
         assert selmodel is not None
         for index in selmodel.selectedRows(COL_PATH):
-            if model.data(index, Qt.CheckStateRole) == Qt.Checked:
-                newvalue = Qt.Unchecked
+            if model.data(index, Qt.ItemDataRole.CheckStateRole) == Qt.CheckState.Checked:
+                newvalue = Qt.CheckState.Unchecked
             else:
-                newvalue = Qt.Checked
-            model.setData(index, newvalue, Qt.CheckStateRole)
+                newvalue = Qt.CheckState.Checked
+            model.setData(index, newvalue, Qt.ItemDataRole.CheckStateRole)
 
 
 class StatusThread(QThread):
@@ -776,7 +774,7 @@ class StatusThread(QThread):
 
 class WctxFileTree(QTreeView):
 
-    def scrollTo(self, index, hint=QAbstractItemView.EnsureVisible):
+    def scrollTo(self, index, hint=QAbstractItemView.ScrollHint.EnsureVisible):
         # don't update horizontal position by selection change
         orighoriz = self.horizontalScrollBar().value()
         super(WctxFileTree, self).scrollTo(index, hint)
@@ -911,37 +909,37 @@ class WctxModel(QAbstractTableModel):
             return None
 
         if index.column() == COL_PATH:
-            if role == Qt.CheckStateRole and self.checkable:
+            if role == Qt.ItemDataRole.CheckStateRole and self.checkable:
                 path = self.rows[index.row()][0]
                 if path in self.partials:
                     changes = self.partials[path]
                     if changes.excludecount == 0:
-                        return Qt.Checked
+                        return Qt.CheckState.Checked
                     elif changes.excludecount == len(changes.hunks):
-                        return Qt.Unchecked
+                        return Qt.CheckState.Unchecked
                     else:
-                        return Qt.PartiallyChecked
+                        return Qt.CheckState.PartiallyChecked
                 if self.checked[path]:
-                    return Qt.Checked
+                    return Qt.CheckState.Checked
                 else:
-                    return Qt.Unchecked
-            elif role == Qt.DisplayRole:
+                    return Qt.CheckState.Unchecked
+            elif role == Qt.ItemDataRole.DisplayRole:
                 return ""
-            elif role == Qt.ToolTipRole:
+            elif role == Qt.ItemDataRole.ToolTipRole:
                 return _('Checked count: %d') % self.checkCount
-        elif role == Qt.DisplayRole:
+        elif role == Qt.ItemDataRole.DisplayRole:
             return self.rows[index.row()][index.column()]
-        elif role == Qt.TextColorRole:
+        elif role == Qt.ItemDataRole.ForegroundRole:
             path, status, mst, upath, ext, sz = self.rows[index.row()]
             if mst:
                 return _colors.get(mst.lower(), QColor('black'))
             else:
                 return _colors.get(status, QColor('black'))
-        elif role == Qt.ToolTipRole:
+        elif role == Qt.ItemDataRole.ToolTipRole:
             path, status, mst, upath, ext, sz = self.rows[index.row()]
             return statusMessage(status, mst, upath)
         '''
-        elif role == Qt.DecorationRole and index.column() == COL_STATUS:
+        elif role == Qt.ItemDataRole.DecorationRole and index.column() == COL_STATUS:
             if status in statusTypes:
                 ico = QIcon()
                 ico.addPixmap(QPixmap('icons/' + statusTypes[status].icon))
@@ -949,19 +947,19 @@ class WctxModel(QAbstractTableModel):
         '''
         return None
 
-    def setData(self, index, value, role=Qt.EditRole):
+    def setData(self, index, value, role=Qt.ItemDataRole.EditRole):
         if not index.isValid():
             return False
-        if (index.column() == COL_PATH and role == Qt.CheckStateRole
+        if (index.column() == COL_PATH and role == Qt.ItemDataRole.CheckStateRole
             and self.checkable):
             if self.data(index, role) == value:
                 return True
-            if value not in (Qt.Checked, Qt.Unchecked):
-                # Qt.PartiallyChecked cannot be set explicitly
+            if value not in (Qt.CheckState.Checked, Qt.CheckState.Unchecked):
+                # Qt.CheckState.PartiallyChecked cannot be set explicitly
                 return False
             path = self.rows[index.row()][COL_PATH]
             upath = self.rows[index.row()][COL_PATH_DISPLAY]
-            self.checked[path] = checked = (value == Qt.Checked)
+            self.checked[path] = checked = (value == Qt.CheckState.Checked)
             self.checkToggled.emit(upath, checked)
             self.checkCountChanged.emit()
             self.dataChanged.emit(index, index)
@@ -969,15 +967,15 @@ class WctxModel(QAbstractTableModel):
         return False
 
     def headerData(self, col, orientation, role):
-        if role != Qt.DisplayRole or orientation != Qt.Horizontal:
+        if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         else:
             return self.headers[col]
 
     def flags(self, index):
-        flags = Qt.ItemIsSelectable | Qt.ItemIsEnabled | Qt.ItemIsDragEnabled
+        flags = Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsDragEnabled
         if index.column() == COL_PATH and self.checkable:
-            flags |= Qt.ItemIsUserCheckable
+            flags |= Qt.ItemFlag.ItemIsUserCheckable
         return flags
 
     def mimeTypes(self):
@@ -1081,7 +1079,7 @@ class WctxModel(QAbstractTableModel):
             # Already sorted!
             pass
         else:
-            if order == Qt.DescendingOrder:
+            if order == Qt.SortOrder.DescendingOrder:
                 # We want the secondary sort to be by _ascending_ path,
                 # even when the primary sort is in descending order
                 self.rows.reverse()
@@ -1099,7 +1097,7 @@ class WctxModel(QAbstractTableModel):
             else:
                 self.rows.sort(key=lambda x: x[col])
 
-        if order == Qt.DescendingOrder:
+        if order == Qt.SortOrder.DescendingOrder:
             self.rows.reverse()
         self.layoutChanged.emit()
         self.endResetModel()
@@ -1208,7 +1206,7 @@ def createStatusFilterMenuButton(actiongroup, parent=None):
     """Create button with drop-down menu for status filter"""
     button = QToolButton(parent)
     button.setIcon(qtlib.geticon('hg-status'))
-    button.setPopupMode(QToolButton.InstantPopup)
+    button.setPopupMode(QToolButton.ToolButtonPopupMode.InstantPopup)
     menu = QMenu(button)
     menu.addActions(actiongroup.actions())
     button.setMenu(menu)
@@ -1243,10 +1241,10 @@ class StatusDialog(QDialog):
                                               parent=self)
 
         self.setWindowTitle(self.stwidget.getTitle())
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
         self.loadSettings()
 
-        qtlib.newshortcutsforstdkey(QKeySequence.Refresh, self,
+        qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Refresh, self,
                                     self.stwidget.refreshWctx)
         QTimer.singleShot(0, self.stwidget.refreshWctx)
 
