@@ -216,9 +216,9 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         tb.addWidget(self.optionsbutton)
 
         self.targetcombo = QComboBox()
-        self.targetcombo.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.targetcombo.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self.targetcombo.setSizeAdjustPolicy(
-            QComboBox.AdjustToMinimumContentsLength)
+            QComboBox.SizeAdjustPolicy.AdjustToContents)
         self.targetcombo.setEnabled(False)
         self.targetcheckbox = QCheckBox(_('Target:'))
         self.targetcheckbox.toggled.connect(self.targetcombo.setEnabled)
@@ -248,7 +248,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         tbar.addWidget(qtlib.Spacer(2, 2))
 
         style = QApplication.style()
-        a = tbar.addAction(style.standardIcon(QStyle.SP_DialogSaveButton),
+        a = tbar.addAction(style.standardIcon(QStyle.StandardPixmap.SP_DialogSaveButton),
                           _('Save'))
         a.setToolTip(_('Save current URL under an alias'))
         self.savebutton = a
@@ -276,7 +276,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self.hgrctv.removeAlias.connect(self.removeAlias)
         self.hgrctv.menuRequest.connect(self.menuRequest)
         pathsframe = QFrame()
-        pathsframe.setFrameStyle(QFrame.StyledPanel|QFrame.Raised)
+        pathsframe.setFrameStyle(QFrame.Shape.StyledPanel|QFrame.Shadow.Raised)
         pathsbox = QVBoxLayout()
         pathsbox.setContentsMargins(0, 0, 0, 0)
         pathsframe.setLayout(pathsbox)
@@ -291,7 +291,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self.reltv.clicked.connect(self.hgrctv.clearSelection)
         self.hgrctv.clicked.connect(self.reltv.clearSelection)
         pathsframe = QFrame()
-        pathsframe.setFrameStyle(QFrame.StyledPanel|QFrame.Raised)
+        pathsframe.setFrameStyle(QFrame.Shape.StyledPanel|QFrame.Shadow.Raised)
         pathsbox = QVBoxLayout()
         pathsbox.setContentsMargins(0, 0, 0, 0)
         pathsframe.setLayout(pathsbox)
@@ -334,13 +334,13 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
             uname = hglib.tounicode(name)
             self.targetcombo.addItem(_('branch: ') + uname, ('--branch', name))
             self.targetcombo.setItemData(self.targetcombo.count() - 1, name,
-                                         Qt.ToolTipRole)
+                                         Qt.ItemDataRole.ToolTipRole)
         for name in sorted(self.repo._bookmarks):
             uname = hglib.tounicode(name)
             self.targetcombo.addItem(_('bookmark: ') + uname,
                                      ('--bookmark', name))
             self.targetcombo.setItemData(self.targetcombo.count() - 1, name,
-                                         Qt.ToolTipRole)
+                                         Qt.ItemDataRole.ToolTipRole)
 
     def _findTargetIndex(self, ctx):
         for name in ctx.bookmarks():
@@ -375,9 +375,9 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
     def editOptions(self):
         dlg = OptionsDialog(self._repoagent, self.opts, self)
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
-        if dlg.exec_() == QDialog.Accepted:
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
+        if dlg.exec_() == QDialog.DialogCode.Accepted:
             self.opts.update(dlg.outopts)
             self.refreshUrl()
 
@@ -471,7 +471,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
     def pathSelected(self, index):
         aliasindex = index.sibling(index.row(), 0)
-        alias = aliasindex.data(Qt.DisplayRole)
+        alias = aliasindex.data(Qt.ItemDataRole.DisplayRole)
         self.curalias = hglib.fromunicode(alias)
         path = index.model().realUrl(index)
         self.setEditUrl(hglib.tounicode(path))
@@ -488,8 +488,8 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         model = self.hgrctv.model()
         assert model is not None
         for col in (0, 1):  # search known (alias, url)
-            ixs = model.match(model.index(0, col), Qt.DisplayRole, newurl, 1,
-                              Qt.MatchFixedString | Qt.MatchCaseSensitive)
+            ixs = model.match(model.index(0, col), Qt.ItemDataRole.DisplayRole, newurl, 1,
+                              Qt.MatchFlag.MatchFixedString | Qt.MatchFlag.MatchCaseSensitive)
             if ixs:
                 self.hgrctv.setCurrentIndex(ixs[0])
                 self.pathSelected(ixs[0])  # in case of row not changed
@@ -500,24 +500,24 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
     def dragEnterEvent(self, event):
         data = event.mimeData()
         if data.hasUrls() or data.hasText():
-            event.setDropAction(Qt.CopyAction)
+            event.setDropAction(Qt.DropAction.CopyAction)
             event.acceptProposedAction()
 
     def dragMoveEvent(self, event):
         data = event.mimeData()
         if data.hasUrls() or data.hasText():
-            event.setDropAction(Qt.CopyAction)
+            event.setDropAction(Qt.DropAction.CopyAction)
             event.acceptProposedAction()
 
     def dropEvent(self, event):
         data = event.mimeData()
         if data.hasUrls():
             url = pycompat.unicode(data.urls()[0].toString())
-            event.setDropAction(Qt.CopyAction)
+            event.setDropAction(Qt.DropAction.CopyAction)
             event.accept()
         elif data.hasText():
             url = pycompat.unicode(data.text())
-            event.setDropAction(Qt.CopyAction)
+            event.setDropAction(Qt.DropAction.CopyAction)
             event.accept()
         else:
             return
@@ -582,9 +582,9 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         alias = hglib.fromunicode(self.menualias)
         urlu = pycompat.unicode(self.menuurl)
         dlg = SaveDialog(self._repoagent, alias, urlu, self, edit=True)
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
-        if dlg.exec_() == QDialog.Accepted:
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
+        if dlg.exec_() == QDialog.DialogCode.Accepted:
             self.curalias = hglib.fromunicode(dlg.aliasentry.text())
             self.setEditUrl(dlg.urlentry.text())
             self.reload()
@@ -600,9 +600,9 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
     def keyPressEvent(self, event):
         sess = self._cmdsession
-        if event.matches(QKeySequence.Refresh):
+        if event.matches(QKeySequence.StandardKey.Refresh):
             self.reload()
-        elif event.key() == Qt.Key_Escape and not sess.isFinished():
+        elif event.key() == Qt.Key.Key_Escape and not sess.isFinished():
             sess.abort()
         else:
             return super(SyncWidget, self).keyPressEvent(event)
@@ -618,9 +618,9 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         else:
             alias = b'new'
         dlg = SaveDialog(self._repoagent, alias, self.currentUrl(), self)
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
-        if dlg.exec_() == QDialog.Accepted:
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
+        if dlg.exec_() == QDialog.DialogCode.Accepted:
             self.curalias = hglib.fromunicode(dlg.aliasentry.text())
             self.reload()
 
@@ -639,8 +639,8 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
                                 parent=self)
             return
         dlg = SecureDialog(self._repoagent, self.currentUrl(), self)
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
         dlg.exec_()
 
     @pyqtSlot()
@@ -1036,8 +1036,8 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
     def postpullclicked(self):
         dlg = PostPullDialog(self._repoagent, self)
-        dlg.setWindowFlags(Qt.Sheet)
-        dlg.setWindowModality(Qt.WindowModal)
+        dlg.setWindowFlags(Qt.WindowType.Sheet)
+        dlg.setWindowModality(Qt.WindowModality.WindowModal)
         dlg.exec_()
 
     def emailclicked(self):
@@ -1118,7 +1118,7 @@ class PostPullDialog(QDialog):
         self.setLayout(layout)
         self.setWindowTitle(_('Post Pull Behavior'))
         self.setWindowFlags(self.windowFlags() &
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
 
         lbl = QLabel(_('Select post-pull operation for this repository'))
         layout.addWidget(lbl)
@@ -1168,8 +1168,7 @@ class PostPullDialog(QDialog):
         cfglabel.linkActivated.connect(self.linkactivated)
         layout.addWidget(cfglabel)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Save|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Save|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
 
@@ -1222,11 +1221,11 @@ class SaveDialog(QDialog):
 
         self.setWindowTitle(_('Save Path'))
         self.setWindowFlags(self.windowFlags() &
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self.origurl = hglib.fromunicode(urlu)
         self.setLayout(QFormLayout())
-        self.layout().setFieldGrowthPolicy(QFormLayout.ExpandingFieldsGrow)
+        self.layout().setFieldGrowthPolicy(QFormLayout.FieldGrowthPolicy.ExpandingFieldsGrow)
 
         self.origalias = alias
         self.aliasentry = QLineEdit(hglib.tounicode(self.origalias))
@@ -1267,11 +1266,10 @@ class SaveDialog(QDialog):
             % hglib.tounicode(alias))
         self.layout().addRow(self.updatesubpaths)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Save|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Save|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
-        bb.button(BB.Save).setAutoDefault(True)
+        bb.button(QDialogButtonBox.StandardButton.Save).setAutoDefault(True)
         self.bb = bb
         self.layout().addRow(bb)
 
@@ -1353,7 +1351,7 @@ class SaveDialog(QDialog):
 
     @pyqtSlot()
     def _updateUi(self):
-        savebtn = self.bb.button(QDialogButtonBox.Save)
+        savebtn = self.bb.button(QDialogButtonBox.StandardButton.Save)
         savebtn.setEnabled(bool(self.aliasentry.text()
                                 and self.urlentry.text()))
 
@@ -1381,7 +1379,7 @@ class SecureDialog(QDialog):
         uhost = hglib.tounicode(u.host)
         self.setWindowTitle(_('Security: ') + uhost)
         self.setWindowFlags(self.windowFlags() & \
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
 
         # if the already user has an [auth] configuration for this URL, use it
         cleanurl = urlutil.removeauth(hglib.fromunicode(urlu))
@@ -1472,7 +1470,7 @@ foo.username = $USER.'''))
         k = b'password'
         c = hglib.tounicode(u.passwd or auth.get(k, b''))
         self._authentries[k] = e = QLineEdit(c)
-        e.setEchoMode(QLineEdit.Password)
+        e.setEchoMode(QLineEdit.EchoMode.Password)
         e.setToolTip(
 _('''Optional. Password to authenticate with. If not given, and the remote
 site requires basic or digest authentication, the user will be prompted for
@@ -1503,8 +1501,7 @@ are expanded in the filename.'''))
         form.addRow(_('User Certificate Chain'),
                     _addBrowseButton(e, self._browseClientCert))
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Help|BB.Save|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Help|QDialogButtonBox.StandardButton.Save|QDialogButtonBox.StandardButton.Cancel)
         bb.rejected.connect(self.reject)
         bb.accepted.connect(self.accept)
         bb.helpRequested.connect(self.keyringHelp)
@@ -1616,26 +1613,26 @@ class PathsTree(QTreeView):
 
     def __init__(self, parent, editable):
         QTreeView.__init__(self, parent)
-        self.setDragDropMode(QTreeView.DragOnly)
-        self.setSelectionMode(QTreeView.SingleSelection)
+        self.setDragDropMode(QTreeView.DragDropMode.DragOnly)
+        self.setSelectionMode(QTreeView.SelectionMode.SingleSelection)
         self.editable = editable
 
     def contextMenuEvent(self, event):
         for index in self.selectedRows():
-            alias = index.data(Qt.DisplayRole)
-            url = index.sibling(index.row(), 1).data(Qt.DisplayRole)
+            alias = index.data(Qt.ItemDataRole.DisplayRole)
+            url = index.sibling(index.row(), 1).data(Qt.ItemDataRole.DisplayRole)
             self.menuRequest.emit(event.globalPos(), url, alias, self.editable)
             return
 
     def keyPressEvent(self, event):
-        if self.editable and event.matches(QKeySequence.Delete):
+        if self.editable and event.matches(QKeySequence.StandardKey.Delete):
             self.deleteSelected()
         else:
             return super(PathsTree, self).keyPressEvent(event)
 
     def deleteSelected(self):
         for index in self.selectedRows():
-            alias = index.data(Qt.DisplayRole)
+            alias = index.data(Qt.ItemDataRole.DisplayRole)
             r = qtlib.QuestionMsgBox(_('Confirm path delete'),
                     _('Delete %s from your repo configuration file?') % alias,
                     parent=self)
@@ -1667,15 +1664,15 @@ class PathsModel(QAbstractTableModel):
             return 0 # no child
         return len(self.headers)
 
-    def data(self, index, role=Qt.DisplayRole):
+    def data(self, index, role=Qt.ItemDataRole.DisplayRole):
         if not index.isValid():
             return None
-        if role == Qt.DisplayRole:
+        if role == Qt.ItemDataRole.DisplayRole:
             return self.rows[index.row()][index.column()]
         return None
 
-    def headerData(self, col, orientation, role=Qt.DisplayRole):
-        if role != Qt.DisplayRole or orientation != Qt.Horizontal:
+    def headerData(self, col, orientation, role=Qt.ItemDataRole.DisplayRole):
+        if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         else:
             return self.headers[col]
@@ -1695,7 +1692,7 @@ class PathsModel(QAbstractTableModel):
         return ['text/uri-list']
 
     def flags(self, index):
-        flags = Qt.ItemIsSelectable | Qt.ItemIsEnabled | Qt.ItemIsDragEnabled
+        flags = Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsDragEnabled
         return flags
 
     def realUrl(self, index):
@@ -1756,8 +1753,7 @@ class OptionsDialog(QDialog):
             self.branchle.setText(hglib.tounicode(opts['branch']))
         form.addRow(lbl, self.branchle)
 
-        BB = QDialogButtonBox
-        bb = QDialogButtonBox(BB.Save|BB.Cancel)
+        bb = QDialogButtonBox(QDialogButtonBox.StandardButton.Save|QDialogButtonBox.StandardButton.Cancel)
         bb.accepted.connect(self.accept)
         bb.rejected.connect(self.reject)
         self.bb = bb
