@@ -62,7 +62,7 @@ class TagDialog(QDialog):
         if opts is None:
             opts = {}
         self.setWindowFlags(self.windowFlags() &
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
 
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
@@ -73,12 +73,12 @@ class TagDialog(QDialog):
         base = QVBoxLayout()
         base.setSpacing(0)
         base.setContentsMargins(0, 0, 0, 0)
-        base.setSizeConstraint(QLayout.SetMinAndMaxSize)
+        base.setSizeConstraint(QLayout.SizeConstraint.SetMinAndMaxSize)
         self.setLayout(base)
 
         formwidget = QWidget(self)
-        formwidget.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
-        form = QFormLayout(fieldGrowthPolicy=QFormLayout.AllNonFixedFieldsGrow)
+        formwidget.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
+        form = QFormLayout(fieldGrowthPolicy=QFormLayout.FieldGrowthPolicy.AllNonFixedFieldsGrow)
         formwidget.setLayout(form)
         base.addWidget(formwidget)
 
@@ -130,11 +130,10 @@ class TagDialog(QDialog):
         optbox.addWidget(self.customTextLineEdit)
 
         ## bottom buttons
-        BB = QDialogButtonBox
-        bbox = QDialogButtonBox(BB.Close)
+        bbox = QDialogButtonBox(QDialogButtonBox.StandardButton.Close)
         bbox.rejected.connect(self.reject)
-        self.addBtn = bbox.addButton(_('&Add'), BB.ActionRole)
-        self.removeBtn = bbox.addButton(_('&Remove'), BB.ActionRole)
+        self.addBtn = bbox.addButton(_('&Add'), QDialogButtonBox.ButtonRole.ActionRole)
+        self.removeBtn = bbox.addButton(_('&Remove'), QDialogButtonBox.ButtonRole.ActionRole)
         form.addRow(bbox)
 
         self.addBtn.clicked.connect(self.onAddTag)
@@ -142,8 +141,8 @@ class TagDialog(QDialog):
 
         ## horizontal separator
         self.sep = QFrame()
-        self.sep.setFrameShadow(QFrame.Sunken)
-        self.sep.setFrameShape(QFrame.HLine)
+        self.sep.setFrameShadow(QFrame.Shadow.Sunken)
+        self.sep.setFrameShape(QFrame.Shape.HLine)
         base.addWidget(self.sep)
 
         ## status line
