@@ -67,8 +67,8 @@ class ImportDialog(QDialog):
     def __init__(self, repoagent, parent, **opts):
         super(ImportDialog, self).__init__(parent)
         self.setWindowFlags(self.windowFlags()
-                            & ~Qt.WindowContextHelpButtonHint
-                            | Qt.WindowMaximizeButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint
+                            | Qt.WindowType.WindowMaximizeButtonHint)
         self.setWindowTitle(_('Import - %s') % repoagent.displayName())
         self.setWindowIcon(qtlib.geticon('hg-import'))
 
@@ -106,14 +106,14 @@ class ImportDialog(QDialog):
         grid.addLayout(srcbox, 1, 1)
         self.p0chk = QCheckBox(_('Do not strip paths (-p0), '
                                  'required for SVN patches'))
-        grid.addWidget(self.p0chk, 2, 1, Qt.AlignLeft)
+        grid.addWidget(self.p0chk, 2, 1, Qt.AlignmentFlag.AlignLeft)
 
         ### patch list
         self.cslist = cslist.ChangesetList(self.repo)
         cslistrow = 4
         cslistcol = 1
         grid.addWidget(self.cslist, cslistrow, cslistcol)
-        grid.addWidget(QLabel(_('Preview:')), 3, 0, Qt.AlignLeft | Qt.AlignTop)
+        grid.addWidget(QLabel(_('Preview:')), 3, 0, Qt.AlignmentFlag.AlignLeft | Qt.AlignmentFlag.AlignTop)
         statbox = QHBoxLayout()
         self.status = QLabel("")
         statbox.addWidget(self.status)
@@ -139,7 +139,7 @@ class ImportDialog(QDialog):
         QTimer.singleShot(0, self.checkStatus)
 
         self._runbutton = cmd.addButton(_('&Import'),
-                                        QDialogButtonBox.AcceptRole)
+                                        QDialogButtonBox.ButtonRole.AcceptRole)
         self._runbutton.clicked.connect(self._runCommand)
 
         grid.setRowStretch(cslistrow, 1)
@@ -179,7 +179,7 @@ class ImportDialog(QDialog):
             self._cmdcontrol.showStatusMessage('')
 
     def keyPressEvent(self, event):
-        if event.matches(QKeySequence.Refresh):
+        if event.matches(QKeySequence.StandardKey.Refresh):
             self.checkStatus()
         else:
             return super(ImportDialog, self).keyPressEvent(event)
