@@ -1192,7 +1192,7 @@ def relatedRepositories(repoid):
         return
 
     f = QFile(reporegistry.settingsfilename())
-    f.open(QIODevice.ReadOnly)
+    f.open(QIODevice.OpenModeFlag.ReadOnly)
     try:
         for e in repotreemodel.iterRepoItemFromXml(f):
             if e.basenode() == repoid:
