@@ -44,7 +44,7 @@ class TopicDialog(QDialog):
     def __init__(self, repoagent, rev, parent=None):
         super(TopicDialog, self).__init__(parent)
         self.setWindowFlags(self.windowFlags() &
-                            ~Qt.WindowContextHelpButtonHint)
+                            ~Qt.WindowType.WindowContextHelpButtonHint)
         self._repoagent = repoagent
         repo = repoagent.rawRepo()
         self._cmdsession = cmdcore.nullCmdSession()
@@ -54,13 +54,13 @@ class TopicDialog(QDialog):
         base = QVBoxLayout()
         base.setSpacing(0)
         base.setContentsMargins(*(0,)*4)
-        base.setSizeConstraint(QLayout.SetMinAndMaxSize)
+        base.setSizeConstraint(QLayout.SizeConstraint.SetMinAndMaxSize)
         self.setLayout(base)
 
         # main layout grid
         formwidget = QWidget(self)
-        formwidget.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
-        form = QFormLayout(fieldGrowthPolicy=QFormLayout.AllNonFixedFieldsGrow)
+        formwidget.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
+        form = QFormLayout(fieldGrowthPolicy=QFormLayout.FieldGrowthPolicy.AllNonFixedFieldsGrow)
         formwidget.setLayout(form)
         base.addWidget(formwidget)
 
@@ -77,11 +77,10 @@ class TopicDialog(QDialog):
         form.addRow(_('Topic:'), self.topicsCombo)
 
         # bottom buttons
-        BB = QDialogButtonBox
         bbox = QDialogButtonBox()
-        self.setBtn = bbox.addButton(_('&Set'), BB.ActionRole)
-        self.clearBtn = bbox.addButton(_('&Clear'), BB.ActionRole)
-        bbox.addButton(BB.Close)
+        self.setBtn = bbox.addButton(_('&Set'), QDialogButtonBox.ButtonRole.ActionRole)
+        self.clearBtn = bbox.addButton(_('&Clear'), QDialogButtonBox.ButtonRole.ActionRole)
+        bbox.addButton(QDialogButtonBox.StandardButton.Close)
         bbox.rejected.connect(self.reject)
         form.addRow(bbox)
 
@@ -90,8 +89,8 @@ class TopicDialog(QDialog):
 
         # horizontal separator
         self.sep = QFrame()
-        self.sep.setFrameShadow(QFrame.Sunken)
-        self.sep.setFrameShape(QFrame.HLine)
+        self.sep.setFrameShadow(QFrame.Shadow.Sunken)
+        self.sep.setFrameShape(QFrame.Shape.HLine)
         self.layout().addWidget(self.sep)
 
         # status line
