@@ -61,7 +61,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
         super(UpdateWidget, self).__init__(parent)
         if opts is None:
             opts = {}
-        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
+        self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Fixed)
         self._repoagent = repoagent
         repo = repoagent.rawRepo()
 
@@ -378,16 +378,16 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
 
                 opts.append('merge')
 
-                dlg = QMessageBox(QMessageBox.Question, _('Confirm Update'),
-                                  '', QMessageBox.Cancel, self)
+                dlg = QMessageBox(QMessageBox.Icon.Question, _('Confirm Update'),
+                                  '', QMessageBox.StandardButton.Cancel, self)
                 buttonnames = {}
                 for name in opts:
                     label, desc = data[name]
                     msg += '\n'
                     msg += desc
-                    btn = dlg.addButton(label, QMessageBox.ActionRole)
+                    btn = dlg.addButton(label, QMessageBox.ButtonRole.ActionRole)
                     buttonnames[btn] = name
-                dlg.setDefaultButton(QMessageBox.Cancel)
+                dlg.setDefaultButton(QMessageBox.StandardButton.Cancel)
                 dlg.setText(msg)
                 dlg.exec_()
                 return buttonnames.get(dlg.clickedButton())
