@@ -3,7 +3,7 @@
 # Copyright 2009 Steve Borho <steve@borho.org>
 #
 # This software may be used and distributed according to the terms of the
-# GNU General Public License version 2, incorporated herein by reference.
+# GNU General Public License version 2 or any later version.
 
 from __future__ import absolute_import
 
@@ -47,6 +47,35 @@ from ..util import hglib
 from ..util.i18n import _
 from . import qtlib
 
+if hglib.TYPE_CHECKING:
+    from typing import (
+        Any,
+        Dict,
+        Iterable,
+        List,
+        Optional,
+        Sequence,
+        Set,
+        Text,
+        Tuple,
+        Union,
+    )
+    from mercurial import (
+        localrepo,
+        ui as uimod,
+    )
+    from .qtgui import (
+        QListWidgetItem,
+    )
+    from ..util.typelib import (
+        DiffTools,
+        HgContext,
+    )
+
+    # Destination name, source name, dest modification time
+    FnsAndMtime = Tuple[bytes, bytes, float]
+
+
 # Match parent2 first, so 'parent1?' will match both parent1 and parent
 _regex = b'\$(parent2|parent1?|child|plabel1|plabel2|clabel|repo|phash1|phash2|chash)'
 
@@ -57,6 +86,7 @@ _nonexistant = _('[non-existant]')
 _diffCount = 0
 
 def snapshotset(repo, ctxs, sa, sb, copies, copyworkingdir = False):
+    # type: (localrepo.localrepository, Sequence[HgContext], List[Set[bytes]], List[Set[bytes]], Dict[bytes, bytes], bool) -> Tuple[List[Optional[bytes]], List[bytes], List[List[FnsAndMtime]]]
     '''snapshot files from parent-child set of revisions'''
     ctx1a, ctx1b, ctx2 = ctxs
     mod_a, add_a, rem_a = sa
@@ -82,7 +112,7 @@ def snapshotset(repo, ctxs, sa, sb, copies, copyworkingdir = False):
         label1b = b'@%d:%s' % (ctx1b.rev(), ctx1b)
     else:
         dir1b = None
-        fns_mtime1b = []
+        fns_mtime1b = []  # type: List[FnsAndMtime]
         label1b = b''
 
     # Either make a copy of ctx2, or use working dir directly if relevant.
@@ -92,7 +122,7 @@ def snapshotset(repo, ctxs, sa, sb, copies, copyworkingdir = False):
             dir2, fns_mtime2 = snapshot(repo, files2, ctx2)
         else:
             dir2 = repo.root
-            fns_mtime2 = []
+            fns_mtime2 = []  # type: List[FnsAndMtime]
         # If ctx2 is working copy, use empty label.
         label2 = b''
     else:
@@ -105,6 +135,7 @@ def snapshotset(repo, ctxs, sa, sb, copies, copyworkingdir = False):
     return dirs, labels, fns_and_mtimes
 
 def snapshot(repo, files, ctx):
+    # type: (localrepo.localrepository, Iterable[bytes], HgContext) -> Tuple[bytes, List[FnsAndMtime]]
     '''snapshot repo files as of some revision, returning a tuple with the
     created temporary snapshot dir and tuples of file info if using working
     copy.'''
@@ -137,7 +168,7 @@ def snapshot(repo, files, ctx):
             if b'x' in fctx.flags():
                 util.setflags(dest, False, True)
             if ctx.rev() is None:
-                fns_and_mtime.append((dest, repo.wjoin(fn), 
+                fns_and_mtime.append((dest, repo.wjoin(fn),
                                     os.lstat(dest).st_mtime))
             else:
                 # Make file read/only, to indicate it's static (archival) nature
@@ -147,18 +178,13 @@ def snapshot(repo, files, ctx):
     return base, fns_and_mtime
 
 def launchtool(cmd, opts, replace, block):
+    # type: (bytes, Sequence[bytes], Dict[Text, Union[bytes, Text]], bool) -> None
+    # TODO: fix up the bytes vs str in the replacement mapping
     def quote(match):
         key = pycompat.sysstr(match.group()[1:])
         return procutil.shellquote(replace[key])
-    if isinstance(cmd, pycompat.unicode):
-        cmd = hglib.fromunicode(cmd)
-    lopts = []
-    for opt in opts:
-        if isinstance(opt, pycompat.unicode):
-            lopts.append(hglib.fromunicode(opt))
-        else:
-            lopts.append(opt)
-    args = b' '.join(lopts)
+
+    args = b' '.join(opts)
     args = re.sub(_regex, quote, args)
     cmdline = procutil.shellquote(cmd) + b' ' + args
     try:
@@ -175,6 +201,7 @@ def launchtool(cmd, opts, replace, block):
                 _('%s : %s') % (hglib.tounicode(cmd), hglib.tounicode(str(e))))
 
 def filemerge(ui, fname, patchedfname):
+    # type: (uimod.ui, Text, Text) -> None
     'Launch the preferred visual diff tool for two text files'
     detectedtools = hglib.difftools(ui)
     if not detectedtools:
@@ -192,6 +219,7 @@ def filemerge(ui, fname, patchedfname):
 
 
 def besttool(ui, tools, force=None):
+    # type: (uimod.ui, DiffTools, Optional[bytes]) -> bytes
     'Select preferred or highest priority tool from dictionary'
     preferred = force or ui.config(b'tortoisehg', b'vdiff') or \
                          ui.config(b'ui', b'merge')
@@ -204,12 +232,14 @@ def besttool(ui, tools, force=None):
         except error.ConfigError as inst:
             ui.warn(b'visdiff: %s\n' % stringutil.forcebytestr(inst))
             p = 0
+        assert p is not None  # help pytype: default *.priority is 0
         pris.append((-p, t))
-    tools = sorted(pris)
-    return tools[0][1]
+
+    return sorted(pris)[0][1]
 
 
 def visualdiff(ui, repo, pats, opts):
+    # type: (uimod.ui, localrepo.localrepository, Sequence[bytes], Dict[Text, Any]) -> Optional[FileSelectionDialog]
     revs = opts.get('rev', [])
     change = opts.get('change')
 
@@ -220,7 +250,7 @@ def visualdiff(ui, repo, pats, opts):
             if isinstance(change, pycompat.unicode):
                 change = hglib.fromunicode(change)
             if isinstance(change, bytes):
-                ctx2 = scmutil.revsymbol(repo, change)
+                ctx2 = hglib.revsymbol(repo, change)
             else:
                 ctx2 = repo[change]
             p = ctx2.parents()
@@ -241,23 +271,44 @@ def visualdiff(ui, repo, pats, opts):
                        _('You likely need to refresh this application'))
         return None
 
+    return visual_diff(ui, repo, pats, ctx1a, ctx1b, ctx2, opts.get('tool'),
+                       opts.get('mainapp'), revs)
+
+def visual_diff(ui, repo, pats, ctx1a, ctx1b, ctx2, tool, mainapp=False,
+                revs=None):
+    # type: (uimod.ui, localrepo.localrepository, Sequence[bytes], HgContext, Optional[HgContext], HgContext, bytes, bool, Optional[Sequence[int]]) -> Optional[FileSelectionDialog]
+    """Opens the visual diff tool on the given file patterns in the given
+    contexts.  If a ``tool`` is provided, it is used, otherwise the diff tool
+    launched is determined by the configuration.  For a 2-way diff, ``ctx1a`` is
+    the context for the first revision, ``ctxb1`` is None, and ``ctx2`` is the
+    context for the second revision.  For a 3-way diff, ``ctx2`` is the wdir
+    context and ``ctx1a`` and ``ctx1b`` are the "local" and "other" contexts
+    respectively.
+    """
+    # TODO: Figure out how to get rid of the `revs` argument
+    if revs is None:
+        revs = []
     pats = scmutil.expandpats(pats)
-    m = match.match(repo.root, b'', pats, None, None, b'relpath')
+    m = match.match(repo.root, b'', pats, None, None, b'relpath', ctx=ctx2)
     n2 = ctx2.node()
 
     def _status(ctx):
+        # type: (HgContext) -> Tuple[List[bytes], List[bytes], List[bytes]]
         status = repo.status(ctx.node(), n2, m)
         return status.modified, status.added, status.removed
 
     mod_a, add_a, rem_a = pycompat.maplist(set, _status(ctx1a))
     if ctx1b:
         mod_b, add_b, rem_b = pycompat.maplist(set, _status(ctx1b))
-        cpy = copies.mergecopies(repo, ctx1a, ctx1b, ctx1a.ancestor(ctx1b))[0]
-        if util.safehasattr(copies, "branch_copies"):
-            cpy = cpy.copy  # hg 5.4 >= 7f8bdee0034e
+        cpy = copies.mergecopies(repo, ctx1a, ctx1b, ctx1a.ancestor(ctx1b))[0].copy
     else:
         cpy = copies.pathcopies(ctx1a, ctx2)
         mod_b, add_b, rem_b = set(), set(), set()
+
+    cpy = {
+        dst: src for dst, src in cpy.items() if m(src) or m(dst)
+    }
+
     MA = mod_a | add_a | mod_b | add_b
     MAR = MA | rem_a | rem_b
     if not MAR:
@@ -273,7 +324,7 @@ def visualdiff(ui, repo, pats, opts):
                 _('No visual diff tools were detected'))
         return None
 
-    preferred = besttool(repo.ui, detectedtools, opts.get('tool'))
+    preferred = besttool(repo.ui, detectedtools, tool)
 
     # Build tool list based on diff-patterns matches
     toollist = set()
@@ -351,6 +402,7 @@ def visualdiff(ui, repo, pats, opts):
             label2 = b'working files'
 
         def getfile(fname, dir, label):
+            # type: (bytes, bytes, bytes) -> Tuple[bytes, bytes]
             file = os.path.join(qtlib.gettempdir(), dir, fname)
             if os.path.isfile(file):
                 return fname+label, file
@@ -379,11 +431,13 @@ def visualdiff(ui, repo, pats, opts):
             label2 += b'[merged]'
 
         repoagent = repo._pyqtobj  # TODO
+
+        # TODO: sort out bytes vs str
         replace = dict(parent=dir1a, parent1=dir1a, parent2=dir1b,
                        plabel1=label1a, plabel2=label1b,
                        phash1=str(ctx1a), phash2=str(ctx1b),
                        repo=hglib.fromunicode(repoagent.displayName()),
-                       clabel=label2, child=dir2, chash=str(ctx2))
+                       clabel=label2, child=dir2, chash=str(ctx2))  # type: Dict[Text, Union[bytes, Text]]
         launchtool(diffcmd, args, replace, True)
 
         # detect if changes were made to mirrored working files
@@ -397,25 +451,19 @@ def visualdiff(ui, repo, pats, opts):
             except EnvironmentError:
                 pass # Ignore I/O errors or missing files
 
-    def dodiffwrapper():
-        try:
-            dodiff()
-        finally:
-            # cleanup happens atexit
-            ui.note(b'cleaning up temp directory\n')
-
-    if opts.get('mainapp'):
-        dodiffwrapper()
+    if mainapp:
+        dodiff()
     else:
         # We are not the main application, so this must be done in a
         # background thread
-        thread = threading.Thread(target=dodiffwrapper, name='visualdiff')
+        thread = threading.Thread(target=dodiff, name='visualdiff')
         thread.setDaemon(True)
         thread.start()
 
 class FileSelectionDialog(QDialog):
     'Dialog for selecting visual diff candidates'
     def __init__(self, repo, pats, ctx1a, sa, ctx1b, sb, ctx2, cpy):
+        # type: (localrepo.localrepository, Sequence[bytes], HgContext, List[Set[bytes]], Optional[HgContext], List[Set[bytes]], HgContext, Dict[bytes, bytes]) -> None
         'Initialize the Dialog'
         QDialog.__init__(self)
 
@@ -441,7 +489,7 @@ class FileSelectionDialog(QDialog):
         self.filesets = (sa, sb)
         self.copies = cpy
         self.repo = repo
-        self.curFile = None
+        self.curFile = None  # type: Optional[bytes]
 
         layout = QVBoxLayout()
         self.setLayout(layout)
@@ -479,8 +527,7 @@ class FileSelectionDialog(QDialog):
             combo.currentIndexChanged[str].connect(self.onToolSelected)
             self.toolCombo = combo
 
-        BB = QDialogButtonBox
-        bb = BB()
+        bb = QDialogButtonBox()
         layout.addWidget(bb)
 
         if ctx2.rev() is None:
@@ -488,14 +535,14 @@ class FileSelectionDialog(QDialog):
             # Do not offer directory diffs when the working directory
             # is being referenced directly
         elif ctx1b:
-            self.p1button = bb.addButton(_('Dir diff to p1'), BB.ActionRole)
+            self.p1button = bb.addButton(_('Dir diff to p1'), QDialogButtonBox.ButtonRole.ActionRole)
             self.p1button.pressed.connect(self.p1dirdiff)
-            self.p2button = bb.addButton(_('Dir diff to p2'), BB.ActionRole)
+            self.p2button = bb.addButton(_('Dir diff to p2'), QDialogButtonBox.ButtonRole.ActionRole)
             self.p2button.pressed.connect(self.p2dirdiff)
-            self.p3button = bb.addButton(_('3-way dir diff'), BB.ActionRole)
+            self.p3button = bb.addButton(_('3-way dir diff'), QDialogButtonBox.ButtonRole.ActionRole)
             self.p3button.pressed.connect(self.threewaydirdiff)
         else:
-            self.dbutton = bb.addButton(_('Directory diff'), BB.ActionRole)
+            self.dbutton = bb.addButton(_('Directory diff'), QDialogButtonBox.ButtonRole.ActionRole)
             self.dbutton.pressed.connect(self.p1dirdiff)
 
         self.updateDiffButtons(preferred)
@@ -505,11 +552,13 @@ class FileSelectionDialog(QDialog):
 
     @pyqtSlot()
     def fillmodel(self):
+        # type: () -> None
         repo = self.repo
         sa, sb = self.filesets
         self.dirs, self.revs = snapshotset(repo, self.ctxs, sa, sb, self.copies)[:2]
 
         def get_status(file, mod, add, rem):
+            # type: (bytes, Set[bytes], Set[bytes], Set[bytes]) -> Text
             if file in mod:
                 return 'M'
             if file in add:
@@ -526,14 +575,16 @@ class FileSelectionDialog(QDialog):
 
     @pyqtSlot(str)
     def onToolSelected(self, tool):
+        # type: (Text) -> None
         'user selected a tool from the tool combo'
-        tool = hglib.fromunicode(tool)
+        tool = hglib.fromunicode(tool)  # pytype: disable=annotation-type-mismatch
         assert tool in self.tools, tool
         self.diffpath, self.diffopts, self.mergeopts = self.tools[tool]
         self.updateDiffButtons(tool)
 
     @pyqtSlot(int)
     def updateToolSelection(self, row):
+        # type: (int) -> None
         'user selected a file, pick an appropriate tool from combo'
         if row == -1:
             return
@@ -559,16 +610,19 @@ class FileSelectionDialog(QDialog):
                 self.toolCombo.setCurrentIndex(i)
 
     def activateCurrent(self):
+        # type: () -> None
         'CTRL+D has been pressed'
         row = self.list.currentRow()
         if row >= 0:
             self.launch(self.list.item(row).text()[2:])
 
     def itemActivated(self, item):
+        # type: (QListWidgetItem) -> None
         'A QListWidgetItem has been activated'
         self.launch(item.text()[2:])
 
     def updateDiffButtons(self, tool):
+        # type: (bytes) -> None
         # hg>=4.4: configbool() may return None as the default is set to None
         if hasattr(self, 'p1button'):
             d2 = self.repo.ui.configbool(b'merge-tools', tool + b'.dirdiff')
@@ -581,13 +635,16 @@ class FileSelectionDialog(QDialog):
             self.dbutton.setEnabled(bool(d2))
 
     def launch(self, fname):
-        fname = hglib.fromunicode(fname)
+        # type: (Text) -> None
+        fname = hglib.fromunicode(fname)  # pytype: disable=annotation-type-mismatch
         source = self.copies.get(fname, None)
         dir1a, dir1b, dir2 = self.dirs
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
 
+        # pytype: disable=redundant-function-type-comment
         def getfile(ctx, dir, fname, source):
+            # type: (HgContext, bytes, bytes, Optional[bytes]) -> Tuple[bytes, bytes]
             m = ctx.manifest()
             if fname in m:
                 path = os.path.join(dir, util.localpath(fname))
@@ -600,13 +657,14 @@ class FileSelectionDialog(QDialog):
                 fp = open(nullfile, 'w')
                 fp.close()
                 return hglib.fromunicode(_nonexistant, 'replace'), nullfile
+        # pytype: enable=redundant-function-type-comment
 
         local, file1a = getfile(ctx1a, dir1a, fname, source)
         if ctx1b:
             other, file1b = getfile(ctx1b, dir1b, fname, source)
         else:
             other, file1b = fname, None
-        fname, file2 = getfile(ctx2, dir2, fname, None)
+        fname, file2 = getfile(ctx2, dir2, fname, None)  # pytype: disable=annotation-type-mismatch
 
         label1a = local+rev1a
         label1b = other+rev1b
@@ -621,11 +679,12 @@ class FileSelectionDialog(QDialog):
                        parent2=file1b, plabel2=label1b,
                        repo=self.reponame,
                        phash1=str(ctx1a), phash2=str(ctx1b), chash=str(ctx2),
-                       clabel=label2, child=file2)
+                       clabel=label2, child=file2)  # type: Dict[Text, Union[bytes, Text]]
         args = ctx1b and self.mergeopts or self.diffopts
         launchtool(self.diffpath, args, replace, False)
 
     def p1dirdiff(self):
+        # type: () -> None
         dir1a, dir1b, dir2 = self.dirs
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
@@ -633,10 +692,11 @@ class FileSelectionDialog(QDialog):
         replace = dict(parent=dir1a, parent1=dir1a, plabel1=rev1a,
                        repo=self.reponame,
                        phash1=str(ctx1a), phash2=str(ctx1b), chash=str(ctx2),
-                       parent2='', plabel2='', clabel=rev2, child=dir2)
+                       parent2='', plabel2='', clabel=rev2, child=dir2)  # type: Dict[Text, Union[bytes, Text]]
         launchtool(self.diffpath, self.diffopts, replace, False)
 
     def p2dirdiff(self):
+        # type: () -> None
         dir1a, dir1b, dir2 = self.dirs
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
@@ -644,10 +704,11 @@ class FileSelectionDialog(QDialog):
         replace = dict(parent=dir1b, parent1=dir1b, plabel1=rev1b,
                        repo=self.reponame,
                        phash1=str(ctx1a), phash2=str(ctx1b), chash=str(ctx2),
-                       parent2='', plabel2='', clabel=rev2, child=dir2)
+                       parent2='', plabel2='', clabel=rev2, child=dir2)  # type: Dict[Text, Union[bytes, Text]]
         launchtool(self.diffpath, self.diffopts, replace, False)
 
     def threewaydirdiff(self):
+        # type: () -> None
         dir1a, dir1b, dir2 = self.dirs
         rev1a, rev1b, rev2 = self.revs
         ctx1a, ctx1b, ctx2 = self.ctxs
@@ -655,5 +716,5 @@ class FileSelectionDialog(QDialog):
         replace = dict(parent=dir1a, parent1=dir1a, plabel1=rev1a,
                        repo=self.reponame,
                        phash1=str(ctx1a), phash2=str(ctx1b), chash=str(ctx2),
-                       parent2=dir1b, plabel2=rev1b, clabel=dir2, child=rev2)
+                       parent2=dir1b, plabel2=rev1b, clabel=dir2, child=rev2)  # type: Dict[Text, Union[bytes, Text]]
         launchtool(self.diffpath, self.mergeopts, replace, False)
