@@ -80,21 +80,21 @@ class WebconfForm(QWidget):
         def setstdicon(w, name):
             w.setIcon(self.style().standardIcon(name))
 
-        setstdicon(self._qui.open_button, QStyle.SP_DialogOpenButton)
-        setstdicon(self._qui.save_button, QStyle.SP_DialogSaveButton)
+        setstdicon(self._qui.open_button, QStyle.StandardPixmap.SP_DialogOpenButton)
+        setstdicon(self._qui.save_button, QStyle.StandardPixmap.SP_DialogSaveButton)
         self._qui.add_button.setIcon(qtlib.geticon('hg-add'))
         self._qui.edit_button.setIcon(qtlib.geticon('edit-file'))
         self._qui.remove_button.setIcon(qtlib.geticon('hg-remove'))
 
     def dragEnterEvent(self, event):
         if self._getlocalpath_from_dropevent(event):
-            event.setDropAction(Qt.LinkAction)
+            event.setDropAction(Qt.DropAction.LinkAction)
             event.accept()
 
     def dropEvent(self, event):
         localpath = self._getlocalpath_from_dropevent(event)
         if localpath:
-            event.setDropAction(Qt.LinkAction)
+            event.setDropAction(Qt.DropAction.LinkAction)
             event.accept()
             self._addpathmap(localpath=localpath)
 
@@ -230,12 +230,12 @@ class _PathDialog(QDialog):
                  invalidpaths=None, parent=None):
         # type: (Text, Text, Optional[Text], Optional[Text], Optional[Iterable[Text]], Optional[QWidget]) -> None
         super(_PathDialog, self).__init__(parent)
-        self.setWindowFlags((self.windowFlags() | Qt.WindowMinimizeButtonHint)
-                            & ~Qt.WindowContextHelpButtonHint)
-        self.resize(QFontMetrics(self.font()).width('M') * 50, self.height())
+        self.setWindowFlags((self.windowFlags() | Qt.WindowType.WindowMinimizeButtonHint)
+                            & ~Qt.WindowType.WindowContextHelpButtonHint)
+        self.resize(QFontMetrics(self.font()).horizontalAdvance('M') * 50, self.height())
         self.setWindowTitle(title)
         self._invalidpaths = set(invalidpaths or [])
-        self.setLayout(QFormLayout(fieldGrowthPolicy=QFormLayout.ExpandingFieldsGrow))
+        self.setLayout(QFormLayout(fieldGrowthPolicy=QFormLayout.FieldGrowthPolicy.ExpandingFieldsGrow))
         self._initfields()
         self._initbuttons(acceptlabel)
         self._path_edit.setText(path or os.path.basename(localpath or ''))
@@ -260,7 +260,7 @@ class _PathDialog(QDialog):
 
         addfield('path', _('Path:'))
         self._localpath_browse_button = QToolButton(
-            icon=self.style().standardIcon(QStyle.SP_DialogOpenButton))
+            icon=self.style().standardIcon(QStyle.StandardPixmap.SP_DialogOpenButton))
         addfield('localpath', _('Local Path:'), self._localpath_browse_button)
         self._localpath_browse_button.clicked.connect(self._browse_localpath)
 
@@ -268,8 +268,8 @@ class _PathDialog(QDialog):
         # type: (Text) -> None
         """initialize dialog buttons"""
         self._buttons = QDialogButtonBox(self)
-        self._accept_button = self._buttons.addButton(QDialogButtonBox.Ok)
-        self._reject_button = self._buttons.addButton(QDialogButtonBox.Cancel)
+        self._accept_button = self._buttons.addButton(QDialogButtonBox.StandardButton.Ok)
+        self._reject_button = self._buttons.addButton(QDialogButtonBox.StandardButton.Cancel)
         self._accept_button.setText(acceptlabel)
         self._buttons.accepted.connect(self.accept)
         self._buttons.rejected.connect(self.reject)
@@ -350,7 +350,7 @@ class WebconfModel(QAbstractTableModel):
         # type: (QModelIndex, int) -> Any
         if not index.isValid():
             return None
-        if role == Qt.DisplayRole:
+        if role == Qt.ItemDataRole.DisplayRole:
             v = self._config.items(b'paths')[index.row()][index.column()]
             return hglib.tounicode(v)
         return None
@@ -369,7 +369,7 @@ class WebconfModel(QAbstractTableModel):
 
     def headerData(self, section, orientation, role):
         # type: (int, int, int) -> Any
-        if role != Qt.DisplayRole or orientation != Qt.Horizontal:
+        if role != Qt.ItemDataRole.DisplayRole or orientation != Qt.Orientation.Horizontal:
             return None
         return self._COLUMNS[section][0]
 
