@@ -33,7 +33,6 @@ from .qtgui import (
     QShortcut,
     QSizePolicy,
     QToolBar,
-    qApp,
 )
 
 from mercurial import (
@@ -82,20 +81,20 @@ class Workbench(QMainWindow):
         rr.progressReceived.connect(self.statusbar.progress)
         self._repomanager.repositoryChanged.connect(rr.scanRepo)
         rr.hide()
-        self.addDockWidget(Qt.LeftDockWidgetArea, rr)
+        self.addDockWidget(Qt.DockWidgetArea.LeftDockWidgetArea, rr)
 
         self.mqpatches = p = mq.MQPatchesWidget(actionregistry, self)
         p.setObjectName('MQPatchesWidget')
         p.patchSelected.connect(self.gotorev)
         p.hide()
-        self.addDockWidget(Qt.LeftDockWidgetArea, p)
+        self.addDockWidget(Qt.DockWidgetArea.LeftDockWidgetArea, p)
 
         cmdagent = cmdcore.CmdAgent(ui, self)
         self._console = LogDockWidget(repomanager, cmdagent, self)
         self._console.setObjectName('Log')
         self._console.hide()
         self._console.visibilityChanged.connect(self._updateShowConsoleAction)
-        self.addDockWidget(Qt.BottomDockWidgetArea, self._console)
+        self.addDockWidget(Qt.DockWidgetArea.BottomDockWidgetArea, self._console)
 
         self._setupActions()
 
@@ -122,12 +121,12 @@ class Workbench(QMainWindow):
             lambda self, dlgmeth: dlgmeth(self), parent=self)
 
     def setupUi(self):
-        desktopgeom = qApp.desktop().availableGeometry()
+        desktopgeom = QApplication.primaryScreen().availableGeometry()
         self.resize(desktopgeom.size() * 0.8)
 
         self.repoTabsWidget = tw = repotab.RepoTabWidget(
             self._config, self._actionregistry, self._repomanager, self)
-        sp = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+        sp = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
         sp.setHorizontalStretch(1)
         sp.setVerticalStretch(1)
         sp.setHeightForWidth(tw.sizePolicy().hasHeightForWidth())
@@ -431,7 +430,7 @@ class Workbench(QMainWindow):
 
         self._lastRepoSyncPath = {}
         self.urlCombo = QComboBox(self)
-        self.urlCombo.setSizeAdjustPolicy(QComboBox.AdjustToContents)
+        self.urlCombo.setSizeAdjustPolicy(QComboBox.SizeAdjustPolicy.AdjustToContents)
         self.urlCombo.currentIndexChanged.connect(self._updateSyncUrl)
         self.urlComboAction = self.synctbar.addWidget(self.urlCombo)
         # hide it because workbench could be started without open repo
@@ -490,7 +489,7 @@ class Workbench(QMainWindow):
                 itemdata = (pathdict[a], pathdict[a])
                 tooltip = pathdict[a]
             self.urlCombo.addItem(itemtext, itemdata)
-            self.urlCombo.setItemData(n, tooltip, Qt.ToolTipRole)
+            self.urlCombo.setItemData(n, tooltip, Qt.ItemDataRole.ToolTipRole)
         # Try to select the previously selected path, if any
         prevpath = self._lastRepoSyncPath.get(repoagent.rootPath())
         if prevpath:
@@ -533,7 +532,7 @@ class Workbench(QMainWindow):
             tooltip = _('There are no configured sync paths.\n'
                         'Open the Synchronize tab to configure them.')
         else:
-            tooltip = self.urlCombo.itemData(index, Qt.ToolTipRole)
+            tooltip = self.urlCombo.itemData(index, Qt.ItemDataRole.ToolTipRole)
         self.urlCombo.setToolTip(tooltip)
 
     def _updateSyncActionToolTip(self, index):
@@ -755,7 +754,7 @@ class Workbench(QMainWindow):
         for u in d.urls():
             root = paths.find_root(pycompat.unicode(u.toLocalFile()))
             if root:
-                event.setDropAction(Qt.LinkAction)
+                event.setDropAction(Qt.DropAction.LinkAction)
                 event.accept()
                 break
 
@@ -768,7 +767,7 @@ class Workbench(QMainWindow):
                 self.showRepo(root)
                 accept = True
         if accept:
-            event.setDropAction(Qt.LinkAction)
+            event.setDropAction(Qt.DropAction.LinkAction)
             event.accept()
 
     def _updateMenu(self):
@@ -890,7 +889,7 @@ class Workbench(QMainWindow):
 
     @pyqtSlot()
     def refresh(self):
-        clear = QApplication.keyboardModifiers() & Qt.ControlModifier
+        clear = QApplication.keyboardModifiers() & Qt.KeyboardModifier.ControlModifier
         w = self._currentRepoWidget()
         if w:
             # check unnoticed changes to emit corresponding signals
@@ -1024,7 +1023,7 @@ class Workbench(QMainWindow):
             cwd = hglib.getcwdu()
         FD = QFileDialog
         path = FD.getExistingDirectory(self, caption, cwd,
-                                       FD.ShowDirsOnly | FD.ReadOnly)
+                                       QFileDialog.Option.ShowDirsOnly | QFileDialog.Option.ReadOnly)
         self.openRepo(path, False)
 
     def _currentRepoWidget(self):
