@@ -20,6 +20,9 @@ from mercurial import (
     sslutil,
     util,
 )
+from mercurial.utils import (
+    urlutil,
+)
 
 from tortoisehg.util import (
     hgversion,
@@ -49,11 +52,14 @@ def debuggethostfingerprint(ui, repo, source=b'default', **opts):
 
     Specify --insecure to disable SSL verification.
     """
-    source = ui.expandpath(source)
-    u = util.url(source)
+    # we have no idea if the source url is for pull or push, so let's assume
+    # 'pull' is more basic operation like other hg debug* commands.
+    source, _branches = urlutil.get_unique_pull_path(
+        b'debuggethostfingerprint', repo, ui, source)
+    u = urlutil.url(source)
     scheme = (u.scheme or b'').split(b'+')[-1]
     host = u.host
-    port = util.getport(u.port or scheme or b'-1')
+    port = urlutil.getport(u.port or scheme or b'-1')
     if scheme != b'https' or not host or not (0 <= port <= 65535):
         raise error.Abort(_('unsupported URL: %s') % source)
 
@@ -78,7 +84,7 @@ def postinitskel(ui, repo, hooktype, result, pats, **kwargs):
     assert hooktype == b'post-init', hooktype
     if result:
         return
-    dest = ui.expandpath(pats and pats[0] or b'.')
+    _src, dest, _branch = urlutil.get_clone_path(ui, pats and pats[0] or b'.')
     skel = ui.config(b'tortoisehg', b'initskel')
     if skel:
         # copy working tree from user-defined path if any
