@@ -604,7 +604,7 @@ def difftools(ui):
             if not path:
                 path = cmd
             diffopts = ui.config(b'extdiff', b'opts.' + cmd)
-            diffopts = pycompat.shlexsplit(diffopts)
+            diffopts = pycompat.shlexsplit(diffopts) if diffopts else []
             diffopts, mergeopts = fixup_extdiff(diffopts)
             tools[cmd] = (path, diffopts, mergeopts)
         elif cmd.startswith(b'opts.'):
@@ -642,7 +642,7 @@ tortoisehgtoollocations = (
 )
 
 def tortoisehgtools(uiorconfig, selectedlocation=None):
-    # type: (IniConfig, Optional[Text]) -> Tuple[Dict[Text, Dict[Text, Union[Text, bool]]], List[Text]]
+    # type: (Union[IniConfig, uimod.ui], Optional[Text]) -> Tuple[Dict[Text, Dict[Text, Union[Text, bool]]], List[Text]]
     """Parse 'tortoisehg-tools' section of ini file.
 
     >>> from pprint import pprint
