@@ -3,10 +3,25 @@
 # Copyright 2009 Steve Borho <steve@borho.org>
 #
 # This software may be used and distributed according to the terms of the
-# GNU General Public License version 2, incorporated herein by reference.
+# GNU General Public License version 2 or any later version.
 
-import gettext, os, locale
-from tortoisehg.util import paths
+from __future__ import absolute_import
+
+import gettext
+import locale
+import os
+
+from mercurial import pycompat
+
+from . import paths
+
+if getattr(pycompat, 'TYPE_CHECKING', False):
+    from typing import (
+        Dict,
+        List,
+        Optional,
+        Text,
+    )
 
 _localeenvs = ('LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG')
 def _defaultlanguage():
@@ -21,13 +36,19 @@ def _defaultlanguage():
     # For details, please read "User Interface Language Management":
     # http://msdn.microsoft.com/en-us/library/dd374098(v=VS.85).aspx
     try:
-        from ctypes import windll  # requires Python>=2.5
+        from ctypes import windll  # pytype: disable=import-error
         langid = windll.kernel32.GetUserDefaultUILanguage()
         return locale.windows_locale[langid]
     except (ImportError, AttributeError, KeyError):
         pass
 
+# to be set later; don't assign these functions directly since they could
+# already be imported by name.
+_ugettext = None
+_ungettext = None
+
 def setlanguage(lang=None):
+    # type: (Optional[Text]) -> None
     """Change translation catalog to the specified language"""
     global t, language
     if not lang:
@@ -37,10 +58,19 @@ def setlanguage(lang=None):
         opts['languages'] = (lang,)
     t = gettext.translation('tortoisehg', paths.get_locale_path(),
                             fallback=True, **opts)
-    language = lang or locale.getdefaultlocale(_localeenvs)[0]
+    global _ugettext, _ungettext
+    try:
+        _ugettext = t.ugettext  # pytype: disable=attribute-error
+        _ungettext = t.ungettext  # pytype: disable=attribute-error
+    except AttributeError:
+        _ugettext = t.gettext
+        _ungettext = t.ngettext
+
+    language = lang or locale.getdefaultlocale(_localeenvs)[0]  # type: Optional[Text]
 setlanguage()
 
 def availablelanguages():
+    # type: () -> List[str]
     """List up language code of which message catalog is available"""
     basedir = paths.get_locale_path()
     def mopath(lang):
@@ -53,17 +83,20 @@ def availablelanguages():
     return sorted(langs)
 
 def _(message, context=''):
+    # type: (Text, Text) -> pycompat.unicode
     if context:
         sep = '\004'
-        tmsg = t.ugettext(context + sep + message)
+        tmsg = _ugettext(context + sep + message)
         if sep not in tmsg:
             return tmsg
-    return t.ugettext(message)
+    return _ugettext(message)
 
 def ngettext(singular, plural, n):
-    return t.ungettext(singular, plural, n)
+    # type: (Text, Text, int) -> pycompat.unicode
+    return _ungettext(singular, plural, n)
 
 def agettext(message, context=''):
+    # type: (Text, Text) -> bytes
     """Translate message and convert to local encoding
     such as 'ascii' before being returned.
 
@@ -75,8 +108,9 @@ def agettext(message, context=''):
         u = _(message, context)
         return hglib.fromunicode(u)
     except (LookupError, UnicodeEncodeError):
-        return message
+        return pycompat.sysbytes(message)
 
 class keepgettext(object):
     def _(self, message, context=''):
+        # type: (Text, Text) -> Dict[Text, Text]
         return {'id': message, 'str': _(message, context)}
