@@ -3,7 +3,7 @@
 # Copyright 2009 Steve Borho <steve@borho.org>
 #
 # This software may be used and distributed according to the terms of the
-# GNU General Public License version 2, incorporated herein by reference.
+# GNU General Public License version 2 or any later version.
 
 from __future__ import absolute_import, print_function
 
@@ -20,7 +20,7 @@ from mercurial import (
 try:
     # TODO: These are generated a str on non Windows platforms, but can be
     #       filesystem encoded on Windows.
-    from .config import (
+    from .config import (  # pytype: disable=import-error
         bin_path,
         icon_path,
         license_path,
@@ -36,15 +36,16 @@ if pycompat.TYPE_CHECKING:
         List,
         Optional,
         overload,
+        Text,
     )
 
     @overload
     def _find_root(p, dn):
-        # type: (str, str) -> str
+        # type: (Text, Text) -> Optional[Text]
         pass
     @overload
     def _find_root(p, dn):
-        # type: (bytes, bytes) -> bytes
+        # type: (bytes, bytes) -> Optional[bytes]
         pass
 
 
@@ -59,15 +60,15 @@ def _find_root(p, dn):
     return p
 
 def find_root(path=None):
-    # type: (Optional[str]) -> str
+    # type: (Optional[Text]) -> Optional[Text]
     return _find_root(path or os.getcwd(), '.hg')
 
 def find_root_bytes(path=None):
-    # type: (Optional[bytes]) -> bytes
+    # type: (Optional[bytes]) -> Optional[bytes]
     return _find_root(path or encoding.getcwd(), b'.hg')
 
 def get_tortoise_icon(icon):
-    # type: (str) -> Optional[str]
+    # type: (Text) -> Optional[Text]
     "Find a tortoisehg icon"
     icopath = os.path.join(get_icon_path(), icon)
     if os.path.isfile(icopath):
@@ -77,26 +78,26 @@ def get_tortoise_icon(icon):
         return None
 
 def get_icon_path():
-    # type: () -> str
+    # type: () -> Text
     global icon_path
     return icon_path or os.path.join(get_prog_root(), 'icons')
 
 def get_license_path():
-    # type: () -> str
+    # type: () -> Text
     global license_path
     return license_path or os.path.join(get_prog_root(), 'COPYING.txt')
 
 def get_locale_path():
-    # type: () -> str
+    # type: () -> Text
     global locale_path
     return locale_path or os.path.join(get_prog_root(), 'locale')
 
 def _get_hg_path():
-    # type: () -> str
+    # type: () -> Text
     return os.path.abspath(os.path.join(mercurial.__file__, '..', '..'))
 
 def get_hg_command():
-    # type: () -> List[str]
+    # type: () -> List[Text]
     """List of command to execute hg (equivalent to mercurial.util.hgcmd)"""
     global _hg_command
     if _hg_command is None:
@@ -111,10 +112,10 @@ def get_hg_command():
     return _hg_command
 
 if os.name == 'nt':
-    import win32file
+    import win32file  # pytype: disable=import-error
 
     def find_in_path(pgmname):
-        # type: (str) -> Optional[str]
+        # type: (Text) -> Optional[Text]
         "return first executable found in search path"
         global bin_path
         ospath = os.environ['PATH'].split(os.pathsep)
@@ -129,7 +130,7 @@ if os.name == 'nt':
         return None
 
     def _find_hg_command():
-        # type: () -> List[str]
+        # type: () -> List[Text]
         if hasattr(sys, 'frozen'):
             progdir = get_prog_root()
             exe = os.path.join(progdir, 'hg.exe')
@@ -155,13 +156,13 @@ if os.name == 'nt':
         return [exe]
 
     def get_prog_root():
-        # type: () -> str
+        # type: () -> Text
         if getattr(sys, 'frozen', False):
             return os.path.dirname(sys.executable)
         return os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
 
     def get_thg_command():
-        # type: () -> List[str]
+        # type: () -> List[Text]
         if getattr(sys, 'frozen', False):
             return [sys.executable]
         return [sys.executable] + sys.argv[:1]
@@ -174,7 +175,7 @@ if os.name == 'nt':
             unc, rest = os.path.splitdrive(path)
             return len(unc) > 2
         else:
-            unc, rest = os.path.splitunc(path)
+            unc, rest = os.path.splitunc(path)  # pytype: disable=module-attr
             return bool(unc)
 
     def is_on_fixed_drive(path):
@@ -192,7 +193,7 @@ if os.name == 'nt':
 else: # Not Windows
 
     def find_in_path(pgmname):
-        # type: (str) -> Optional[str]
+        # type: (Text) -> Optional[Text]
         """ return first executable found in search path """
         global bin_path
         ospath = os.environ['PATH'].split(os.pathsep)
@@ -204,7 +205,7 @@ else: # Not Windows
         return None
 
     def _find_hg_command():
-        # type: () -> List[str]
+        # type: () -> List[Text]
         # look for in-place build, i.e. "make local"
         exe = os.path.join(_get_hg_path(), 'hg')
         if os.path.exists(exe):
@@ -216,12 +217,12 @@ else: # Not Windows
         return [exe]
 
     def get_prog_root():
-        # type: () -> str
+        # type: () -> Text
         path = os.path.dirname(os.path.dirname(os.path.dirname(__file__)))
         return path
 
     def get_thg_command():
-        # type: () -> List[str]
+        # type: () -> List[Text]
         return sys.argv[:1]
 
     def is_unc_path(path):
