@@ -36,11 +36,24 @@ Caveats:
 
 import atexit, ctypes, os, threading
 
-from mercurial import error
+from mercurial import (
+    error,
+    pycompat,
+)
 
 from tortoisehg.util import hgversion
 from tortoisehg.util.i18n import agettext as _
 
+if pycompat.TYPE_CHECKING:
+    from typing import (
+        BinaryIO,
+        Optional,
+    )
+    from mercurial import (
+        ui as uimod,
+    )
+
+
 testedwith = hgversion.testedwith
 
 _CTRL_C_EVENT = 0
@@ -54,12 +67,12 @@ _WM_STOPMESSAGELOOP = _WM_APP + 0
 
 def _errcheckbool(result, func, args):
     if not result:
-        raise ctypes.WinError()
+        raise ctypes.WinError()  # pytype: disable=module-attr
     return args
 
 def _errcheckminus1(result, func, args):
     if result == -1:
-        raise ctypes.WinError()
+        raise ctypes.WinError()  # pytype: disable=module-attr
     return args
 
 if os.name == 'nt':
@@ -83,7 +96,9 @@ if os.name == 'nt':
     _UINT = wintypes.UINT
     _WPARAM = wintypes.WPARAM
 
-    _WNDPROC = ctypes.WINFUNCTYPE(_LRESULT, _HWND, _UINT, _WPARAM, _LPARAM)
+    _WNDPROC = ctypes.WINFUNCTYPE(  # pytype: disable=module-attr
+        _LRESULT, _HWND, _UINT, _WPARAM, _LPARAM
+    )
 
     class _WNDCLASS(ctypes.Structure):
         _fields_ = [
@@ -99,7 +114,8 @@ if os.name == 'nt':
             ('lpszClassName', _LPCTSTR),
             ]
 
-    _CreateWindowEx = ctypes.windll.user32.CreateWindowExA
+    windll = ctypes.windll  # pytype: disable=module-attr
+    _CreateWindowEx = windll.user32.CreateWindowExA
     _CreateWindowEx.restype = _HWND
     _CreateWindowEx.argtypes = (_DWORD, _LPCTSTR, _LPCTSTR, _DWORD,
                                 ctypes.c_int, ctypes.c_int, ctypes.c_int,
@@ -107,55 +123,56 @@ if os.name == 'nt':
                                 _LPVOID)
     _CreateWindowEx.errcheck = _errcheckbool
 
-    _DefWindowProc = ctypes.windll.user32.DefWindowProcA
+    _DefWindowProc = windll.user32.DefWindowProcA
     _DefWindowProc.restype = _LRESULT
     _DefWindowProc.argtypes = (_HWND, _UINT, _WPARAM, _LPARAM)
 
-    _DestroyWindow = ctypes.windll.user32.DestroyWindow
+    _DestroyWindow = windll.user32.DestroyWindow
     _DestroyWindow.restype = _BOOL
     _DestroyWindow.argtypes = (_HWND,)
     _DestroyWindow.errcheck = _errcheckbool
 
-    _DispatchMessage = ctypes.windll.user32.DispatchMessageA
+    _DispatchMessage = windll.user32.DispatchMessageA
     _DispatchMessage.restype = _LRESULT
     _DispatchMessage.argtypes = (ctypes.POINTER(_MSG),)
 
-    _GenerateConsoleCtrlEvent = ctypes.windll.kernel32.GenerateConsoleCtrlEvent
+    _GenerateConsoleCtrlEvent = windll.kernel32.GenerateConsoleCtrlEvent
     _GenerateConsoleCtrlEvent.restype = _BOOL
     _GenerateConsoleCtrlEvent.argtypes = (_DWORD, _DWORD)
     _GenerateConsoleCtrlEvent.errcheck = _errcheckbool
 
-    _GetMessage = ctypes.windll.user32.GetMessageA
+    _GetMessage = windll.user32.GetMessageA
     _GetMessage.restype = _BOOL  # -1, 0, or non-zero
     _GetMessage.argtypes = (ctypes.POINTER(_MSG), _HWND, _UINT, _UINT)
     _GetMessage.errcheck = _errcheckminus1
 
-    _GetModuleHandle = ctypes.windll.kernel32.GetModuleHandleA
+    _GetModuleHandle = windll.kernel32.GetModuleHandleA
     _GetModuleHandle.restype = _HMODULE
     _GetModuleHandle.argtypes = (_LPCTSTR,)
     _GetModuleHandle.errcheck = _errcheckbool
 
-    _PostQuitMessage = ctypes.windll.user32.PostQuitMessage
+    _PostQuitMessage = windll.user32.PostQuitMessage
     _PostQuitMessage.restype = None
     _PostQuitMessage.argtypes = (ctypes.c_int,)
 
-    _PostMessage = ctypes.windll.user32.PostMessageA
+    _PostMessage = windll.user32.PostMessageA
     _PostMessage.restype = _BOOL
     _PostMessage.argtypes = (_HWND, _UINT, _WPARAM, _LPARAM)
     _PostMessage.errcheck = _errcheckbool
 
-    _RegisterClass = ctypes.windll.user32.RegisterClassA
+    _RegisterClass = windll.user32.RegisterClassA
     _RegisterClass.restype = _ATOM
     _RegisterClass.argtypes = (ctypes.POINTER(_WNDCLASS),)
     _RegisterClass.errcheck = _errcheckbool
 
-    _TranslateMessage = ctypes.windll.user32.TranslateMessage
+    _TranslateMessage = windll.user32.TranslateMessage
     _TranslateMessage.restype = _BOOL
     _TranslateMessage.argtypes = (ctypes.POINTER(_MSG),)
 
 class messageserver(object):
 
     def __init__(self, logfile):
+        # type: (Optional[BinaryIO]) -> None
         self._logfile = logfile
         self._thread = threading.Thread(target=self._mainloop)
         self._thread.setDaemon(True)  # skip global join before atexit
@@ -231,6 +248,7 @@ class messageserver(object):
         return _DefWindowProc(hwnd, msg, wparam, lparam)
 
 def _openlogfile(ui):
+    # type: (uimod.ui) -> Optional[BinaryIO]
     log = ui.config(b'win32ill', b'log')
     if log == b'-':
         return ui.ferr
@@ -238,6 +256,7 @@ def _openlogfile(ui):
         return open(log, 'ab')
 
 def uisetup(ui):
+    # type: (uimod.ui) -> None
     if os.name != 'nt':
         ui.warn(_('win32ill: unsupported platform: %s\n') % os.name)
         return
